#!/usr/bin/env python
# encoding: utf-8

name = "H_Abstraction/TS_training"
shortDesc = u"Distances used to train group additivity values for TS geometries"
longDesc = u"""
Put interatomic distances for reactions to use as a training set for fitting
group additivity values in this file.
"""
recommended = True

entry(
    index = 1,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.40773504244', 'd12': '0.895297060023', 'd13': '2.30303210246'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 2,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.35892133446', 'd12': '0.930299051641', 'd13': '2.28893519078'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 3,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.20216645606', 'd12': '0.907894558278', 'd13': '2.10402794429'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 4,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.21988501633', 'd12': '1.15309849454', 'd13': '2.37290946709'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 5,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {3,S} {6,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.46347894682', 'd12': '0.862862296846', 'd13': '2.32579722591'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 6,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.06757172779', 'd12': '1.11574127633', 'd13': '2.1796554827'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 7,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.926273983824', 'd12': '1.36413844572', 'd13': '2.29011119802'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 8,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.08060600298', 'd12': '1.23289966705', 'd13': '2.31166939106'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 9,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.04828664688', 'd12': '1.17928080736', 'd13': '2.22345150147'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 10,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': '1.19436701782', 'd12': '1.23398956601', 'd13': '2.42765010692'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 11,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.856116451331', 'd12': '1.47813602871', 'd13': '2.33353250223'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 12,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.890380160538', 'd12': '1.41348718108', 'd13': '2.3037243324'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 13,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.929233924724', 'd12': '1.36327979666', 'd13': '2.29221727048'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 14,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.857297575577', 'd12': '1.47462637073', 'd13': '2.33091998893'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 15,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {5,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.30720965209', 'd12': '0.974384887201', 'd13': '2.28142288545'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 16,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     O u0 p2 c0  {2,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     O u0 p2 c0  {2,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.929232557334', 'd12': '1.36776843715', 'd13': '2.2968743381'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 17,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {3,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {4,D} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4    O u0 p2 c0  {2,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.955049619099', 'd12': '1.32911528045', 'd13': '2.28383585417'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 18,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4  *3 C u1 p0 c0  {2,S} {3,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {12,S}
4  *1 C u0 p0 c0  {2,S} {3,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {4,S}
12    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.41659613444', 'd12': '0.887625561499', 'd13': '2.30400248858'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 19,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {3,S} {15,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     O u0 p2 c0  {3,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.929562714059', 'd12': '1.35777238782', 'd13': '2.28701840306'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 20,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     O u0 p2 c0  {1,S} {14,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.923478017904', 'd12': '1.36923344491', 'd13': '2.29270714272'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 21,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5  *1 C u0 p0 c0  {2,S} {9,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {5,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.927276316146', 'd12': '1.36286435818', 'd13': '2.28958345535'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 22,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.970596361047', 'd12': '1.31339574095', 'd13': '2.28396108373'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 23,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {6,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {2,S} {4,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.976300411313', 'd12': '1.30507883057', 'd13': '2.28125066263'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 24,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.919883004244', 'd12': '1.37805888248', 'd13': '2.29790558097'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 25,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.92744513748', 'd12': '1.37106798486', 'd13': '2.29850984591'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 26,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.850034093713', 'd12': '1.4930819397', 'd13': '2.34311603157'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 27,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {5,B} {8,S}
3     C u0 p0 c0  {1,B} {6,B} {9,S}
4     C u0 p0 c0  {5,B} {6,B} {10,S}
5     C u0 p0 c0  {2,B} {4,B} {11,S}
6     C u0 p0 c0  {3,B} {4,B} {12,S}
7  *1 O u0 p2 c0  {1,S} {13,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13 *2 H u0 p0 c0  {7,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {5,B} {8,S}
3     C u0 p0 c0  {1,B} {6,B} {9,S}
4     C u0 p0 c0  {5,B} {6,B} {10,S}
5     C u0 p0 c0  {2,B} {4,B} {11,S}
6     C u0 p0 c0  {3,B} {4,B} {12,S}
7  *3 O u1 p2 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.08657681722', 'd12': '1.08110686108', 'd13': '2.16027024006'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 28,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
3     C u0 p0 c0  {1,S} {4,B} {5,B}
4     C u0 p0 c0  {3,B} {7,B} {14,S}
5     C u0 p0 c0  {3,B} {8,B} {15,S}
6     C u0 p0 c0  {7,B} {8,B} {16,S}
7     C u0 p0 c0  {4,B} {6,B} {17,S}
8     C u0 p0 c0  {5,B} {6,B} {18,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {7,S}
18    H u0 p0 c0  {8,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {6,B} {11,S}
4     C u0 p0 c0  {2,B} {7,B} {12,S}
5     C u0 p0 c0  {6,B} {7,B} {13,S}
6     C u0 p0 c0  {3,B} {5,B} {14,S}
7     C u0 p0 c0  {4,B} {5,B} {15,S}
8  *3 C u1 p0 c0  {1,S} {16,S} {17,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {8,S}
17    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.923728822558', 'd12': '1.36787122418', 'd13': '2.29107401551'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via double-ended TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 29,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37890', 'd12': '1.33014', 'd13': '2.70895'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 30,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.44233', 'd12': '1.28923', 'd13': '2.73121'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 31,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.30536', 'd12': '1.20569', 'd13': '2.51006'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 32,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.14362', 'd12': '1.40355', 'd13': '2.54716'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 33,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.22242', 'd12': '1.32319', 'd13': '2.54544'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 34,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.10392', 'd12': '1.27899', 'd13': '2.34834'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 35,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37951', 'd12': '1.32326', 'd13': '2.70269'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 36,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *3 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.15831', 'd12': '1.38612', 'd13': '2.54409'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 37,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {3,S} {6,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.31192', 'd12': '1.37209', 'd13': '2.68374'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 38,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {4,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {8,S} {9,S}
3     C u0 p0 c0  {2,S} {4,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {3,S} {5,S} {12,S}
5  *2 H u0 p0 c0  {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
4  *3 C u1 p0 c0  {2,S} {3,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.39021', 'd12': '1.31082', 'd13': '2.70089'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 39,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.35719', 'd12': '1.33957', 'd13': '2.69461'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 40,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.32993', 'd12': '1.37733', 'd13': '2.70362'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 41,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.33663', 'd12': '1.36697', 'd13': '2.70329'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 42,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.30692', 'd12': '1.38471', 'd13': '2.69157'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 43,
    reactant1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.39456', 'd12': '1.18856', 'd13': '2.58134'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 44,
    reactant1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.32977', 'd12': '1.05831', 'd13': '2.28959'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation""",
    longDesc = 
u"""
""",
)

entry(
    index = 45,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.808251, 'd12': 1.407349, 'd13': 2.196944},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 46,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.296176, 'd12': 1.002833, 'd13': 2.29898},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 47,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.216325, 'd12': 1.324475, 'd13': 2.537847},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 48,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.91111, 'd12': 1.201, 'd13': 2.10677},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 49,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.060399, 'd12': 1.250952, 'd13': 2.311305},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 50,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.926377, 'd12': 1.366101, 'd13': 2.29247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 51,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19983, 'd12': 1.310536, 'd13': 2.509181},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 52,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.274424, 'd12': 1.486471, 'd13': 2.760463},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 53,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.126056, 'd12': 1.425793, 'd13': 2.55168},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 54,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.877258, 'd12': 1.430155, 'd13': 2.306828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 55,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.927201, 'd12': 1.366575, 'd13': 2.293246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 56,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {3,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.008692, 'd12': 1.297897, 'd13': 2.306541},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 57,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.235607, 'd12': 1.272333, 'd13': 2.495812},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 58,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.002539, 'd12': 1.591884, 'd13': 2.498974},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 59,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.162672, 'd12': 1.477049, 'd13': 2.638169},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 60,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.464952, 'd12': 1.262583, 'd13': 2.727535},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 61,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     O u0 p2 c0  {1,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {4,S}
4     O u0 p2 c0  {3,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.176607, 'd12': 1.193929, 'd13': 2.370363},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 62,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.012158, 'd12': 1.268907, 'd13': 2.279237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 63,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.246208, 'd12': 1.275568, 'd13': 2.521678},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 64,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.380732, 'd12': 1.32602, 'd13': 2.706495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 65,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.363688, 'd12': 1.332471, 'd13': 2.695568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 66,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.470831, 'd12': 1.26608, 'd13': 2.736083},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 67,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {3,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.430905, 'd12': 1.302739, 'd13': 2.733224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 68,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.371495, 'd12': 0.926853, 'd13': 2.298343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 69,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.317309, 'd12': 1.223801, 'd13': 2.535817},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 70,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.429246, 'd12': 1.284618, 'd13': 2.712247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 71,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33542, 'd12': 1.380621, 'd13': 2.716025},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 72,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.149865, 'd12': 1.40219, 'd13': 2.551133},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 73,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.355809, 'd12': 1.356755, 'd13': 2.71208},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 74,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.289857, 'd12': 1.24964, 'd13': 2.539487},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 75,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.248587, 'd12': 1.276309, 'd13': 2.524895},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 76,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.329108, 'd12': 1.421184, 'd13': 2.749792},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 77,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.306486, 'd12': 1.449892, 'd13': 2.754254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 78,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.185967, 'd12': 1.355088, 'd13': 2.540637},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 79,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.377889, 'd12': 1.328058, 'd13': 2.705697},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 80,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {5,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {5,S} {14,S} {15,S} {16,S}
5  *3 C u1 p0 c0  {1,S} {3,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.065669, 'd12': 1.235549, 'd13': 2.301216},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 81,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.409141, 'd12': 1.307025, 'd13': 2.715605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 82,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.381915, 'd12': 1.325846, 'd13': 2.707452},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 83,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.299711, 'd12': 1.382945, 'd13': 2.682409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 84,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {3,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.930376, 'd12': 1.362744, 'd13': 2.292827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 85,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {1,S} {2,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.968067, 'd12': 1.319334, 'd13': 2.286248},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 86,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4443, 'd12': 1.287947, 'd13': 2.732236},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 87,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.513197, 'd12': 1.235324, 'd13': 2.74749},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 88,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.463225, 'd12': 1.272173, 'd13': 2.734469},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 89,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.994169, 'd12': 1.282451, 'd13': 2.276393},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 90,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    O u1 p2 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48516, 'd12': 1.131035, 'd13': 2.614105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 91,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38475, 'd12': 1.160095, 'd13': 2.544667},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 92,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32645, 'd12': 1.222161, 'd13': 2.548529},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 93,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.493337, 'd12': 1.255489, 'd13': 2.74766},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 94,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {3,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {4,D} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4    O u0 p2 c0  {2,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.380239, 'd12': 1.321635, 'd13': 2.701664},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 95,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.455335, 'd12': 1.287741, 'd13': 2.74237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 96,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.464653, 'd12': 1.254446, 'd13': 2.717863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 97,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.353827, 'd12': 1.354599, 'd13': 2.708409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 98,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.331478, 'd12': 1.4283, 'd13': 2.756683},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 99,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.309076, 'd12': 1.457569, 'd13': 2.765122},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 100,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.352875, 'd12': 1.359062, 'd13': 2.711432},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 101,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.330919, 'd12': 1.229832, 'd13': 2.560671},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 102,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.246807, 'd12': 1.280576, 'd13': 2.526767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 103,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30392, 'd12': 1.45327, 'd13': 2.755748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 104,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.210177, 'd12': 1.332136, 'd13': 2.542273},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 105,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.188088, 'd12': 1.355607, 'd13': 2.543226},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 106,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {3,D} {7,S}
3     C u0 p0 c0  {2,D} {8,S} {9,S}
4     O u0 p2 c0  {1,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2 *3 C u1 p0 c0  {1,S} {4,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    O u0 p2 c0  {2,S} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.483497, 'd12': 1.271122, 'd13': 2.75044},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 107,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.418941, 'd12': 1.291399, 'd13': 2.710328},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 108,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.376535, 'd12': 1.333048, 'd13': 2.708112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 109,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,S} {11,D}
4     O u0 p2 c0  {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,D}
3  *3 C u1 p0 c0  {4,S} {9,S} {10,S}
4     O u0 p2 c0  {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     O u0 p2 c0  {2,D}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38536, 'd12': 1.318788, 'd13': 2.703903},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 110,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,S} {11,D}
4     O u0 p2 c0  {2,S} {3,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {4,S} {8,D}
3  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
4     O u0 p2 c0  {1,S} {2,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     O u0 p2 c0  {2,D}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.403984, 'd12': 1.298579, 'd13': 2.702172},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 111,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,D} {10,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    C u0 p0 c0  {2,S} {8,D} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.453078, 'd12': 1.280278, 'd13': 2.731984},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 112,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,D} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
3    C u0 p0 c0  {1,S} {6,D} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {3,D}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.343187, 'd12': 1.364407, 'd13': 2.707408},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 113,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.421882, 'd12': 1.318758, 'd13': 2.74022},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 114,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.384498, 'd12': 1.346259, 'd13': 2.730612},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 115,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.201517, 'd12': 1.34754, 'd13': 2.547347},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 116,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.152543, 'd12': 1.404984, 'd13': 2.557307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 117,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.356039, 'd12': 1.360934, 'd13': 2.716761},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 118,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.351842, 'd12': 1.408127, 'd13': 2.756651},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 119,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307129, 'd12': 1.461382, 'd13': 2.768218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 120,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {16,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16 *2 H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.453162, 'd12': 1.113429, 'd13': 2.565773},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 121,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44811, 'd12': 1.286944, 'd13': 2.734005},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 122,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.389466, 'd12': 1.322772, 'd13': 2.712125},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 123,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.195943, 'd12': 1.347002, 'd13': 2.542942},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 124,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {4,S} {5,S} {12,D}
4     O u0 p2 c0  {1,S} {3,S}
5     O u0 p2 c0  {2,S} {3,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {5,S} {9,D}
3  *3 C u1 p0 c0  {5,S} {10,S} {11,S}
4     O u0 p2 c0  {1,S} {2,S}
5     O u0 p2 c0  {2,S} {3,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {2,D}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.382092, 'd12': 1.321991, 'd13': 2.703748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 125,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {9,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {8,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.259028, 'd12': 1.243519, 'd13': 2.490608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 126,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.405721, 'd12': 1.205245, 'd13': 2.603715},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 127,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25767, 'd12': 1.278589, 'd13': 2.534594},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 128,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.410864, 'd12': 1.321875, 'd13': 2.730185},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 129,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,D} {15,S}
6     C u0 p0 c0  {4,S} {5,D} {16,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {6,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     C u0 p0 c0  {2,S} {6,D} {15,S}
6     C u0 p0 c0  {3,S} {5,D} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.370231, 'd12': 1.341899, 'd13': 2.712072},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 130,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33492, 'd12': 1.390728, 'd13': 2.723733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 131,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.391177, 'd12': 1.337615, 'd13': 2.727653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 132,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.415978, 'd12': 1.314561, 'd13': 2.730215},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 133,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {11,D} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    O u0 p2 c0  {4,D}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.454247, 'd12': 1.286158, 'd13': 2.739153},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 134,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {5,D} {12,S}
4     C u0 p0 c0  {1,S} {6,D} {13,S}
5     C u0 p0 c0  {3,D} {7,S} {15,S}
6     C u0 p0 c0  {4,D} {7,S} {16,S}
7     C u0 p0 c0  {5,S} {6,S} {14,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    O u0 p2 c0  {7,D}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {4,S}
3     C u0 p0 c0  {2,S} {5,D} {12,S}
4     C u0 p0 c0  {2,S} {6,D} {13,S}
5     C u0 p0 c0  {3,D} {7,S} {14,S}
6     C u0 p0 c0  {4,D} {7,S} {15,S}
7     C u0 p0 c0  {5,S} {6,S} {11,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    O u0 p2 c0  {7,D}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.627066, 'd12': 1.210734, 'd13': 2.837081},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 135,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.254681, 'd12': 1.279753, 'd13': 2.532874},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 136,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.318814, 'd12': 1.251585, 'd13': 2.554427},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 137,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.245048, 'd12': 1.288264, 'd13': 2.531537},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 138,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {8,S} {9,S} {10,S} {11,S}
2     C u0 p0 c0  {3,B} {4,B} {8,S}
3     C u0 p0 c0  {2,B} {6,B} {12,S}
4     C u0 p0 c0  {2,B} {7,B} {13,S}
5     C u0 p0 c0  {6,B} {7,B} {14,S}
6     C u0 p0 c0  {3,B} {5,B} {15,S}
7     C u0 p0 c0  {4,B} {5,B} {16,S}
8     O u0 p2 c0  {1,S} {2,S}
9  *2 H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {7,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {5,B} {9,S}
3     C u0 p0 c0  {1,B} {6,B} {10,S}
4     C u0 p0 c0  {5,B} {6,B} {11,S}
5     C u0 p0 c0  {2,B} {4,B} {12,S}
6     C u0 p0 c0  {3,B} {4,B} {13,S}
7  *3 C u1 p0 c0  {8,S} {14,S} {15,S}
8     O u0 p2 c0  {1,S} {7,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4136, 'd12': 1.311451, 'd13': 2.724572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 139,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.286517, 'd12': 1.264185, 'd13': 2.546171},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 140,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.247176, 'd12': 1.284317, 'd13': 2.529051},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 141,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     C u0 p0 c0  {2,S} {18,S} {19,S} {20,S}
7     C u0 p0 c0  {2,S} {21,S} {22,S} {23,S}
8     C u0 p0 c0  {2,S} {24,S} {25,S} {26,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
26    H u0 p0 c0  {8,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
4     C u0 p0 c0  {1,S} {18,S} {19,S} {20,S}
5     C u0 p0 c0  {1,S} {21,S} {22,S} {23,S}
6     C u0 p0 c0  {2,S} {9,S} {10,S} {11,S}
7     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
8  *3 C u1 p0 c0  {2,S} {24,S} {25,S}
9     H u0 p0 c0  {6,S}
10    H u0 p0 c0  {6,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {7,S}
13    H u0 p0 c0  {7,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {3,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {4,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {5,S}
22    H u0 p0 c0  {5,S}
23    H u0 p0 c0  {5,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.379587, 'd12': 1.333337, 'd13': 2.706613},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 142,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     O u0 p2 c0  {2,S} {18,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18 *3 O u1 p2 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
6     O u0 p2 c0  {2,S} {7,S}
7  *1 O u0 p2 c0  {6,S} {19,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19 *2 H u0 p0 c0  {7,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.345438, 'd12': 1.094942, 'd13': 2.436127},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 143,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6     O u0 p2 c0  {2,S} {16,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16 *3 O u1 p2 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {2,S} {7,S}
6     O u0 p2 c0  {1,S} {16,S}
7  *1 O u0 p2 c0  {5,S} {17,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {6,S}
17 *2 H u0 p0 c0  {7,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.420877, 'd12': 1.060269, 'd13': 2.465326},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 144,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    O u1 p2 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {6,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {4,S} {15,S} {16,S}
6     C u0 p0 c0  {3,S} {4,S} {17,S} {18,S}
7     O u0 p2 c0  {1,S} {19,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
19 *3 O u1 p2 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {9,S}
2     C u0 p0 c0  {1,S} {4,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {5,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {6,S} {14,S} {15,S}
5     C u0 p0 c0  {3,S} {6,S} {16,S} {17,S}
6     C u0 p0 c0  {4,S} {5,S} {18,S} {19,S}
7     O u0 p2 c0  {1,S} {8,S}
8  *1 O u0 p2 c0  {7,S} {20,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20 *2 H u0 p0 c0  {8,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.405068, 'd12': 1.066347, 'd13': 2.461135},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 145,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {9,S}
2     C u0 p0 c0  {6,S} {7,S} {8,S} {10,S}
3  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {2,S} {23,S} {24,S} {25,S}
8     C u0 p0 c0  {2,S} {26,S} {27,S} {28,S}
9     O u0 p2 c0  {1,S} {10,S}
10    O u0 p2 c0  {2,S} {9,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {7,S}
25    H u0 p0 c0  {7,S}
26    H u0 p0 c0  {8,S}
27    H u0 p0 c0  {8,S}
28    H u0 p0 c0  {8,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {9,S}
2     C u0 p0 c0  {6,S} {7,S} {8,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {1,S} {23,S} {24,S} {25,S}
6     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
7     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
8  *3 C u1 p0 c0  {2,S} {26,S} {27,S}
9     O u0 p2 c0  {1,S} {10,S}
10    O u0 p2 c0  {2,S} {9,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {7,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    H u0 p0 c0  {5,S}
24    H u0 p0 c0  {5,S}
25    H u0 p0 c0  {5,S}
26    H u0 p0 c0  {8,S}
27    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.362866, 'd12': 1.339148, 'd13': 2.70112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 146,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.585963, 'd12': 1.207705, 'd13': 2.793668},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 147,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.387594, 'd12': 1.217391, 'd13': 2.604205},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 148,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {5,B} {12,S}
4     C u0 p0 c0  {2,B} {7,B} {15,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {5,B} {7,B} {13,S}
7     C u0 p0 c0  {4,B} {6,B} {14,S}
8     O u0 p2 c0  {1,S} {16,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {4,S}
16 *3 O u1 p2 c0  {8,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {8,S} {10,S} {11,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {5,B} {13,S}
4     C u0 p0 c0  {2,B} {7,B} {16,S}
5     C u0 p0 c0  {3,B} {6,B} {12,S}
6     C u0 p0 c0  {5,B} {7,B} {14,S}
7     C u0 p0 c0  {4,B} {6,B} {15,S}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {17,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.374965, 'd12': 1.076901, 'd13': 2.450556},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 149,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.301073, 'd12': 1.423371, 'd13': 2.724135},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 150,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.310432, 'd12': 0.972136, 'd13': 2.282304},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 151,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.052469, 'd12': 1.341712, 'd13': 2.29163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 152,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.544596, 'd12': 1.233914, 'd13': 2.77851},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 153,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34342, 'd12': 1.412594, 'd13': 2.737275},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 154,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33285, 'd12': 1.392257, 'd13': 2.724149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 155,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.305805, 'd12': 1.44735, 'd13': 2.751257},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 156,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.411619, 'd12': 1.287052, 'd13': 2.698415},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 157,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.496988, 'd12': 1.275252, 'd13': 2.771865},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 158,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.328593, 'd12': 1.219969, 'd13': 2.518475},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 159,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48334, 'd12': 1.086921, 'd13': 2.569676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 160,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *3 C u1 p0 c0  {2,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 0.97841, 'd12': 1.320296, 'd13': 2.298176},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 161,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.190105, 'd12': 1.355419, 'd13': 2.545508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 162,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.386526, 'd12': 1.395629, 'd13': 2.782155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 163,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.345537, 'd12': 1.41706, 'd13': 2.734548},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 164,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.357681, 'd12': 1.371076, 'd13': 2.727624},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 165,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.334129, 'd12': 1.394987, 'd13': 2.727829},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 166,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.408956, 'd12': 1.288945, 'd13': 2.697672},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 167,
    reactant1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.056332, 'd12': 1.660094, 'd13': 2.716154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 168,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.455887, 'd12': 1.307194, 'd13': 2.761316},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 169,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.418259, 'd12': 1.316115, 'd13': 2.721717},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 170,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.395046, 'd12': 1.351556, 'd13': 2.746143},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 171,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.304434, 'd12': 1.245948, 'd13': 2.550214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 172,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.476903, 'd12': 1.264341, 'd13': 2.740492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 173,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.334801, 'd12': 1.383413, 'd13': 2.718214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 174,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.176561, 'd12': 1.371259, 'd13': 2.547001},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 175,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.151769, 'd12': 1.402633, 'd13': 2.553686},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 176,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.358629, 'd12': 1.395402, 'd13': 2.751896},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 177,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.378691, 'd12': 1.352975, 'd13': 2.731071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 178,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.332454, 'd12': 1.396635, 'd13': 2.72898},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 179,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.349393, 'd12': 1.400777, 'd13': 2.748536},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 180,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.410103, 'd12': 1.295021, 'd13': 2.703918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 181,
    reactant1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.075459, 'd12': 1.603839, 'd13': 2.678774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 182,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.502489, 'd12': 1.275561, 'd13': 2.776544},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 183,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.422416, 'd12': 1.307104, 'd13': 2.729321},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 184,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.443078, 'd12': 1.291611, 'd13': 2.733904},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 185,
    reactant1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12593, 'd12': 1.494936, 'd13': 2.619254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 186,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,D} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {9,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.460727, 'd12': 1.307047, 'd13': 2.76402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 187,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.503366, 'd12': 1.274549, 'd13': 2.776775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 188,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3     C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4  *1 C u0 p0 c0  {1,S} {10,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
11 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3     C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4  *3 C u1 p0 c0  {1,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.499708, 'd12': 1.280838, 'd13': 2.777508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 189,
    reactant1 = """
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *1 C u0 p0 c0  {3,S} {10,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
11 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.490125, 'd12': 1.281734, 'd13': 2.768809},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 190,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.369307, 'd12': 1.213795, 'd13': 2.578224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 191,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.381618, 'd12': 1.303803, 'd13': 2.685418},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 192,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.339219, 'd12': 1.386573, 'd13': 2.724421},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 193,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40752, 'd12': 1.324029, 'd13': 2.729261},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 194,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {7,S} {8,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6 *2 H u0 p0 c0  {3,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.419813, 'd12': 1.341631, 'd13': 2.752365},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 195,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.409078, 'd12': 1.300082, 'd13': 2.708894},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 196,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.404289, 'd12': 1.322631, 'd13': 2.726413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 197,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.406087, 'd12': 1.314745, 'd13': 2.715634},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 198,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.481921, 'd12': 1.265173, 'd13': 2.746184},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 199,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {2,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.502992, 'd12': 1.273234, 'd13': 2.775786},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 200,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *1 C u0 p0 c0  {5,S} {13,D} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     O u0 p2 c0  {1,S} {5,S}
5  *3 C u1 p0 c0  {4,S} {13,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.411288, 'd12': 1.31096, 'd13': 2.722246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 201,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {1,S} {15,D} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,D}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.504782, 'd12': 1.277167, 'd13': 2.778712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 202,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.422491, 'd12': 1.279787, 'd13': 2.702277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 203,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.433791, 'd12': 1.331086, 'd13': 2.759466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 204,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.344864, 'd12': 1.232721, 'd13': 2.576968},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 205,
    reactant1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.189731, 'd12': 1.417057, 'd13': 2.604216},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 206,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.461026, 'd12': 1.308636, 'd13': 2.768538},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 207,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35724, 'd12': 1.3751, 'd13': 2.73016},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 208,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.339756, 'd12': 1.236844, 'd13': 2.575745},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 209,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.465935, 'd12': 1.240011, 'd13': 2.705301},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 210,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.426374, 'd12': 1.310685, 'd13': 2.73602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 211,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7  *1 C u0 p0 c0  {2,S} {12,S} {22,S} {23,S}
8     C u0 p0 c0  {2,S} {24,S} {25,S} {26,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {7,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
26    H u0 p0 c0  {8,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     C u0 p0 c0  {1,S} {18,S} {19,S} {20,S}
7     C u0 p0 c0  {2,S} {21,S} {22,S} {23,S}
8  *3 C u1 p0 c0  {2,S} {24,S} {25,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.467679, 'd12': 1.165923, 'd13': 2.632605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 212,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {2,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.440032, 'd12': 1.307357, 'd13': 2.743703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 213,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
3     C u0 p0 c0  {1,S} {4,B} {5,B}
4     C u0 p0 c0  {3,B} {7,B} {14,S}
5     C u0 p0 c0  {3,B} {8,B} {15,S}
6     C u0 p0 c0  {7,B} {8,B} {16,S}
7     C u0 p0 c0  {4,B} {6,B} {17,S}
8     C u0 p0 c0  {5,B} {6,B} {18,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {7,S}
18    H u0 p0 c0  {8,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {6,B} {11,S}
4     C u0 p0 c0  {2,B} {7,B} {12,S}
5     C u0 p0 c0  {6,B} {7,B} {13,S}
6     C u0 p0 c0  {3,B} {5,B} {14,S}
7     C u0 p0 c0  {4,B} {5,B} {15,S}
8  *3 C u1 p0 c0  {1,S} {16,S} {17,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {8,S}
17    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.155233, 'd12': 1.389889, 'd13': 2.544901},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 214,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {3,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {3,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.463798, 'd12': 1.308541, 'd13': 2.77175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 215,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {2,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.470008, 'd12': 1.299677, 'd13': 2.765791},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 216,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {1,S} {15,D} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,D}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.419633, 'd12': 1.355331, 'd13': 2.757765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 217,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.289507, 'd12': 1.256038, 'd13': 2.542827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 218,
    reactant1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.084727, 'd12': 1.599845, 'd13': 2.632605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 219,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.207728, 'd12': 1.343942, 'd13': 2.52238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 220,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.447046, 'd12': 1.268698, 'd13': 2.715651},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 221,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.157061, 'd12': 1.387852, 'd13': 2.544644},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 222,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {4,S} {10,D} {11,S}
4     O u0 p2 c0  {1,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
11 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     O u0 p2 c0  {1,S} {4,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.400219, 'd12': 1.317411, 'd13': 2.717538},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 223,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {4,S} {10,D} {11,S}
4     O u0 p2 c0  {1,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
11 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     O u0 p2 c0  {1,S} {4,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.369407, 'd12': 1.350874, 'd13': 2.720067},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 224,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *1 C u0 p0 c0  {5,S} {13,D} {14,S}
5     O u0 p2 c0  {2,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *2 H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     O u0 p2 c0  {2,S} {5,S}
5  *3 C u1 p0 c0  {4,S} {13,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.401544, 'd12': 1.316801, 'd13': 2.718293},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 225,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.368342, 'd12': 1.301866, 'd13': 2.670175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 226,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.366807, 'd12': 1.223685, 'd13': 2.589608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 227,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49714, 'd12': 1.244105, 'd13': 2.741235},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 228,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {5,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {4,D} {5,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *3 C u1 p0 c0  {3,S} {13,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.365815, 'd12': 1.22576, 'd13': 2.590913},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 229,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.475176, 'd12': 1.2474, 'd13': 2.722152},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 230,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.460601, 'd12': 1.257363, 'd13': 2.717863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 231,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4645, 'd12': 1.28515, 'd13': 2.74755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 232,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39584, 'd12': 1.15497, 'd13': 2.55035},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 233,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33923, 'd12': 1.22246, 'd13': 2.55653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 234,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4027, 'd12': 1.1524, 'd13': 2.5549},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 235,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33965, 'd12': 1.22029, 'd13': 2.55515},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 236,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14693, 'd12': 1.05778, 'd13': 2.2018},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 237,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3615, 'd12': 1.19277, 'd13': 2.55206},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 238,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36537, 'd12': 1.18793, 'd13': 2.55312},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 239,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.04802, 'd12': 1.24975, 'd13': 2.29631},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 240,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34472, 'd12': 1.20093, 'd13': 2.54466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 241,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.56172, 'd12': 1.21958, 'd13': 2.77843},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 242,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40437, 'd12': 1.29438, 'd13': 2.69639},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 243,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54692, 'd12': 1.06429, 'd13': 2.61094},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 244,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.51251, 'd12': 1.07478, 'd13': 2.58617},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 245,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49915, 'd12': 1.23899, 'd13': 2.73813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 246,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43931, 'd12': 1.29223, 'd13': 2.73106},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 247,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3563, 'd12': 1.3751, 'd13': 2.7299},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 248,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32493, 'd12': 1.23524, 'd13': 2.55853},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 249,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32662, 'd12': 1.23227, 'd13': 2.55831},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 250,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43796, 'd12': 1.16929, 'd13': 2.60307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 251,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48877, 'd12': 1.13195, 'd13': 2.61754},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 252,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36627, 'd12': 1.36997, 'd13': 2.72492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 253,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28842, 'd12': 1.2841, 'd13': 2.57085},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 254,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30648, 'd12': 1.25665, 'd13': 2.55165},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 255,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29098, 'd12': 1.28233, 'd13': 2.57282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 256,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31291, 'd12': 1.24693, 'd13': 2.55976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 257,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21398, 'd12': 1.18161, 'd13': 2.3926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 258,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14566, 'd12': 1.19861, 'd13': 2.34236},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 259,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2645, 'd12': 1.29127, 'd13': 2.55403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 260,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4317, 'd12': 1.30678, 'd13': 2.73707},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 261,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39513, 'd12': 1.32678, 'd13': 2.72178},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 262,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4003, 'd12': 1.33276, 'd13': 2.73048},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 263,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36925, 'd12': 1.35932, 'd13': 2.72635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 264,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52025, 'd12': 1.25472, 'd13': 2.77157},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 265,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42535, 'd12': 1.31715, 'd13': 2.74206},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 266,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42188, 'd12': 1.31943, 'd13': 2.74058},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 267,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39787, 'd12': 1.35642, 'd13': 2.75277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 268,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3949, 'd12': 1.30496, 'd13': 2.69921},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 269,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.54499, 'd12': 1.22688, 'd13': 2.76811},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 270,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49453, 'd12': 1.08536, 'd13': 2.57808},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 271,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34372, 'd12': 1.32515, 'd13': 2.66858},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 272,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.58064, 'd12': 1.21013, 'd13': 2.78913},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 273,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.63621, 'd12': 1.19456, 'd13': 2.8296},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 274,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30104, 'd12': 1.22872, 'd13': 2.52774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 275,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45271, 'd12': 1.2474, 'd13': 2.69994},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 276,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48384, 'd12': 1.24755, 'd13': 2.73092},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 277,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,B} {6,B} {7,S}
2     C u0 p0 c0  {1,B} {3,B} {8,S}
3     C u0 p0 c0  {2,B} {4,B} {9,S}
4     C u0 p0 c0  {3,B} {5,B} {10,S}
5     C u0 p0 c0  {4,B} {6,B} {11,S}
6     C u0 p0 c0  {1,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.7883, 'd12': 1.11822, 'd13': 2.72249},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 278,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.83906, 'd12': 1.15005, 'd13': 2.8339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 279,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33911, 'd12': 1.32731, 'd13': 2.66614},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 280,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38136, 'd12': 1.3002, 'd13': 2.68147},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 281,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4419, 'd12': 1.12041, 'd13': 2.56111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 282,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52157, 'd12': 1.24362, 'd13': 2.76374},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 283,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48582, 'd12': 1.25446, 'd13': 2.73982},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 284,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47281, 'd12': 1.28254, 'd13': 2.75245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 285,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40491, 'd12': 1.14908, 'd13': 2.55287},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 286,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40496, 'd12': 1.14979, 'd13': 2.55458},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 287,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48928, 'd12': 1.26884, 'd13': 2.757},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 288,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45564, 'd12': 1.27882, 'd13': 2.73397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 289,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41597, 'd12': 1.3076, 'd13': 2.72339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 290,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3921, 'd12': 1.33465, 'd13': 2.71635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 291,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4489, 'd12': 1.30203, 'd13': 2.7492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 292,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37297, 'd12': 1.17504, 'd13': 2.54771},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 293,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46579, 'd12': 1.28126, 'd13': 2.74613},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 294,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42727, 'd12': 1.30178, 'd13': 2.72849},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 295,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49951, 'd12': 1.2665, 'd13': 2.76595},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 296,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39121, 'd12': 1.3275, 'd13': 2.71845},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 297,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37145, 'd12': 1.30932, 'd13': 2.68013},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 298,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.51956, 'd12': 1.21389, 'd13': 2.73063},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 299,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42941, 'd12': 1.12316, 'd13': 2.51147},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 300,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.33968, 'd12': 0.9018, 'd13': 2.22722},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 301,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30467, 'd12': 1.21817, 'd13': 2.402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 302,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3887, 'd12': 1.1423, 'd13': 2.49413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 303,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43653, 'd12': 1.25393, 'd13': 2.68602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 304,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3766, 'd12': 1.26872, 'd13': 2.64367},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 305,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48049, 'd12': 1.23161, 'd13': 2.7063},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 306,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52012, 'd12': 1.21282, 'd13': 2.73203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 307,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.64989, 'd12': 1.18263, 'd13': 2.82623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 308,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36923, 'd12': 1.28719, 'd13': 2.65352},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 309,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.63906, 'd12': 1.06073, 'd13': 2.67112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 310,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33681, 'd12': 1.41201, 'd13': 2.74352},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 311,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45701, 'd12': 1.29925, 'd13': 2.75322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 312,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35579, 'd12': 1.1896, 'd13': 2.54517},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 313,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34673, 'd12': 1.19842, 'd13': 2.54512},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 314,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37871, 'd12': 1.36509, 'd13': 2.7437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 315,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39566, 'd12': 1.346, 'd13': 2.7406},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 316,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47435, 'd12': 1.2966, 'd13': 2.77043},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 317,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43306, 'd12': 1.31876, 'd13': 2.75032},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 318,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44466, 'd12': 1.3079, 'd13': 2.74542},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 319,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43245, 'd12': 1.31165, 'd13': 2.7418},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 320,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35885, 'd12': 1.1892, 'd13': 2.54765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 321,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35535, 'd12': 1.21905, 'd13': 2.57338},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 322,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38428, 'd12': 1.34325, 'd13': 2.71004},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 323,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.422, 'd12': 1.31117, 'd13': 2.72112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 324,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46414, 'd12': 1.2927, 'd13': 2.74909},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 325,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41, 'd12': 1.27717, 'd13': 2.68716},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 326,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.57265, 'd12': 1.20382, 'd13': 2.77343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 327,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.49513, 'd12': 0.841684, 'd13': 2.33681},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 328,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5254, 'd12': 1.06245, 'd13': 2.58634},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 329,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.61958, 'd12': 1.18795, 'd13': 2.80652},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 330,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5714, 'd12': 1.19841, 'd13': 2.76953},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 331,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.68593, 'd12': 1.17338, 'd13': 2.85891},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 332,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50087, 'd12': 1.22722, 'd13': 2.72783},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 333,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53278, 'd12': 1.21578, 'd13': 2.74802},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 334,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3333, 'd12': 1.32045, 'd13': 2.65337},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 335,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.60895, 'd12': 1.19765, 'd13': 2.8065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 336,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4903, 'd12': 1.2363, 'd13': 2.72627},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 337,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47875, 'd12': 1.27494, 'd13': 2.7441},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 338,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37079, 'd12': 1.3353, 'd13': 2.70413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 339,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42485, 'd12': 1.31238, 'd13': 2.73645},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 340,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24878, 'd12': 1.27581, 'd13': 2.52443},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 341,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4014, 'd12': 1.15338, 'd13': 2.55064},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 342,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42331, 'd12': 1.13681, 'd13': 2.55943},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 343,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34092, 'd12': 1.20843, 'd13': 2.54924},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 344,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30897, 'd12': 1.08962, 'd13': 2.36795},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 345,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21694, 'd12': 1.30766, 'd13': 2.52459},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 346,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36898, 'd12': 1.35935, 'd13': 2.71107},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 347,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29497, 'd12': 1.25137, 'd13': 2.54477},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 348,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39814, 'd12': 1.29288, 'd13': 2.68982},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 349,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50287, 'd12': 1.24358, 'd13': 2.74346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 350,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45635, 'd12': 1.27691, 'd13': 2.73245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 351,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40453, 'd12': 1.32704, 'd13': 2.71695},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 352,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46945, 'd12': 1.27233, 'd13': 2.74161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 353,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40813, 'd12': 1.32392, 'd13': 2.72161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 354,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54225, 'd12': 1.23897, 'd13': 2.78097},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 355,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48069, 'd12': 1.28487, 'd13': 2.7573},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 356,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44844, 'd12': 1.30369, 'd13': 2.74594},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 357,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40254, 'd12': 1.29562, 'd13': 2.69763},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 358,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34532, 'd12': 1.15905, 'd13': 2.50237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 359,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36685, 'd12': 1.34346, 'd13': 2.70935},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 360,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41397, 'd12': 1.32115, 'd13': 2.73455},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 361,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39197, 'd12': 1.32233, 'd13': 2.71424},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 362,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38667, 'd12': 1.34692, 'd13': 2.73232},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 363,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41606, 'd12': 1.27405, 'd13': 2.68801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 364,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34439, 'd12': 1.14532, 'd13': 2.48689},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 365,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3971, 'd12': 1.35146, 'd13': 2.72129},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 366,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38379, 'd12': 1.35312, 'd13': 2.70705},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 367,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42342, 'd12': 1.30486, 'd13': 2.7282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 368,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4712, 'd12': 1.289, 'd13': 2.75925},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 369,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22322, 'd12': 1.29495, 'd13': 2.51816},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 370,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28956, 'd12': 1.21428, 'd13': 2.43122},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 371,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40033, 'd12': 1.32124, 'd13': 2.72027},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 372,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41519, 'd12': 1.34611, 'd13': 2.75749},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 373,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41789, 'd12': 1.30179, 'd13': 2.71733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 374,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.479, 'd12': 1.29585, 'd13': 2.769},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 375,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40908, 'd12': 1.15072, 'd13': 2.55872},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 376,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33091, 'd12': 1.22644, 'd13': 2.5551},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 377,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3856, 'd12': 1.16802, 'd13': 2.55167},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 378,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.03208, 'd12': 1.25616, 'd13': 2.28495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 379,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26764, 'd12': 1.26362, 'd13': 2.52879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 380,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37004, 'd12': 1.34244, 'd13': 2.70934},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 381,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38854, 'd12': 1.36275, 'd13': 2.75065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 382,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.57828, 'd12': 1.22487, 'd13': 2.79964},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 383,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39692, 'd12': 1.32433, 'd13': 2.71827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 384,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40724, 'd12': 1.31046, 'd13': 2.71494},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 385,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40463, 'd12': 1.34608, 'd13': 2.74465},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 386,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48906, 'd12': 1.26802, 'd13': 2.75507},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 387,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47384, 'd12': 1.30388, 'd13': 2.77606},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 388,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44577, 'd12': 1.29455, 'd13': 2.7385},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 389,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44111, 'd12': 1.32518, 'd13': 2.76238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 390,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.56044, 'd12': 1.23357, 'd13': 2.79353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 391,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41813, 'd12': 1.29908, 'd13': 2.71518},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 392,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38731, 'd12': 1.32309, 'd13': 2.70918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 393,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48978, 'd12': 1.23122, 'd13': 2.71946},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 394,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37981, 'd12': 1.35666, 'd13': 2.67437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 395,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39732, 'd12': 1.36471, 'd13': 2.70692},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 396,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42207, 'd12': 1.29123, 'd13': 2.71297},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 397,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.48012, 'd12': 1.28849, 'd13': 2.76623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 398,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26723, 'd12': 1.26377, 'd13': 2.5295},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 399,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39807, 'd12': 1.34897, 'd13': 2.7452},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 400,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39662, 'd12': 1.2763, 'd13': 2.65627},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 401,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38898, 'd12': 1.34982, 'd13': 2.73659},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 402,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36152, 'd12': 1.37352, 'd13': 2.66839},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 403,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36122, 'd12': 1.34754, 'd13': 2.70843},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 404,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47498, 'd12': 1.27439, 'd13': 2.74156},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 405,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39255, 'd12': 1.15711, 'd13': 2.54933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 406,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48718, 'd12': 1.2659, 'd13': 2.75167},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 407,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45259, 'd12': 1.28048, 'd13': 2.73265},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 408,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52296, 'd12': 1.25105, 'd13': 2.77378},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 409,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41451, 'd12': 1.30539, 'd13': 2.71983},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 410,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36752, 'd12': 1.33988, 'd13': 2.70732},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 411,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4082, 'd12': 1.32146, 'd13': 2.72864},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 412,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25339, 'd12': 1.27052, 'd13': 2.52391},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 413,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.414, 'd12': 1.3002, 'd13': 2.71331},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 414,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23931, 'd12': 1.28855, 'd13': 2.52786},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 415,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42039, 'd12': 1.26732, 'd13': 2.68765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 416,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52273, 'd12': 1.21954, 'd13': 2.73698},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 417,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30063, 'd12': 1.24711, 'd13': 2.54774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 418,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41978, 'd12': 1.27052, 'd13': 2.69014},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 419,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46706, 'd12': 1.24287, 'd13': 2.70985},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 420,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.58035, 'd12': 1.08945, 'd13': 2.66557},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 421,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39938, 'd12': 1.34062, 'd13': 2.73493},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 422,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42796, 'd12': 1.30129, 'd13': 2.72825},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 423,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32469, 'd12': 1.23285, 'd13': 2.55648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 424,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33573, 'd12': 1.22023, 'd13': 2.55506},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 425,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31879, 'd12': 1.23278, 'd13': 2.54995},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 426,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3243, 'd12': 1.38181, 'd13': 2.70604},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 427,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38315, 'd12': 1.34882, 'd13': 2.7317},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 428,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4515, 'd12': 1.3026, 'd13': 2.75339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 429,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42422, 'd12': 1.31705, 'd13': 2.7398},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 430,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42895, 'd12': 1.30064, 'd13': 2.72899},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 431,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40298, 'd12': 1.32504, 'd13': 2.7275},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 432,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.53653, 'd12': 1.21498, 'd13': 2.7511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 433,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38226, 'd12': 1.35014, 'd13': 2.72797},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 434,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44255, 'd12': 1.28818, 'd13': 2.73006},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 435,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38556, 'd12': 1.33952, 'd13': 2.72332},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 436,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42766, 'd12': 1.30158, 'd13': 2.72917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 437,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39717, 'd12': 1.33603, 'd13': 2.73031},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 438,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37412, 'd12': 1.37843, 'd13': 2.74968},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 439,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40849, 'd12': 1.33753, 'd13': 2.7456},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 440,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34227, 'd12': 1.22081, 'd13': 2.56129},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 441,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32993, 'd12': 1.22373, 'd13': 2.55323},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 442,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.54891, 'd12': 1.23401, 'd13': 2.77926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 443,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43704, 'd12': 1.32307, 'd13': 2.75649},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 444,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4158, 'd12': 1.3449, 'd13': 2.74243},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 445,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48217, 'd12': 1.30749, 'd13': 2.7756},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 446,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40241, 'd12': 1.35799, 'd13': 2.74951},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 447,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38926, 'd12': 1.39311, 'd13': 2.78222},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 448,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42115, 'd12': 1.34637, 'd13': 2.76729},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 449,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.46021, 'd12': 1.29715, 'd13': 2.7571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 450,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40085, 'd12': 1.37034, 'd13': 2.76176},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 451,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39054, 'd12': 1.38769, 'd13': 2.77622},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 452,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44278, 'd12': 1.31025, 'd13': 2.75033},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 453,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44705, 'd12': 1.31835, 'd13': 2.76111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 454,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.56893, 'd12': 1.05815, 'd13': 2.62141},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 455,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.4952, 'd12': 0.847337, 'd13': 2.34245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 456,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.69328, 'd12': 1.17661, 'd13': 2.86926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 457,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5134, 'd12': 1.22941, 'd13': 2.74253},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 458,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35025, 'd12': 1.31336, 'd13': 2.66355},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 459,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35667, 'd12': 1.31451, 'd13': 2.67053},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 460,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37831, 'd12': 1.26578, 'd13': 2.6419},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 461,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39315, 'd12': 1.29177, 'd13': 2.68488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 462,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49798, 'd12': 1.23504, 'd13': 2.73061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 463,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.96225, 'd12': 1.30416, 'd13': 2.26271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 464,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43164, 'd12': 1.2622, 'd13': 2.69172},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 465,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37772, 'd12': 1.27591, 'd13': 2.65247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 466,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46922, 'd12': 1.29014, 'd13': 2.74358},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 467,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35535, 'd12': 1.20425, 'd13': 2.55918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 468,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16334, 'd12': 1.19113, 'd13': 2.34154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 469,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36104, 'd12': 1.18712, 'd13': 2.54519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 470,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37029, 'd12': 1.35211, 'd13': 2.7088},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 471,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35672, 'd12': 1.36975, 'd13': 2.72409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 472,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4149, 'd12': 1.33781, 'd13': 2.75114},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 473,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39891, 'd12': 1.35061, 'd13': 2.73131},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 474,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47826, 'd12': 1.26262, 'd13': 2.73345},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 475,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42803, 'd12': 1.30263, 'd13': 2.71906},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 476,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46208, 'd12': 1.29459, 'd13': 2.75378},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 477,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.57557, 'd12': 1.20557, 'd13': 2.76642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 478,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44174, 'd12': 1.30925, 'd13': 2.73402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 479,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5025, 'd12': 1.2602, 'd13': 2.75386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 480,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45939, 'd12': 1.28569, 'd13': 2.73657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 481,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41904, 'd12': 1.31667, 'd13': 2.7347},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 482,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33068, 'd12': 1.40976, 'd13': 2.73102},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 483,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40023, 'd12': 1.33999, 'd13': 2.73812},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 484,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34538, 'd12': 1.41187, 'd13': 2.73639},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 485,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53028, 'd12': 1.23017, 'd13': 2.74519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 486,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36646, 'd12': 1.34198, 'd13': 2.70608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 487,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5  *1 C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40229, 'd12': 1.15182, 'd13': 2.55364},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 488,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.921406, 'd12': 1.3722, 'd13': 2.29351},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 489,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39767, 'd12': 1.14911, 'd13': 2.5466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 490,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42436, 'd12': 1.29561, 'd13': 2.71976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 491,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3869, 'd12': 1.30613, 'd13': 2.69264},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 492,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45347, 'd12': 1.29464, 'd13': 2.72115},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 493,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52223, 'd12': 1.25033, 'd13': 2.77109},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 494,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3796, 'd12': 1.32308, 'd13': 2.70218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 495,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35925, 'd12': 1.35333, 'd13': 2.71199},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 496,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41189, 'd12': 1.27552, 'd13': 2.68619},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 497,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4111, 'd12': 1.3166, 'd13': 2.72353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 498,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36478, 'd12': 1.34131, 'd13': 2.70397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 499,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35427, 'd12': 1.35471, 'd13': 2.70828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 500,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40477, 'd12': 1.32664, 'd13': 2.72937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 501,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4558, 'd12': 1.29628, 'd13': 2.75088},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 502,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48981, 'd12': 1.27166, 'd13': 2.75918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 503,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.29083, 'd12': 1.27513, 'd13': 2.56346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 504,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26436, 'd12': 1.29226, 'd13': 2.55636},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 505,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29297, 'd12': 1.1007, 'd13': 2.36587},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 506,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28509, 'd12': 1.11254, 'd13': 2.35466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 507,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38764, 'd12': 1.22107, 'd13': 2.60764},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 508,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34824, 'd12': 1.23778, 'd13': 2.58597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 509,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31637, 'd12': 1.25494, 'd13': 2.57087},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 510,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33531, 'd12': 1.2485, 'd13': 2.57495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 511,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35139, 'd12': 1.23786, 'd13': 2.58357},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 512,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32962, 'd12': 1.2071, 'd13': 2.53574},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 513,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41998, 'd12': 1.11146, 'd13': 2.53061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 514,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47185, 'd12': 1.27947, 'd13': 2.73907},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 515,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34221, 'd12': 1.20364, 'd13': 2.54311},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 516,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35988, 'd12': 1.37476, 'd13': 2.72511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 517,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43263, 'd12': 1.32677, 'd13': 2.75306},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 518,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50195, 'd12': 1.25494, 'd13': 2.75148},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 519,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48331, 'd12': 1.2758, 'd13': 2.74918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 520,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45507, 'd12': 1.29902, 'd13': 2.7437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 521,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55469, 'd12': 1.20924, 'd13': 2.76225},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 522,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43153, 'd12': 1.31295, 'd13': 2.72826},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 523,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48449, 'd12': 1.26998, 'd13': 2.74554},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 524,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29472, 'd12': 1.26032, 'd13': 2.55282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 525,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4146, 'd12': 1.31069, 'd13': 2.71524},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 526,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46939, 'd12': 1.27873, 'd13': 2.73755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 527,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.77539, 'd12': 1.13473, 'd13': 2.8567},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 528,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33572, 'd12': 1.41477, 'd13': 2.74611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 529,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39812, 'd12': 1.34214, 'd13': 2.73691},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 530,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.32478, 'd12': 1.42925, 'd13': 2.74904},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 531,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29147, 'd12': 1.27437, 'd13': 2.56139},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 532,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3485, 'd12': 1.39534, 'd13': 2.73601},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 533,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43033, 'd12': 1.30554, 'd13': 2.73549},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 534,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32983, 'd12': 1.22888, 'd13': 2.55778},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 535,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.08399, 'd12': 1.2379, 'd13': 2.32103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 536,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30689, 'd12': 1.24721, 'd13': 2.55389},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 537,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35236, 'd12': 1.3836, 'd13': 2.73459},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 538,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38536, 'd12': 1.34647, 'd13': 2.73158},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 539,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45021, 'd12': 1.30834, 'd13': 2.75849},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 540,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42413, 'd12': 1.32471, 'd13': 2.74816},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 541,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.46516, 'd12': 1.27571, 'd13': 2.74009},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 542,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43311, 'd12': 1.30286, 'd13': 2.73532},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 543,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40728, 'd12': 1.32641, 'd13': 2.73254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 544,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38674, 'd12': 1.35192, 'd13': 2.73439},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 545,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3836, 'd12': 1.38216, 'd13': 2.76484},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 546,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38984, 'd12': 1.33976, 'd13': 2.72832},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 547,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43083, 'd12': 1.30418, 'd13': 2.73393},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 548,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4021, 'd12': 1.33664, 'd13': 2.7349},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 549,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.385, 'd12': 1.37374, 'd13': 2.7572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 550,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37265, 'd12': 1.36752, 'd13': 2.73991},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 551,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37093, 'd12': 1.37954, 'd13': 2.74137},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 552,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34254, 'd12': 1.39866, 'd13': 2.7296},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 553,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34438, 'd12': 1.40445, 'd13': 2.74589},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 554,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.28163, 'd12': 1.28076, 'd13': 2.5505},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 555,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31178, 'd12': 1.09719, 'd13': 2.37274},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 556,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28376, 'd12': 1.28153, 'd13': 2.55387},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 557,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.0033, 'd12': 1.12951, 'd13': 2.13189},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 558,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40386, 'd12': 1.21533, 'd13': 2.61884},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 559,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34264, 'd12': 1.2428, 'd13': 2.5851},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 560,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43921, 'd12': 1.20346, 'd13': 2.64238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 561,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26042, 'd12': 1.28937, 'd13': 2.5497},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 562,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32826, 'd12': 1.25352, 'd13': 2.57242},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 563,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.238, 'd12': 1.30885, 'd13': 2.54504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 564,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18494, 'd12': 1.17814, 'd13': 2.36175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 565,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47701, 'd12': 1.27934, 'd13': 2.74805},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 566,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35259, 'd12': 1.35903, 'd13': 2.71095},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 567,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42318, 'd12': 1.15057, 'd13': 2.54778},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 568,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41715, 'd12': 1.14131, 'd13': 2.55597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 569,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.910509, 'd12': 1.3793, 'd13': 2.28925},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 570,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4607, 'd12': 1.27318, 'd13': 2.73105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 571,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.51782, 'd12': 1.2605, 'd13': 2.77411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 572,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39691, 'd12': 1.29783, 'd13': 2.69417},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 573,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37792, 'd12': 1.32647, 'd13': 2.70384},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 574,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34141, 'd12': 1.37365, 'd13': 2.71447},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 575,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39253, 'd12': 1.32584, 'd13': 2.71732},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 576,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38888, 'd12': 1.29189, 'd13': 2.68057},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 577,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42442, 'd12': 1.30392, 'd13': 2.72808},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 578,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35499, 'd12': 1.35632, 'd13': 2.71012},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 579,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35529, 'd12': 1.35404, 'd13': 2.70845},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 580,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41284, 'd12': 1.31902, 'd13': 2.72837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 581,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.80797, 'd12': 1.12563, 'd13': 2.93169},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 582,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.46532, 'd12': 1.28402, 'd13': 2.74078},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 583,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44306, 'd12': 1.29554, 'd13': 2.73801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 584,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42229, 'd12': 1.27441, 'd13': 2.69495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 585,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47934, 'd12': 1.28634, 'd13': 2.75686},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 586,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35438, 'd12': 1.36092, 'd13': 2.71277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 587,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47355, 'd12': 1.27934, 'd13': 2.74281},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 588,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.6743, 'd12': 1.05367, 'd13': 2.72623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 589,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39801, 'd12': 1.31595, 'd13': 2.71349},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 590,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39545, 'd12': 1.15796, 'd13': 2.55229},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 591,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41087, 'd12': 1.14781, 'd13': 2.55822},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 592,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26019, 'd12': 1.26963, 'd13': 2.52793},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 593,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37445, 'd12': 1.16774, 'd13': 2.54032},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 594,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3788, 'd12': 1.33357, 'd13': 2.71049},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 595,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35261, 'd12': 1.33585, 'd13': 2.6873},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 596,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48044, 'd12': 1.24559, 'd13': 2.72562},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 597,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41607, 'd12': 1.30695, 'd13': 2.71966},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 598,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49624, 'd12': 1.26559, 'd13': 2.75825},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 599,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45861, 'd12': 1.28538, 'd13': 2.73933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 600,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40471, 'd12': 1.31233, 'd13': 2.71539},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 601,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37628, 'd12': 1.33535, 'd13': 2.70978},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 602,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47669, 'd12': 1.23622, 'd13': 2.71203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 603,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37275, 'd12': 1.35078, 'd13': 2.72312},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 604,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25158, 'd12': 1.27612, 'd13': 2.52572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 605,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41505, 'd12': 1.33375, 'd13': 2.74714},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 606,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36551, 'd12': 1.33936, 'd13': 2.70022},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 607,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40034, 'd12': 1.31203, 'd13': 2.71041},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 608,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37705, 'd12': 1.35631, 'd13': 2.67091},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 609,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40264, 'd12': 1.33704, 'd13': 2.73802},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 610,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39548, 'd12': 1.33057, 'd13': 2.72411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 611,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39897, 'd12': 1.3433, 'd13': 2.73757},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 612,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41243, 'd12': 1.31145, 'd13': 2.71838},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 613,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.40216, 'd12': 1.32878, 'd13': 2.72965},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 614,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16 *2 H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40151, 'd12': 1.30846, 'd13': 2.7039},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 615,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39056, 'd12': 1.33902, 'd13': 2.72877},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 616,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55829, 'd12': 1.2336, 'd13': 2.78933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 617,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43053, 'd12': 1.31833, 'd13': 2.74624},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 618,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39071, 'd12': 1.34026, 'd13': 2.72923},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 619,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43153, 'd12': 1.33284, 'd13': 2.76379},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 620,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52683, 'd12': 1.25229, 'd13': 2.77633},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 621,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.63851, 'd12': 1.19012, 'd13': 2.81856},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 622,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4198, 'd12': 1.3148, 'd13': 2.73394},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 623,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.56451, 'd12': 1.22131, 'd13': 2.77962},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 624,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42476, 'd12': 1.31788, 'd13': 2.74138},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 625,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38353, 'd12': 1.35278, 'd13': 2.7341},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 626,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33456, 'd12': 1.1579, 'd13': 2.48586},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 627,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.62473, 'd12': 1.19982, 'd13': 2.82455},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 628,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.68226, 'd12': 1.18206, 'd13': 2.86093},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 629,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.64434, 'd12': 1.19329, 'd13': 2.83353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 630,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45582, 'd12': 1.30115, 'd13': 2.75626},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 631,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.938574, 'd12': 1.33739, 'd13': 2.27402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 632,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24166, 'd12': 1.27685, 'd13': 2.51712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 633,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25839, 'd12': 1.24308, 'd13': 2.48813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 634,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45274, 'd12': 1.16062, 'd13': 2.6078},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 635,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46236, 'd12': 1.24532, 'd13': 2.70694},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 636,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3339, 'd12': 1.33122, 'd13': 2.66472},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 637,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36664, 'd12': 1.31227, 'd13': 2.67788},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 638,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36495, 'd12': 1.37166, 'd13': 2.73596},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 639,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39799, 'd12': 1.32921, 'd13': 2.72657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 640,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38932, 'd12': 1.34874, 'd13': 2.73597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 641,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42214, 'd12': 1.32196, 'd13': 2.74268},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 642,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39391, 'd12': 1.35009, 'd13': 2.74355},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 643,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3301, 'd12': 1.35718, 'd13': 2.68643},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 644,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37501, 'd12': 1.30102, 'd13': 2.6748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 645,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55167, 'd12': 1.21385, 'd13': 2.76503},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 646,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34532, 'd12': 1.33257, 'd13': 2.67783},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 647,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48521, 'd12': 1.26531, 'd13': 2.75003},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 648,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45393, 'd12': 1.28762, 'd13': 2.74141},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 649,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50055, 'd12': 1.26829, 'd13': 2.76673},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 650,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54964, 'd12': 1.21237, 'd13': 2.75163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 651,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.65468, 'd12': 1.18264, 'd13': 2.83635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 652,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42942, 'd12': 1.32565, 'd13': 2.75428},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 653,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4531, 'd12': 1.30877, 'd13': 2.74512},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 654,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46011, 'd12': 1.28864, 'd13': 2.73855},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 655,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49449, 'd12': 1.27264, 'd13': 2.75511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 656,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.58313, 'd12': 1.19972, 'd13': 2.78194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 657,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43997, 'd12': 1.30282, 'd13': 2.73277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 658,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4795, 'd12': 1.28272, 'd13': 2.75164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 659,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43039, 'd12': 1.30123, 'd13': 2.73035},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 660,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43536, 'd12': 1.32843, 'd13': 2.76096},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 661,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47983, 'd12': 1.27778, 'd13': 2.75507},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 662,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47368, 'd12': 1.3084, 'd13': 2.77214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 663,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.5883, 'd12': 1.21968, 'd13': 2.8075},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 664,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42469, 'd12': 1.27489, 'd13': 2.69939},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 665,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48246, 'd12': 1.26714, 'd13': 2.74948},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 666,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52354, 'd12': 1.25239, 'd13': 2.77492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 667,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,D}
2 *3 C u1 p0 c0  {1,D} {4,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37308, 'd12': 1.26933, 'd13': 2.64103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 668,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.65247, 'd12': 1.14252, 'd13': 2.71127},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 669,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43687, 'd12': 1.33014, 'd13': 2.76348},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 670,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48044, 'd12': 1.30449, 'd13': 2.76837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 671,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42417, 'd12': 1.27083, 'd13': 2.68999},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 672,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47417, 'd12': 1.26481, 'd13': 2.73568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 673,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37348, 'd12': 1.35254, 'd13': 2.72445},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 674,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38442, 'd12': 1.35019, 'd13': 2.72837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 675,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.45333, 'd12': 1.28498, 'd13': 2.73508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 676,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40834, 'd12': 1.32455, 'd13': 2.73224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 677,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45036, 'd12': 1.30722, 'd13': 2.75734},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 678,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.09787, 'd12': 1.22263, 'd13': 2.3173},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 679,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34569, 'd12': 1.22285, 'd13': 2.56657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 680,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33965, 'd12': 1.20714, 'd13': 2.54547},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 681,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35056, 'd12': 1.37122, 'd13': 2.71768},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 682,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.53019, 'd12': 1.22818, 'd13': 2.75642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 683,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38535, 'd12': 1.34688, 'd13': 2.73181},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 684,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46219, 'd12': 1.3, 'd13': 2.75883},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 685,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42291, 'd12': 1.31956, 'd13': 2.73315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 686,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.51629, 'd12': 1.23452, 'd13': 2.74519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 687,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34229, 'd12': 1.3954, 'd13': 2.71348},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 688,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44589, 'd12': 1.29322, 'd13': 2.73652},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 689,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36905, 'd12': 1.37997, 'd13': 2.74857},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 690,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33674, 'd12': 1.37771, 'd13': 2.70833},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 691,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44228, 'd12': 1.28936, 'd13': 2.72558},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 692,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32826, 'd12': 1.41012, 'd13': 2.71484},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 693,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36152, 'd12': 1.37952, 'd13': 2.73696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 694,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3631, 'd12': 1.36627, 'd13': 2.72149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 695,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35841, 'd12': 1.3851, 'd13': 2.74085},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 696,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37815, 'd12': 1.35184, 'd13': 2.72755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 697,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37677, 'd12': 1.36832, 'd13': 2.74479},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 698,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47362, 'd12': 1.2757, 'd13': 2.74741},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 699,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37881, 'd12': 1.34989, 'd13': 2.72856},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 700,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41594, 'd12': 1.32895, 'd13': 2.74279},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 701,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47976, 'd12': 1.1401, 'd13': 2.61975},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 702,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41226, 'd12': 1.3281, 'd13': 2.74016},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 703,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38785, 'd12': 1.34321, 'd13': 2.73002},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 704,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54588, 'd12': 1.22344, 'd13': 2.76789},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 705,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44116, 'd12': 1.29743, 'd13': 2.73813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 706,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.57381, 'd12': 1.20128, 'd13': 2.77437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 707,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42495, 'd12': 1.31622, 'd13': 2.72863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 708,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47255, 'd12': 1.27438, 'd13': 2.74499},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 709,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41542, 'd12': 1.34491, 'd13': 2.75676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 710,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41, 'd12': 1.31199, 'd13': 2.72163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 711,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46518, 'd12': 1.27818, 'd13': 2.74276},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 712,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53617, 'd12': 1.21017, 'd13': 2.73795},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 713,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43405, 'd12': 1.30864, 'd13': 2.74148},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 714,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41458, 'd12': 1.33631, 'd13': 2.74877},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 715,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39173, 'd12': 1.34695, 'd13': 2.72477},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 716,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39359, 'd12': 1.33938, 'd13': 2.73186},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 717,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38488, 'd12': 1.34986, 'd13': 2.73332},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 718,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37426, 'd12': 1.36738, 'd13': 2.73994},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 719,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40708, 'd12': 1.34165, 'd13': 2.74711},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 720,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1583, 'd12': 1.19936, 'd13': 2.3568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 721,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46014, 'd12': 1.16881, 'd13': 2.62033},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 722,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3832, 'd12': 1.34265, 'd13': 2.72522},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 723,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40851, 'd12': 1.34314, 'd13': 2.74987},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 724,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38091, 'd12': 1.35944, 'd13': 2.73876},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 725,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49674, 'd12': 1.25939, 'd13': 2.75602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 726,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47253, 'd12': 1.27651, 'd13': 2.74872},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 727,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.58885, 'd12': 1.19739, 'd13': 2.7861},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 728,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45602, 'd12': 1.29448, 'd13': 2.74229},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 729,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44267, 'd12': 1.31816, 'd13': 2.76081},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 730,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42671, 'd12': 1.29719, 'd13': 2.7219},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 731,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49379, 'd12': 1.26058, 'd13': 2.75431},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 732,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49329, 'd12': 1.23182, 'd13': 2.71344},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 733,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44529, 'd12': 1.30777, 'd13': 2.75095},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 734,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42553, 'd12': 1.32022, 'd13': 2.74571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 735,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4458, 'd12': 1.30869, 'd13': 2.7522},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 736,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5832, 'd12': 1.20768, 'd13': 2.79038},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 737,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40881, 'd12': 1.32625, 'd13': 2.72158},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 738,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37804, 'd12': 1.35127, 'd13': 2.72771},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 739,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28313, 'd12': 1.40395, 'd13': 2.68703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 740,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.09066, 'd12': 1.45849, 'd13': 2.54912},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 741,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31078, 'd12': 1.35429, 'd13': 2.66504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 742,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.59454, 'd12': 1.19668, 'd13': 2.79109},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 743,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.71185, 'd12': 1.17201, 'd13': 2.8827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 744,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30259, 'd12': 1.36499, 'd13': 2.6671},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 745,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13164, 'd12': 1.37251, 'd13': 2.50155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 746,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45747, 'd12': 1.244, 'd13': 2.69917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 747,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39639, 'd12': 1.30103, 'd13': 2.69685},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 748,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.993558, 'd12': 1.27988, 'd13': 2.27252},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 749,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40786, 'd12': 1.2888, 'd13': 2.69653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 750,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44418, 'd12': 1.2564, 'd13': 2.69996},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 751,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44711, 'd12': 1.25328, 'd13': 2.69988},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 752,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45798, 'd12': 1.24408, 'd13': 2.70165},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 753,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42601, 'd12': 1.27421, 'd13': 2.7002},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 754,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45919, 'd12': 1.24702, 'd13': 2.70571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 755,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31732, 'd12': 1.38604, 'd13': 2.69931},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 756,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49221, 'd12': 1.25943, 'd13': 2.7509},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 757,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40293, 'd12': 1.26416, 'd13': 2.65444},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 758,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34821, 'd12': 1.35775, 'd13': 2.70535},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 759,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38929, 'd12': 1.31063, 'd13': 2.69985},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 760,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33055, 'd12': 1.37758, 'd13': 2.70743},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 761,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26546, 'd12': 1.25435, 'd13': 2.51716},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 762,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34315, 'd12': 1.35687, 'd13': 2.69805},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 763,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37733, 'd12': 1.31841, 'd13': 2.69501},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 764,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38053, 'd12': 1.31605, 'd13': 2.69658},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 765,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35326, 'd12': 1.3439, 'd13': 2.69708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 766,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29652, 'd12': 1.23374, 'd13': 2.52852},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 767,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37696, 'd12': 1.32895, 'd13': 2.7057},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 768,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36424, 'd12': 1.34382, 'd13': 2.70745},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 769,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47969, 'd12': 1.26789, 'd13': 2.74621},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 770,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.926756, 'd12': 1.36623, 'd13': 2.2926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 771,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23386, 'd12': 1.29495, 'd13': 2.52865},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 772,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42189, 'd12': 1.30243, 'd13': 2.72373},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 773,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49721, 'd12': 1.25946, 'd13': 2.75537},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 774,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40659, 'd12': 1.29398, 'd13': 2.69995},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 775,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35792, 'd12': 1.3534, 'd13': 2.71103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 776,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38349, 'd12': 1.33201, 'd13': 2.7155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 777,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41402, 'd12': 1.27402, 'd13': 2.68794},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 778,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41319, 'd12': 1.31625, 'd13': 2.72846},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 779,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35807, 'd12': 1.35094, 'd13': 2.70887},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 780,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23729, 'd12': 1.28748, 'd13': 2.52401},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 781,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.46329, 'd12': 1.30047, 'd13': 2.7611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 782,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42317, 'd12': 1.2979, 'd13': 2.71892},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 783,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35622, 'd12': 1.35088, 'd13': 2.7071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 784,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39935, 'd12': 1.33252, 'd13': 2.73164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 785,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.45348, 'd12': 1.3046, 'd13': 2.75733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 786,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44973, 'd12': 1.30712, 'd13': 2.7546},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 787,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4461, 'd12': 1.28708, 'd13': 2.72767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 788,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {6,S}
2     C u0 p0 c0  {1,D} {4,S} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49832, 'd12': 1.25759, 'd13': 2.75592},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 789,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5257, 'd12': 1.25576, 'd13': 2.77724},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 790,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23463, 'd12': 1.29432, 'd13': 2.52885},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 791,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38587, 'd12': 1.1615, 'd13': 2.54729},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 792,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41923, 'd12': 1.30521, 'd13': 2.72297},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 793,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4174, 'd12': 1.27548, 'd13': 2.69251},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 794,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42051, 'd12': 1.32601, 'd13': 2.74369},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 795,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3595, 'd12': 1.35413, 'd13': 2.71337},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 796,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43256, 'd12': 1.30072, 'd13': 2.73271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 797,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.45014, 'd12': 1.30679, 'd13': 2.75289},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 798,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46886, 'd12': 1.28517, 'd13': 2.75105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 799,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49678, 'd12': 1.26722, 'd13': 2.76292},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 800,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35855, 'd12': 1.35801, 'd13': 2.7152},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 801,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.51912, 'd12': 1.25745, 'd13': 2.77579},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 802,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42412, 'd12': 1.33344, 'd13': 2.75006},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 803,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29437, 'd12': 1.16491, 'd13': 2.45731},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 804,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5683, 'd12': 1.22743, 'd13': 2.79411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 805,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43573, 'd12': 1.30955, 'd13': 2.74302},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 806,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44545, 'd12': 1.29959, 'd13': 2.74492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 807,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.65036, 'd12': 1.19014, 'd13': 2.83937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 808,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4487, 'd12': 1.30837, 'd13': 2.75615},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 809,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40025, 'd12': 1.3444, 'd13': 2.74258},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 810,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.572, 'd12': 1.21079, 'd13': 2.77974},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 811,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41199, 'd12': 1.3373, 'd13': 2.74696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 812,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37461, 'd12': 1.38683, 'd13': 2.75922},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 813,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46134, 'd12': 1.29848, 'd13': 2.75655},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 814,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39095, 'd12': 1.35407, 'd13': 2.74434},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 815,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43373, 'd12': 1.31634, 'd13': 2.74932},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 816,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37966, 'd12': 1.37369, 'd13': 2.75246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 817,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47327, 'd12': 1.30134, 'd13': 2.77381},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 818,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49647, 'd12': 1.27698, 'd13': 2.75717},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 819,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53082, 'd12': 1.24619, 'd13': 2.77574},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 820,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49826, 'd12': 1.27446, 'd13': 2.75642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 821,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47303, 'd12': 1.30735, 'd13': 2.77879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 822,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53763, 'd12': 1.24397, 'd13': 2.78084},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 823,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.51361, 'd12': 1.25993, 'd13': 2.77239},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 824,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *1 C u0 p0 c0  {1,S} {7,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
8 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4887, 'd12': 1.30388, 'd13': 2.78598},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 825,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50851, 'd12': 1.26541, 'd13': 2.77315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 826,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4202, 'd12': 1.32484, 'd13': 2.74183},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 827,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.67468, 'd12': 1.17671, 'd13': 2.85052},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 828,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22543, 'd12': 1.1559, 'd13': 2.36582},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 829,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24735, 'd12': 1.28401, 'd13': 2.53128},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 830,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5875, 'd12': 1.08573, 'd13': 2.67185},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 831,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38265, 'd12': 1.30965, 'd13': 2.69203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 832,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.00142, 'd12': 1.26778, 'd13': 2.26801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 833,
    reactant1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46987, 'd12': 1.15696, 'd13': 2.59782},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 834,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53058, 'd12': 1.22707, 'd13': 2.75727},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 835,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48625, 'd12': 1.27245, 'd13': 2.75463},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 836,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45052, 'd12': 1.28405, 'd13': 2.73061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 837,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.60197, 'd12': 1.20219, 'd13': 2.80371},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 838,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {1,S} {5,D} {11,S}
5     C u0 p0 c0  {2,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42178, 'd12': 1.18521, 'd13': 2.60601},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 839,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32771, 'd12': 1.15706, 'd13': 2.48383},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 840,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4604, 'd12': 1.29114, 'd13': 2.75123},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 841,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.65773, 'd12': 1.18904, 'd13': 2.84603},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 842,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53929, 'd12': 1.22061, 'd13': 2.75918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 843,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48479, 'd12': 1.0915, 'd13': 2.57607},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 844,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.72931, 'd12': 1.12752, 'd13': 2.66883},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 845,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37094, 'd12': 1.32675, 'd13': 2.6976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 846,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.51676, 'd12': 1.2452, 'd13': 2.75708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 847,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.79222, 'd12': 1.12191, 'd13': 2.65523},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 848,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4224, 'd12': 1.28273, 'd13': 2.70479},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 849,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36795, 'd12': 1.17993, 'd13': 2.54543},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 850,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35995, 'd12': 1.3313, 'd13': 2.69093},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 851,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33706, 'd12': 1.33046, 'd13': 2.66667},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 852,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41514, 'd12': 1.28617, 'd13': 2.70116},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 853,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38324, 'd12': 1.32098, 'd13': 2.70403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 854,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45037, 'd12': 1.26522, 'd13': 2.71552},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 855,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41412, 'd12': 1.29804, 'd13': 2.71189},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 856,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35366, 'd12': 1.29897, 'd13': 2.64496},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 857,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41716, 'd12': 1.12972, 'd13': 2.51447},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 858,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35844, 'd12': 1.28289, 'd13': 2.63999},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 859,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.31627, 'd12': 1.32618, 'd13': 2.64064},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 860,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31892, 'd12': 1.32623, 'd13': 2.64402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 861,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43283, 'd12': 1.24345, 'd13': 2.67525},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 862,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.56345, 'd12': 1.22546, 'd13': 2.7866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 863,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54377, 'd12': 1.23682, 'd13': 2.77828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 864,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4927, 'd12': 1.26535, 'd13': 2.75791},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 865,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33245, 'd12': 1.21514, 'd13': 2.54606},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 866,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35426, 'd12': 1.34529, 'd13': 2.69875},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 867,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47659, 'd12': 1.25621, 'd13': 2.73086},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 868,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49717, 'd12': 1.27145, 'd13': 2.76302},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 869,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46158, 'd12': 1.26902, 'd13': 2.73047},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 870,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42674, 'd12': 1.29394, 'd13': 2.72065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 871,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46487, 'd12': 1.09182, 'd13': 2.5481},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 872,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    product1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18587, 'd12': 1.33568, 'd13': 2.52149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 873,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42911, 'd12': 1.29098, 'd13': 2.71933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 874,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33666, 'd12': 1.3641, 'd13': 2.69967},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 875,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41708, 'd12': 1.28632, 'd13': 2.70146},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 876,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48022, 'd12': 1.18185, 'd13': 2.66056},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 877,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50386, 'd12': 1.25312, 'd13': 2.75683},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 878,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43173, 'd12': 1.1942, 'd13': 2.62521},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 879,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39507, 'd12': 1.29547, 'd13': 2.69026},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 880,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37522, 'd12': 1.32627, 'd13': 2.70138},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 881,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44678, 'd12': 1.28386, 'd13': 2.72891},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 882,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25466, 'd12': 1.27217, 'd13': 2.52674},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 883,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53531, 'd12': 1.21686, 'd13': 2.75166},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 884,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35358, 'd12': 1.2165, 'd13': 2.56758},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 885,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.86601, 'd12': 1.12382, 'd13': 2.89113},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 886,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33836, 'd12': 1.30835, 'd13': 2.64307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 887,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36094, 'd12': 1.21025, 'd13': 2.56111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 888,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49686, 'd12': 1.23884, 'd13': 2.73408},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 889,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48766, 'd12': 1.2431, 'd13': 2.72937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 890,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.5563, 'd12': 1.23064, 'd13': 2.78107},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 891,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44761, 'd12': 1.27151, 'd13': 2.71754},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 892,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.49971, 'd12': 1.26893, 'd13': 2.76194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 893,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.64033, 'd12': 1.19361, 'd13': 2.83392},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 894,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39101, 'd12': 1.20242, 'd13': 2.58403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 895,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39758, 'd12': 1.15369, 'd13': 2.54972},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 896,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3853, 'd12': 1.30683, 'd13': 2.69212},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 897,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41379, 'd12': 1.29015, 'd13': 2.70311},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 898,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38284, 'd12': 1.31804, 'd13': 2.70071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 899,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45318, 'd12': 1.24105, 'd13': 2.692},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 900,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.52223, 'd12': 1.23188, 'd13': 2.75409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 901,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38761, 'd12': 1.34035, 'd13': 2.72788},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 902,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.46629, 'd12': 1.26781, 'd13': 2.73399},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 903,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.45301, 'd12': 1.31364, 'd13': 2.76177},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 904,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34513, 'd12': 1.20595, 'd13': 2.54997},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 905,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.49206, 'd12': 1.27711, 'd13': 2.76775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 906,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.54507, 'd12': 1.21198, 'd13': 2.75442},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 907,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47813, 'd12': 1.28193, 'd13': 2.75993},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 908,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36211, 'd12': 1.21217, 'd13': 2.56789},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 909,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39042, 'd12': 1.35742, 'd13': 2.7428},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 910,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37688, 'd12': 1.36987, 'd13': 2.73991},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 911,
    reactant1 = """
1  *1 C u0 p0 c0  {2,B} {6,B} {7,S}
2     C u0 p0 c0  {1,B} {3,B} {8,S}
3     C u0 p0 c0  {2,B} {4,B} {9,S}
4     C u0 p0 c0  {3,B} {5,B} {10,S}
5     C u0 p0 c0  {4,B} {6,B} {11,S}
6     C u0 p0 c0  {1,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34704, 'd12': 1.32198, 'd13': 2.6677},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 912,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4813, 'd12': 1.2289, 'd13': 2.70983},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 913,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.70846, 'd12': 1.12859, 'd13': 2.74322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 914,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39585, 'd12': 1.28764, 'd13': 2.68333},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 915,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41172, 'd12': 1.28125, 'd13': 2.69194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 916,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53913, 'd12': 1.22567, 'd13': 2.76389},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 917,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36473, 'd12': 1.13839, 'd13': 2.50034},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 918,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43887, 'd12': 1.26632, 'd13': 2.70515},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 919,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43385, 'd12': 1.27046, 'd13': 2.70411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 920,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47801, 'd12': 1.24552, 'd13': 2.7234},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 921,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.59187, 'd12': 1.2215, 'd13': 2.8131},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 922,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43098, 'd12': 1.12535, 'd13': 2.55318},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 923,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37621, 'd12': 1.1581, 'd13': 2.53151},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 924,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48379, 'd12': 1.26066, 'd13': 2.74142},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 925,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38552, 'd12': 1.30237, 'd13': 2.68616},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 926,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42677, 'd12': 1.28737, 'd13': 2.71361},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 927,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4222, 'd12': 1.30625, 'd13': 2.72456},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 928,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3765, 'd12': 1.33066, 'd13': 2.70328},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 929,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39558, 'd12': 1.31601, 'd13': 2.70759},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 930,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38142, 'd12': 1.31545, 'd13': 2.69481},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 931,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43382, 'd12': 1.30367, 'd13': 2.73291},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 932,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33802, 'd12': 1.35462, 'd13': 2.69224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 933,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33876, 'd12': 1.35704, 'd13': 2.69559},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 934,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42516, 'd12': 1.31417, 'd13': 2.72543},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 935,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.50467, 'd12': 1.12519, 'd13': 2.62453},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 936,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37359, 'd12': 1.36073, 'd13': 2.73351},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 937,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36702, 'd12': 1.37353, 'd13': 2.71876},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 938,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.51826, 'd12': 1.24721, 'd13': 2.75697},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 939,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34739, 'd12': 1.406, 'd13': 2.74051},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 940,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5  *1 C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42516, 'd12': 1.13658, 'd13': 2.56162},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 941,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42748, 'd12': 1.27413, 'd13': 2.70104},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 942,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41317, 'd12': 1.28498, 'd13': 2.69712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 943,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41592, 'd12': 1.30128, 'd13': 2.71276},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 944,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35743, 'd12': 1.29811, 'd13': 2.65071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 945,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.78373, 'd12': 1.13119, 'd13': 2.9029},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 946,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34239, 'd12': 1.35655, 'd13': 2.69841},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 947,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.426, 'd12': 1.047, 'd13': 2.46431},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 948,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21926, 'd12': 1.31974, 'd13': 2.53718},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 949,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33507, 'd12': 1.22954, 'd13': 2.55965},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 950,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14168, 'd12': 1.201, 'd13': 2.33315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 951,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48503, 'd12': 1.27456, 'd13': 2.75364},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 952,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.5294, 'd12': 1.2322, 'd13': 2.76137},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 953,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.51006, 'd12': 1.24601, 'd13': 2.75369},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 954,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.47196, 'd12': 1.2678, 'd13': 2.73917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 955,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.52761, 'd12': 1.21697, 'd13': 2.74458},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 956,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42649, 'd12': 1.29778, 'd13': 2.72359},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 957,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19 *2 H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.43127, 'd12': 1.30243, 'd13': 2.7335},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 958,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30797, 'd12': 1.09292, 'd13': 2.39488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 959,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30727, 'd12': 1.26208, 'd13': 2.56878},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 960,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21147, 'd12': 1.32782, 'd13': 2.53922},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 961,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42322, 'd12': 1.13212, 'd13': 2.55226},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 962,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38481, 'd12': 1.30936, 'd13': 2.69386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 963,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37629, 'd12': 1.32357, 'd13': 2.69097},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 964,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22741, 'd12': 1.29227, 'd13': 2.51669},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 965,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40912, 'd12': 1.3074, 'd13': 2.71202},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 966,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4532, 'd12': 1.30752, 'd13': 2.75513},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 967,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33803, 'd12': 1.3602, 'd13': 2.69039},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 968,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41337, 'd12': 1.31358, 'd13': 2.72653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 969,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47067, 'd12': 1.25015, 'd13': 2.71963},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 970,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43247, 'd12': 1.2812, 'd13': 2.71309},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 971,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37031, 'd12': 1.32384, 'd13': 2.69218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 972,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49471, 'd12': 1.25021, 'd13': 2.74397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 973,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55342, 'd12': 1.22607, 'd13': 2.77343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 974,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52066, 'd12': 1.24041, 'd13': 2.75987},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 975,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {3,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42279, 'd12': 1.29538, 'd13': 2.71676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 976,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.47334, 'd12': 1.26087, 'd13': 2.73346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 977,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.63093, 'd12': 1.19704, 'd13': 2.82794},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 978,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.58837, 'd12': 1.07699, 'd13': 2.6653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 979,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49669, 'd12': 1.23799, 'd13': 2.73421},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 980,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43274, 'd12': 1.26573, 'd13': 2.69676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 981,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37374, 'd12': 1.38238, 'd13': 2.75374},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 982,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35913, 'd12': 1.31774, 'd13': 2.67585},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 983,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34511, 'd12': 1.32106, 'd13': 2.66523},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 984,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37942, 'd12': 1.30511, 'd13': 2.68166},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 985,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4219, 'd12': 1.28718, 'd13': 2.70752},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 986,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45871, 'd12': 1.26654, 'd13': 2.7231},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 987,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43026, 'd12': 1.28847, 'd13': 2.71439},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 988,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37582, 'd12': 1.27626, 'd13': 2.64959},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 989,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40568, 'd12': 1.26907, 'd13': 2.67434},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 990,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.68236, 'd12': 1.17658, 'd13': 2.85612},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 991,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49838, 'd12': 1.25545, 'd13': 2.75326},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 992,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32114, 'd12': 1.38015, 'd13': 2.69514},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 993,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1909, 'd12': 1.31553, 'd13': 2.50386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 994,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41993, 'd12': 1.28291, 'd13': 2.69996},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 995,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.49378, 'd12': 1.23851, 'd13': 2.73076},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 996,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.55197, 'd12': 1.22812, 'd13': 2.77525},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 997,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.54694, 'd12': 1.23552, 'd13': 2.76807},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 998,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33999, 'd12': 1.32066, 'd13': 2.66062},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 999,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.49396, 'd12': 1.25283, 'd13': 2.74416},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1000,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.44743, 'd12': 1.29268, 'd13': 2.73467},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1001,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.42146, 'd12': 1.31164, 'd13': 2.73115},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1002,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.54131, 'd12': 1.21361, 'd13': 2.75322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1003,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.45527, 'd12': 1.24306, 'd13': 2.69156},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1004,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.76763, 'd12': 1.13328, 'd13': 2.84773},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1005,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.53645, 'd12': 1.22354, 'd13': 2.75765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1006,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41335, 'd12': 1.30072, 'd13': 2.70863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1007,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40433, 'd12': 1.32419, 'd13': 2.7274},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1008,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55929, 'd12': 1.21738, 'd13': 2.77648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1009,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3727, 'd12': 1.35455, 'd13': 2.72587},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1010,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.54407, 'd12': 1.22922, 'd13': 2.76703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1011,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52014, 'd12': 1.24265, 'd13': 2.76268},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1012,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.55905, 'd12': 1.21255, 'd13': 2.7708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1013,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.59101, 'd12': 1.20625, 'd13': 2.78503},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1014,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45292, 'd12': 1.25637, 'd13': 2.70879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1015,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.60863, 'd12': 1.19737, 'd13': 2.80488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1016,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.70073, 'd12': 1.17736, 'd13': 2.87611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1017,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.834517, 'd12': 1.53746, 'd13': 2.37194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1018,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.56333, 'd12': 1.05429, 'd13': 2.61718},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1019,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52824, 'd12': 1.22279, 'd13': 2.75062},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1020,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38878, 'd12': 1.29094, 'd13': 2.67882},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1021,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.64229, 'd12': 1.18711, 'd13': 2.82866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1022,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44528, 'd12': 1.26168, 'd13': 2.70696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1023,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2969, 'd12': 1.35503, 'd13': 2.65192},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1024,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26704, 'd12': 1.44216, 'd13': 2.70443},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1025,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.64192, 'd12': 1.1997, 'd13': 2.84154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1026,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.52263, 'd12': 1.22449, 'd13': 2.74623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1027,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44762, 'd12': 1.26039, 'd13': 2.708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1028,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24649, 'd12': 1.40884, 'd13': 2.65412},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1029,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.61742, 'd12': 1.2021, 'd13': 2.81952},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1030,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.60828, 'd12': 1.21449, 'd13': 2.82277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1031,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31707, 'd12': 1.34274, 'd13': 2.65897},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1032,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31258, 'd12': 1.3592, 'd13': 2.66866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1033,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.56773, 'd12': 1.20995, 'd13': 2.77265},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1034,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.59503, 'd12': 1.20119, 'd13': 2.79504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1035,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {6,S}
2     C u0 p0 c0  {1,D} {4,S} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.61859, 'd12': 1.19503, 'd13': 2.81321},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1036,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46989, 'd12': 1.2377, 'd13': 2.70663},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1037,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36318, 'd12': 1.31867, 'd13': 2.68142},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1038,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48636, 'd12': 1.23021, 'd13': 2.7161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1039,
    reactant1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48483, 'd12': 1.15339, 'd13': 2.60691},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1040,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41086, 'd12': 1.32206, 'd13': 2.73237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1041,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39662, 'd12': 1.32928, 'd13': 2.7258},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1042,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42494, 'd12': 1.29358, 'd13': 2.71767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1043,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44613, 'd12': 1.29002, 'd13': 2.73555},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1044,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39145, 'd12': 1.3033, 'd13': 2.69413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1045,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41667, 'd12': 1.28613, 'd13': 2.70271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1046,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37467, 'd12': 1.32391, 'd13': 2.69839},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1047,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36383, 'd12': 1.29154, 'd13': 2.65429},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1048,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.4341, 'd12': 1.30049, 'd13': 2.73398},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1049,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43396, 'd12': 1.26865, 'd13': 2.7026},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1050,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38184, 'd12': 1.31396, 'd13': 2.69579},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1051,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41433, 'd12': 1.29097, 'd13': 2.70224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1052,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.46516, 'd12': 1.27691, 'd13': 2.7409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1053,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.43686, 'd12': 1.2677, 'd13': 2.70414},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1054,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35426, 'd12': 1.36735, 'd13': 2.72044},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1055,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.48696, 'd12': 1.26549, 'd13': 2.75164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1056,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38913, 'd12': 1.3065, 'd13': 2.69554},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1057,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45541, 'd12': 1.28076, 'd13': 2.73615},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1058,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41059, 'd12': 1.29548, 'd13': 2.70572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1059,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37984, 'd12': 1.32312, 'd13': 2.70272},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1060,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24003, 'd12': 1.28612, 'd13': 2.52591},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1061,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42255, 'd12': 1.29856, 'd13': 2.71914},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1062,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3659, 'd12': 1.29393, 'd13': 2.65648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1063,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33559, 'd12': 1.35986, 'd13': 2.69509},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1064,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38237, 'd12': 1.31643, 'd13': 2.69867},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1065,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42069, 'd12': 1.28005, 'd13': 2.70055},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1066,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44855, 'd12': 1.28794, 'd13': 2.73128},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1067,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44333, 'd12': 1.26504, 'd13': 2.70806},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1068,
    reactant1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.61836, 'd12': 1.20678, 'd13': 2.81885},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1069,
    reactant1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.62646, 'd12': 1.18877, 'd13': 2.80617},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1070,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.53291, 'd12': 1.25136, 'd13': 2.78427},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1071,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    reactant2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.5188, 'd12': 1.26123, 'd13': 2.7775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""B3LYP/6-31+G(d,p) calculation via group additive TS generator.""",
    longDesc = 
u"""
""",
)

entry(
    index = 1072,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.895297060023', 'd12': '1.40773504244', 'd13': '2.30303210246'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1""",
    longDesc = 
u"""
""",
)

entry(
    index = 1073,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.930299051641', 'd12': '1.35892133446', 'd13': '2.28893519078'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 2""",
    longDesc = 
u"""
""",
)

entry(
    index = 1074,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.907894558278', 'd12': '1.20216645606', 'd13': '2.10402794429'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 3""",
    longDesc = 
u"""
""",
)

entry(
    index = 1075,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.15309849454', 'd12': '1.21988501633', 'd13': '2.37290946709'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 4""",
    longDesc = 
u"""
""",
)

entry(
    index = 1076,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {3,S} {6,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.862862296846', 'd12': '1.46347894682', 'd13': '2.32579722591'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 5""",
    longDesc = 
u"""
""",
)

entry(
    index = 1077,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.11574127633', 'd12': '1.06757172779', 'd13': '2.1796554827'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 6""",
    longDesc = 
u"""
""",
)

entry(
    index = 1078,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36413844572', 'd12': '0.926273983824', 'd13': '2.29011119802'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 7""",
    longDesc = 
u"""
""",
)

entry(
    index = 1079,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.23289966705', 'd12': '1.08060600298', 'd13': '2.31166939106'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 8""",
    longDesc = 
u"""
""",
)

entry(
    index = 1080,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.17928080736', 'd12': '1.04828664688', 'd13': '2.22345150147'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 9""",
    longDesc = 
u"""
""",
)

entry(
    index = 1081,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': '1.23398956601', 'd12': '1.19436701782', 'd13': '2.42765010692'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 10""",
    longDesc = 
u"""
""",
)

entry(
    index = 1082,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.47813602871', 'd12': '0.856116451331', 'd13': '2.33353250223'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 11""",
    longDesc = 
u"""
""",
)

entry(
    index = 1083,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.41348718108', 'd12': '0.890380160538', 'd13': '2.3037243324'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 12""",
    longDesc = 
u"""
""",
)

entry(
    index = 1084,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36327979666', 'd12': '0.929233924724', 'd13': '2.29221727048'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 13""",
    longDesc = 
u"""
""",
)

entry(
    index = 1085,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.47462637073', 'd12': '0.857297575577', 'd13': '2.33091998893'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 14""",
    longDesc = 
u"""
""",
)

entry(
    index = 1086,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {5,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.974384887201', 'd12': '1.30720965209', 'd13': '2.28142288545'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 15""",
    longDesc = 
u"""
""",
)

entry(
    index = 1087,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     O u0 p2 c0  {2,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     O u0 p2 c0  {2,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36776843715', 'd12': '0.929232557334', 'd13': '2.2968743381'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 16""",
    longDesc = 
u"""
""",
)

entry(
    index = 1088,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {3,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {4,D} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4    O u0 p2 c0  {2,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.32911528045', 'd12': '0.955049619099', 'd13': '2.28383585417'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 17""",
    longDesc = 
u"""
""",
)

entry(
    index = 1089,
    reactant1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    reactant2 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {12,S}
4  *1 C u0 p0 c0  {2,S} {3,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {4,S}
12    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4  *3 C u1 p0 c0  {2,S} {3,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '0.887625561499', 'd12': '1.41659613444', 'd13': '2.30400248858'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 18""",
    longDesc = 
u"""
""",
)

entry(
    index = 1090,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     O u0 p2 c0  {3,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {3,S} {15,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.35777238782', 'd12': '0.929562714059', 'd13': '2.28701840306'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 19""",
    longDesc = 
u"""
""",
)

entry(
    index = 1091,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     O u0 p2 c0  {1,S} {14,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36923344491', 'd12': '0.923478017904', 'd13': '2.29270714272'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 20""",
    longDesc = 
u"""
""",
)

entry(
    index = 1092,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5  *1 C u0 p0 c0  {2,S} {9,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {5,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36286435818', 'd12': '0.927276316146', 'd13': '2.28958345535'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 21""",
    longDesc = 
u"""
""",
)

entry(
    index = 1093,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.31339574095', 'd12': '0.970596361047', 'd13': '2.28396108373'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 22""",
    longDesc = 
u"""
""",
)

entry(
    index = 1094,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {2,S} {4,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {6,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.30507883057', 'd12': '0.976300411313', 'd13': '2.28125066263'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 23""",
    longDesc = 
u"""
""",
)

entry(
    index = 1095,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37805888248', 'd12': '0.919883004244', 'd13': '2.29790558097'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 24""",
    longDesc = 
u"""
""",
)

entry(
    index = 1096,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37106798486', 'd12': '0.92744513748', 'd13': '2.29850984591'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 25""",
    longDesc = 
u"""
""",
)

entry(
    index = 1097,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.4930819397', 'd12': '0.850034093713', 'd13': '2.34311603157'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 26""",
    longDesc = 
u"""
""",
)

entry(
    index = 1098,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {5,B} {8,S}
3     C u0 p0 c0  {1,B} {6,B} {9,S}
4     C u0 p0 c0  {5,B} {6,B} {10,S}
5     C u0 p0 c0  {2,B} {4,B} {11,S}
6     C u0 p0 c0  {3,B} {4,B} {12,S}
7  *3 O u1 p2 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {5,B} {8,S}
3     C u0 p0 c0  {1,B} {6,B} {9,S}
4     C u0 p0 c0  {5,B} {6,B} {10,S}
5     C u0 p0 c0  {2,B} {4,B} {11,S}
6     C u0 p0 c0  {3,B} {4,B} {12,S}
7  *1 O u0 p2 c0  {1,S} {13,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13 *2 H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.08110686108', 'd12': '1.08657681722', 'd13': '2.16027024006'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 27""",
    longDesc = 
u"""
""",
)

entry(
    index = 1099,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {6,B} {11,S}
4     C u0 p0 c0  {2,B} {7,B} {12,S}
5     C u0 p0 c0  {6,B} {7,B} {13,S}
6     C u0 p0 c0  {3,B} {5,B} {14,S}
7     C u0 p0 c0  {4,B} {5,B} {15,S}
8  *3 C u1 p0 c0  {1,S} {16,S} {17,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {8,S}
17    H u0 p0 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
3     C u0 p0 c0  {1,S} {4,B} {5,B}
4     C u0 p0 c0  {3,B} {7,B} {14,S}
5     C u0 p0 c0  {3,B} {8,B} {15,S}
6     C u0 p0 c0  {7,B} {8,B} {16,S}
7     C u0 p0 c0  {4,B} {6,B} {17,S}
8     C u0 p0 c0  {5,B} {6,B} {18,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {7,S}
18    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36787122418', 'd12': '0.923728822558', 'd13': '2.29107401551'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 28""",
    longDesc = 
u"""
""",
)

entry(
    index = 1100,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.33014', 'd12': '1.37890', 'd13': '2.70895'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 29""",
    longDesc = 
u"""
""",
)

entry(
    index = 1101,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.28923', 'd12': '1.44233', 'd13': '2.73121'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 30""",
    longDesc = 
u"""
""",
)

entry(
    index = 1102,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.20569', 'd12': '1.30536', 'd13': '2.51006'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 31""",
    longDesc = 
u"""
""",
)

entry(
    index = 1103,
    reactant1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.40355', 'd12': '1.14362', 'd13': '2.54716'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 32""",
    longDesc = 
u"""
""",
)

entry(
    index = 1104,
    reactant1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.32319', 'd12': '1.22242', 'd13': '2.54544'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 33""",
    longDesc = 
u"""
""",
)

entry(
    index = 1105,
    reactant1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *1 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.27899', 'd12': '1.10392', 'd13': '2.34834'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 34""",
    longDesc = 
u"""
""",
)

entry(
    index = 1106,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.32326', 'd12': '1.37951', 'd13': '2.70269'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 35""",
    longDesc = 
u"""
""",
)

entry(
    index = 1107,
    reactant1 = """
1    O u0 p2 c0  {2,S} {4,S}
2 *3 O u0 p2 c0  {1,S} {3,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.38612', 'd12': '1.15831', 'd13': '2.54409'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 36""",
    longDesc = 
u"""
""",
)

entry(
    index = 1108,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {3,S} {6,S}
3 *2 H u0 p0 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37209', 'd12': '1.31192', 'd13': '2.68374'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 37""",
    longDesc = 
u"""
""",
)

entry(
    index = 1109,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
4  *3 C u1 p0 c0  {2,S} {3,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {4,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {8,S} {9,S}
3     C u0 p0 c0  {2,S} {4,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {3,S} {5,S} {12,S}
5  *2 H u0 p0 c0  {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.31082', 'd12': '1.39021', 'd13': '2.70089'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 38""",
    longDesc = 
u"""
""",
)

entry(
    index = 1110,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.33957', 'd12': '1.35719', 'd13': '2.69461'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 39""",
    longDesc = 
u"""
""",
)

entry(
    index = 1111,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {3,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.37733', 'd12': '1.32993', 'd13': '2.70362'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 40""",
    longDesc = 
u"""
""",
)

entry(
    index = 1112,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.36697', 'd12': '1.33663', 'd13': '2.70329'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 41""",
    longDesc = 
u"""
""",
)

entry(
    index = 1113,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.38471', 'd12': '1.30692', 'd13': '2.69157'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 42""",
    longDesc = 
u"""
""",
)

entry(
    index = 1114,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.18856', 'd12': '1.39456', 'd13': '2.58134'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 43""",
    longDesc = 
u"""
""",
)

entry(
    index = 1115,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': '1.05831', 'd12': '1.32977', 'd13': '2.28959'},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 44""",
    longDesc = 
u"""
""",
)

entry(
    index = 1116,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.407349, 'd12': 0.808251, 'd13': 2.196944},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 45""",
    longDesc = 
u"""
""",
)

entry(
    index = 1117,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.002833, 'd12': 1.296176, 'd13': 2.29898},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 46""",
    longDesc = 
u"""
""",
)

entry(
    index = 1118,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.324475, 'd12': 1.216325, 'd13': 2.537847},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 47""",
    longDesc = 
u"""
""",
)

entry(
    index = 1119,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.201, 'd12': 0.91111, 'd13': 2.10677},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 48""",
    longDesc = 
u"""
""",
)

entry(
    index = 1120,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.250952, 'd12': 1.060399, 'd13': 2.311305},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 49""",
    longDesc = 
u"""
""",
)

entry(
    index = 1121,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.366101, 'd12': 0.926377, 'd13': 2.29247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 50""",
    longDesc = 
u"""
""",
)

entry(
    index = 1122,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.310536, 'd12': 1.19983, 'd13': 2.509181},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 51""",
    longDesc = 
u"""
""",
)

entry(
    index = 1123,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.486471, 'd12': 1.274424, 'd13': 2.760463},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 52""",
    longDesc = 
u"""
""",
)

entry(
    index = 1124,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.425793, 'd12': 1.126056, 'd13': 2.55168},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 53""",
    longDesc = 
u"""
""",
)

entry(
    index = 1125,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.430155, 'd12': 0.877258, 'd13': 2.306828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 54""",
    longDesc = 
u"""
""",
)

entry(
    index = 1126,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.366575, 'd12': 0.927201, 'd13': 2.293246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 55""",
    longDesc = 
u"""
""",
)

entry(
    index = 1127,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {3,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.297897, 'd12': 1.008692, 'd13': 2.306541},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 56""",
    longDesc = 
u"""
""",
)

entry(
    index = 1128,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.272333, 'd12': 1.235607, 'd13': 2.495812},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 57""",
    longDesc = 
u"""
""",
)

entry(
    index = 1129,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.591884, 'd12': 1.002539, 'd13': 2.498974},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 58""",
    longDesc = 
u"""
""",
)

entry(
    index = 1130,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.477049, 'd12': 1.162672, 'd13': 2.638169},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 59""",
    longDesc = 
u"""
""",
)

entry(
    index = 1131,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.262583, 'd12': 1.464952, 'd13': 2.727535},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 60""",
    longDesc = 
u"""
""",
)

entry(
    index = 1132,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {4,S}
4     O u0 p2 c0  {3,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     O u0 p2 c0  {1,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.193929, 'd12': 1.176607, 'd13': 2.370363},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 61""",
    longDesc = 
u"""
""",
)

entry(
    index = 1133,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.268907, 'd12': 1.012158, 'd13': 2.279237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 62""",
    longDesc = 
u"""
""",
)

entry(
    index = 1134,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.275568, 'd12': 1.246208, 'd13': 2.521678},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 63""",
    longDesc = 
u"""
""",
)

entry(
    index = 1135,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32602, 'd12': 1.380732, 'd13': 2.706495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 64""",
    longDesc = 
u"""
""",
)

entry(
    index = 1136,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {6,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.332471, 'd12': 1.363688, 'd13': 2.695568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 65""",
    longDesc = 
u"""
""",
)

entry(
    index = 1137,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26608, 'd12': 1.470831, 'd13': 2.736083},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 66""",
    longDesc = 
u"""
""",
)

entry(
    index = 1138,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {3,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.302739, 'd12': 1.430905, 'd13': 2.733224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 67""",
    longDesc = 
u"""
""",
)

entry(
    index = 1139,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.926853, 'd12': 1.371495, 'd13': 2.298343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 68""",
    longDesc = 
u"""
""",
)

entry(
    index = 1140,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.223801, 'd12': 1.317309, 'd13': 2.535817},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 69""",
    longDesc = 
u"""
""",
)

entry(
    index = 1141,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.284618, 'd12': 1.429246, 'd13': 2.712247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 70""",
    longDesc = 
u"""
""",
)

entry(
    index = 1142,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.380621, 'd12': 1.33542, 'd13': 2.716025},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 71""",
    longDesc = 
u"""
""",
)

entry(
    index = 1143,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40219, 'd12': 1.149865, 'd13': 2.551133},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 72""",
    longDesc = 
u"""
""",
)

entry(
    index = 1144,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.356755, 'd12': 1.355809, 'd13': 2.71208},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 73""",
    longDesc = 
u"""
""",
)

entry(
    index = 1145,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24964, 'd12': 1.289857, 'd13': 2.539487},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 74""",
    longDesc = 
u"""
""",
)

entry(
    index = 1146,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.276309, 'd12': 1.248587, 'd13': 2.524895},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 75""",
    longDesc = 
u"""
""",
)

entry(
    index = 1147,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.421184, 'd12': 1.329108, 'd13': 2.749792},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 76""",
    longDesc = 
u"""
""",
)

entry(
    index = 1148,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.449892, 'd12': 1.306486, 'd13': 2.754254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 77""",
    longDesc = 
u"""
""",
)

entry(
    index = 1149,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.355088, 'd12': 1.185967, 'd13': 2.540637},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 78""",
    longDesc = 
u"""
""",
)

entry(
    index = 1150,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.328058, 'd12': 1.377889, 'd13': 2.705697},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 79""",
    longDesc = 
u"""
""",
)

entry(
    index = 1151,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {5,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {5,S} {14,S} {15,S} {16,S}
5  *3 C u1 p0 c0  {1,S} {3,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.235549, 'd12': 1.065669, 'd13': 2.301216},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 80""",
    longDesc = 
u"""
""",
)

entry(
    index = 1152,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307025, 'd12': 1.409141, 'd13': 2.715605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 81""",
    longDesc = 
u"""
""",
)

entry(
    index = 1153,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.325846, 'd12': 1.381915, 'd13': 2.707452},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 82""",
    longDesc = 
u"""
""",
)

entry(
    index = 1154,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.382945, 'd12': 1.299711, 'd13': 2.682409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 83""",
    longDesc = 
u"""
""",
)

entry(
    index = 1155,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {3,S} {15,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.362744, 'd12': 0.930376, 'd13': 2.292827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 84""",
    longDesc = 
u"""
""",
)

entry(
    index = 1156,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5  *3 C u1 p0 c0  {1,S} {2,S} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.319334, 'd12': 0.968067, 'd13': 2.286248},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 85""",
    longDesc = 
u"""
""",
)

entry(
    index = 1157,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.287947, 'd12': 1.4443, 'd13': 2.732236},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 86""",
    longDesc = 
u"""
""",
)

entry(
    index = 1158,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.235324, 'd12': 1.513197, 'd13': 2.74749},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 87""",
    longDesc = 
u"""
""",
)

entry(
    index = 1159,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.272173, 'd12': 1.463225, 'd13': 2.734469},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 88""",
    longDesc = 
u"""
""",
)

entry(
    index = 1160,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.282451, 'd12': 0.994169, 'd13': 2.276393},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 89""",
    longDesc = 
u"""
""",
)

entry(
    index = 1161,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    O u1 p2 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.131035, 'd12': 1.48516, 'd13': 2.614105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 90""",
    longDesc = 
u"""
""",
)

entry(
    index = 1162,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.160095, 'd12': 1.38475, 'd13': 2.544667},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 91""",
    longDesc = 
u"""
""",
)

entry(
    index = 1163,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.222161, 'd12': 1.32645, 'd13': 2.548529},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 92""",
    longDesc = 
u"""
""",
)

entry(
    index = 1164,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.255489, 'd12': 1.493337, 'd13': 2.74766},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 93""",
    longDesc = 
u"""
""",
)

entry(
    index = 1165,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {3,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {4,D} {7,S}
3    O u0 p2 c0  {1,S} {2,S}
4    O u0 p2 c0  {2,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.321635, 'd12': 1.380239, 'd13': 2.701664},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 94""",
    longDesc = 
u"""
""",
)

entry(
    index = 1166,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.287741, 'd12': 1.455335, 'd13': 2.74237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 95""",
    longDesc = 
u"""
""",
)

entry(
    index = 1167,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.254446, 'd12': 1.464653, 'd13': 2.717863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 96""",
    longDesc = 
u"""
""",
)

entry(
    index = 1168,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.354599, 'd12': 1.353827, 'd13': 2.708409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 97""",
    longDesc = 
u"""
""",
)

entry(
    index = 1169,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.4283, 'd12': 1.331478, 'd13': 2.756683},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 98""",
    longDesc = 
u"""
""",
)

entry(
    index = 1170,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.457569, 'd12': 1.309076, 'd13': 2.765122},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 99""",
    longDesc = 
u"""
""",
)

entry(
    index = 1171,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.359062, 'd12': 1.352875, 'd13': 2.711432},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 100""",
    longDesc = 
u"""
""",
)

entry(
    index = 1172,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.229832, 'd12': 1.330919, 'd13': 2.560671},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 101""",
    longDesc = 
u"""
""",
)

entry(
    index = 1173,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *3 O u1 p2 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.280576, 'd12': 1.246807, 'd13': 2.526767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 102""",
    longDesc = 
u"""
""",
)

entry(
    index = 1174,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.45327, 'd12': 1.30392, 'd13': 2.755748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 103""",
    longDesc = 
u"""
""",
)

entry(
    index = 1175,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.332136, 'd12': 1.210177, 'd13': 2.542273},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 104""",
    longDesc = 
u"""
""",
)

entry(
    index = 1176,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.355607, 'd12': 1.188088, 'd13': 2.543226},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 105""",
    longDesc = 
u"""
""",
)

entry(
    index = 1177,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2 *3 C u1 p0 c0  {1,S} {4,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    O u0 p2 c0  {2,S} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {3,D} {7,S}
3     C u0 p0 c0  {2,D} {8,S} {9,S}
4     O u0 p2 c0  {1,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.271122, 'd12': 1.483497, 'd13': 2.75044},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 106""",
    longDesc = 
u"""
""",
)

entry(
    index = 1178,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.291399, 'd12': 1.418941, 'd13': 2.710328},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 107""",
    longDesc = 
u"""
""",
)

entry(
    index = 1179,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.333048, 'd12': 1.376535, 'd13': 2.708112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 108""",
    longDesc = 
u"""
""",
)

entry(
    index = 1180,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,D}
3  *3 C u1 p0 c0  {4,S} {9,S} {10,S}
4     O u0 p2 c0  {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     O u0 p2 c0  {2,D}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,S} {11,D}
4     O u0 p2 c0  {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.318788, 'd12': 1.38536, 'd13': 2.703903},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 109""",
    longDesc = 
u"""
""",
)

entry(
    index = 1181,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {4,S} {8,D}
3  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
4     O u0 p2 c0  {1,S} {2,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     O u0 p2 c0  {2,D}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,S} {11,D}
4     O u0 p2 c0  {2,S} {3,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.298579, 'd12': 1.403984, 'd13': 2.702172},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 110""",
    longDesc = 
u"""
""",
)

entry(
    index = 1182,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    C u0 p0 c0  {2,S} {8,D} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,D} {10,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.280278, 'd12': 1.453078, 'd13': 2.731984},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 111""",
    longDesc = 
u"""
""",
)

entry(
    index = 1183,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
3    C u0 p0 c0  {1,S} {6,D} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {3,D}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,D} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.364407, 'd12': 1.343187, 'd13': 2.707408},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 112""",
    longDesc = 
u"""
""",
)

entry(
    index = 1184,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.318758, 'd12': 1.421882, 'd13': 2.74022},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 113""",
    longDesc = 
u"""
""",
)

entry(
    index = 1185,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.346259, 'd12': 1.384498, 'd13': 2.730612},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 114""",
    longDesc = 
u"""
""",
)

entry(
    index = 1186,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34754, 'd12': 1.201517, 'd13': 2.547347},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 115""",
    longDesc = 
u"""
""",
)

entry(
    index = 1187,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.404984, 'd12': 1.152543, 'd13': 2.557307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 116""",
    longDesc = 
u"""
""",
)

entry(
    index = 1188,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.360934, 'd12': 1.356039, 'd13': 2.716761},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 117""",
    longDesc = 
u"""
""",
)

entry(
    index = 1189,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.408127, 'd12': 1.351842, 'd13': 2.756651},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 118""",
    longDesc = 
u"""
""",
)

entry(
    index = 1190,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.461382, 'd12': 1.307129, 'd13': 2.768218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 119""",
    longDesc = 
u"""
""",
)

entry(
    index = 1191,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {16,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16 *2 H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.113429, 'd12': 1.453162, 'd13': 2.565773},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 120""",
    longDesc = 
u"""
""",
)

entry(
    index = 1192,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.286944, 'd12': 1.44811, 'd13': 2.734005},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 121""",
    longDesc = 
u"""
""",
)

entry(
    index = 1193,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.322772, 'd12': 1.389466, 'd13': 2.712125},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 122""",
    longDesc = 
u"""
""",
)

entry(
    index = 1194,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.347002, 'd12': 1.195943, 'd13': 2.542942},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 123""",
    longDesc = 
u"""
""",
)

entry(
    index = 1195,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {5,S} {9,D}
3  *3 C u1 p0 c0  {5,S} {10,S} {11,S}
4     O u0 p2 c0  {1,S} {2,S}
5     O u0 p2 c0  {2,S} {3,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {2,D}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {4,S} {5,S} {12,D}
4     O u0 p2 c0  {1,S} {3,S}
5     O u0 p2 c0  {2,S} {3,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.321991, 'd12': 1.382092, 'd13': 2.703748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 124""",
    longDesc = 
u"""
""",
)

entry(
    index = 1196,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {9,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {8,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.243519, 'd12': 1.259028, 'd13': 2.490608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 125""",
    longDesc = 
u"""
""",
)

entry(
    index = 1197,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.205245, 'd12': 1.405721, 'd13': 2.603715},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 126""",
    longDesc = 
u"""
""",
)

entry(
    index = 1198,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.278589, 'd12': 1.25767, 'd13': 2.534594},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 127""",
    longDesc = 
u"""
""",
)

entry(
    index = 1199,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.321875, 'd12': 1.410864, 'd13': 2.730185},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 128""",
    longDesc = 
u"""
""",
)

entry(
    index = 1200,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {6,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     C u0 p0 c0  {2,S} {6,D} {15,S}
6     C u0 p0 c0  {3,S} {5,D} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,D} {15,S}
6     C u0 p0 c0  {4,S} {5,D} {16,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.341899, 'd12': 1.370231, 'd13': 2.712072},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 129""",
    longDesc = 
u"""
""",
)

entry(
    index = 1201,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,S} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.390728, 'd12': 1.33492, 'd13': 2.723733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 130""",
    longDesc = 
u"""
""",
)

entry(
    index = 1202,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.337615, 'd12': 1.391177, 'd13': 2.727653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 131""",
    longDesc = 
u"""
""",
)

entry(
    index = 1203,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.314561, 'd12': 1.415978, 'd13': 2.730215},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 132""",
    longDesc = 
u"""
""",
)

entry(
    index = 1204,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {11,D} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    O u0 p2 c0  {4,D}
12    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.286158, 'd12': 1.454247, 'd13': 2.739153},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 133""",
    longDesc = 
u"""
""",
)

entry(
    index = 1205,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {4,S}
3     C u0 p0 c0  {2,S} {5,D} {12,S}
4     C u0 p0 c0  {2,S} {6,D} {13,S}
5     C u0 p0 c0  {3,D} {7,S} {14,S}
6     C u0 p0 c0  {4,D} {7,S} {15,S}
7     C u0 p0 c0  {5,S} {6,S} {11,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    O u0 p2 c0  {7,D}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {5,D} {12,S}
4     C u0 p0 c0  {1,S} {6,D} {13,S}
5     C u0 p0 c0  {3,D} {7,S} {15,S}
6     C u0 p0 c0  {4,D} {7,S} {16,S}
7     C u0 p0 c0  {5,S} {6,S} {14,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    O u0 p2 c0  {7,D}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.210734, 'd12': 1.627066, 'd13': 2.837081},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 134""",
    longDesc = 
u"""
""",
)

entry(
    index = 1206,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.279753, 'd12': 1.254681, 'd13': 2.532874},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 135""",
    longDesc = 
u"""
""",
)

entry(
    index = 1207,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.251585, 'd12': 1.318814, 'd13': 2.554427},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 136""",
    longDesc = 
u"""
""",
)

entry(
    index = 1208,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.288264, 'd12': 1.245048, 'd13': 2.531537},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 137""",
    longDesc = 
u"""
""",
)

entry(
    index = 1209,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {5,B} {9,S}
3     C u0 p0 c0  {1,B} {6,B} {10,S}
4     C u0 p0 c0  {5,B} {6,B} {11,S}
5     C u0 p0 c0  {2,B} {4,B} {12,S}
6     C u0 p0 c0  {3,B} {4,B} {13,S}
7  *3 C u1 p0 c0  {8,S} {14,S} {15,S}
8     O u0 p2 c0  {1,S} {7,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {8,S} {9,S} {10,S} {11,S}
2     C u0 p0 c0  {3,B} {4,B} {8,S}
3     C u0 p0 c0  {2,B} {6,B} {12,S}
4     C u0 p0 c0  {2,B} {7,B} {13,S}
5     C u0 p0 c0  {6,B} {7,B} {14,S}
6     C u0 p0 c0  {3,B} {5,B} {15,S}
7     C u0 p0 c0  {4,B} {5,B} {16,S}
8     O u0 p2 c0  {1,S} {2,S}
9  *2 H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.311451, 'd12': 1.4136, 'd13': 2.724572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 138""",
    longDesc = 
u"""
""",
)

entry(
    index = 1210,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {1,S} {3,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.264185, 'd12': 1.286517, 'd13': 2.546171},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 139""",
    longDesc = 
u"""
""",
)

entry(
    index = 1211,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.284317, 'd12': 1.247176, 'd13': 2.529051},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 140""",
    longDesc = 
u"""
""",
)

entry(
    index = 1212,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
4     C u0 p0 c0  {1,S} {18,S} {19,S} {20,S}
5     C u0 p0 c0  {1,S} {21,S} {22,S} {23,S}
6     C u0 p0 c0  {2,S} {9,S} {10,S} {11,S}
7     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
8  *3 C u1 p0 c0  {2,S} {24,S} {25,S}
9     H u0 p0 c0  {6,S}
10    H u0 p0 c0  {6,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {7,S}
13    H u0 p0 c0  {7,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {3,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {4,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {5,S}
22    H u0 p0 c0  {5,S}
23    H u0 p0 c0  {5,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     C u0 p0 c0  {2,S} {18,S} {19,S} {20,S}
7     C u0 p0 c0  {2,S} {21,S} {22,S} {23,S}
8     C u0 p0 c0  {2,S} {24,S} {25,S} {26,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
26    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.333337, 'd12': 1.379587, 'd13': 2.706613},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 141""",
    longDesc = 
u"""
""",
)

entry(
    index = 1213,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
6     O u0 p2 c0  {2,S} {7,S}
7  *1 O u0 p2 c0  {6,S} {19,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19 *2 H u0 p0 c0  {7,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     O u0 p2 c0  {2,S} {18,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18 *3 O u1 p2 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.094942, 'd12': 1.345438, 'd13': 2.436127},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 142""",
    longDesc = 
u"""
""",
)

entry(
    index = 1214,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {2,S} {7,S}
6     O u0 p2 c0  {1,S} {16,S}
7  *1 O u0 p2 c0  {5,S} {17,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {6,S}
17 *2 H u0 p0 c0  {7,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {15,S}
6     O u0 p2 c0  {2,S} {16,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16 *3 O u1 p2 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.060269, 'd12': 1.420877, 'd13': 2.465326},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 143""",
    longDesc = 
u"""
""",
)

entry(
    index = 1215,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {9,S}
2     C u0 p0 c0  {1,S} {4,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {5,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {6,S} {14,S} {15,S}
5     C u0 p0 c0  {3,S} {6,S} {16,S} {17,S}
6     C u0 p0 c0  {4,S} {5,S} {18,S} {19,S}
7     O u0 p2 c0  {1,S} {8,S}
8  *1 O u0 p2 c0  {7,S} {20,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20 *2 H u0 p0 c0  {8,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2 *2 H u0 p0 c0  {1,S}
3    O u1 p2 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {6,S} {11,S} {12,S}
4     C u0 p0 c0  {5,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {2,S} {4,S} {15,S} {16,S}
6     C u0 p0 c0  {3,S} {4,S} {17,S} {18,S}
7     O u0 p2 c0  {1,S} {19,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
19 *3 O u1 p2 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.066347, 'd12': 1.405068, 'd13': 2.461135},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 144""",
    longDesc = 
u"""
""",
)

entry(
    index = 1216,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {9,S}
2     C u0 p0 c0  {6,S} {7,S} {8,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {1,S} {23,S} {24,S} {25,S}
6     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
7     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
8  *3 C u1 p0 c0  {2,S} {26,S} {27,S}
9     O u0 p2 c0  {1,S} {10,S}
10    O u0 p2 c0  {2,S} {9,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {7,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    H u0 p0 c0  {5,S}
24    H u0 p0 c0  {5,S}
25    H u0 p0 c0  {5,S}
26    H u0 p0 c0  {8,S}
27    H u0 p0 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {9,S}
2     C u0 p0 c0  {6,S} {7,S} {8,S} {10,S}
3  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {2,S} {23,S} {24,S} {25,S}
8     C u0 p0 c0  {2,S} {26,S} {27,S} {28,S}
9     O u0 p2 c0  {1,S} {10,S}
10    O u0 p2 c0  {2,S} {9,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {7,S}
25    H u0 p0 c0  {7,S}
26    H u0 p0 c0  {8,S}
27    H u0 p0 c0  {8,S}
28    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.339148, 'd12': 1.362866, 'd13': 2.70112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 145""",
    longDesc = 
u"""
""",
)

entry(
    index = 1217,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.207705, 'd12': 1.585963, 'd13': 2.793668},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 146""",
    longDesc = 
u"""
""",
)

entry(
    index = 1218,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.217391, 'd12': 1.387594, 'd13': 2.604205},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 147""",
    longDesc = 
u"""
""",
)

entry(
    index = 1219,
    reactant1 = """
1     C u0 p0 c0  {2,S} {8,S} {10,S} {11,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {5,B} {13,S}
4     C u0 p0 c0  {2,B} {7,B} {16,S}
5     C u0 p0 c0  {3,B} {6,B} {12,S}
6     C u0 p0 c0  {5,B} {7,B} {14,S}
7     C u0 p0 c0  {4,B} {6,B} {15,S}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {17,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {5,B} {12,S}
4     C u0 p0 c0  {2,B} {7,B} {15,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {5,B} {7,B} {13,S}
7     C u0 p0 c0  {4,B} {6,B} {14,S}
8     O u0 p2 c0  {1,S} {16,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {7,S}
15    H u0 p0 c0  {4,S}
16 *3 O u1 p2 c0  {8,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.076901, 'd12': 1.374965, 'd13': 2.450556},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 148""",
    longDesc = 
u"""
""",
)

entry(
    index = 1220,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.423371, 'd12': 1.301073, 'd13': 2.724135},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 149""",
    longDesc = 
u"""
""",
)

entry(
    index = 1221,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.972136, 'd12': 1.310432, 'd13': 2.282304},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 150""",
    longDesc = 
u"""
""",
)

entry(
    index = 1222,
    reactant1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.341712, 'd12': 1.052469, 'd13': 2.29163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 151""",
    longDesc = 
u"""
""",
)

entry(
    index = 1223,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.233914, 'd12': 1.544596, 'd13': 2.77851},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 152""",
    longDesc = 
u"""
""",
)

entry(
    index = 1224,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.412594, 'd12': 1.34342, 'd13': 2.737275},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 153""",
    longDesc = 
u"""
""",
)

entry(
    index = 1225,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.392257, 'd12': 1.33285, 'd13': 2.724149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 154""",
    longDesc = 
u"""
""",
)

entry(
    index = 1226,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44735, 'd12': 1.305805, 'd13': 2.751257},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 155""",
    longDesc = 
u"""
""",
)

entry(
    index = 1227,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.287052, 'd12': 1.411619, 'd13': 2.698415},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 156""",
    longDesc = 
u"""
""",
)

entry(
    index = 1228,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.275252, 'd12': 1.496988, 'd13': 2.771865},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 157""",
    longDesc = 
u"""
""",
)

entry(
    index = 1229,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.219969, 'd12': 1.328593, 'd13': 2.518475},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 158""",
    longDesc = 
u"""
""",
)

entry(
    index = 1230,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.086921, 'd12': 1.48334, 'd13': 2.569676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 159""",
    longDesc = 
u"""
""",
)

entry(
    index = 1231,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *3 C u1 p0 c0  {2,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {3,S} {7,D} {8,S}
3    O u0 p2 c0  {1,S} {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.320296, 'd12': 0.97841, 'd13': 2.298176},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 160""",
    longDesc = 
u"""
""",
)

entry(
    index = 1232,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.355419, 'd12': 1.190105, 'd13': 2.545508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 161""",
    longDesc = 
u"""
""",
)

entry(
    index = 1233,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.395629, 'd12': 1.386526, 'd13': 2.782155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 162""",
    longDesc = 
u"""
""",
)

entry(
    index = 1234,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41706, 'd12': 1.345537, 'd13': 2.734548},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 163""",
    longDesc = 
u"""
""",
)

entry(
    index = 1235,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.371076, 'd12': 1.357681, 'd13': 2.727624},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 164""",
    longDesc = 
u"""
""",
)

entry(
    index = 1236,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.394987, 'd12': 1.334129, 'd13': 2.727829},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 165""",
    longDesc = 
u"""
""",
)

entry(
    index = 1237,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.288945, 'd12': 1.408956, 'd13': 2.697672},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 166""",
    longDesc = 
u"""
""",
)

entry(
    index = 1238,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.660094, 'd12': 1.056332, 'd13': 2.716154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 167""",
    longDesc = 
u"""
""",
)

entry(
    index = 1239,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307194, 'd12': 1.455887, 'd13': 2.761316},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 168""",
    longDesc = 
u"""
""",
)

entry(
    index = 1240,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.316115, 'd12': 1.418259, 'd13': 2.721717},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 169""",
    longDesc = 
u"""
""",
)

entry(
    index = 1241,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.351556, 'd12': 1.395046, 'd13': 2.746143},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 170""",
    longDesc = 
u"""
""",
)

entry(
    index = 1242,
    reactant1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.245948, 'd12': 1.304434, 'd13': 2.550214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 171""",
    longDesc = 
u"""
""",
)

entry(
    index = 1243,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.264341, 'd12': 1.476903, 'd13': 2.740492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 172""",
    longDesc = 
u"""
""",
)

entry(
    index = 1244,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.383413, 'd12': 1.334801, 'd13': 2.718214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 173""",
    longDesc = 
u"""
""",
)

entry(
    index = 1245,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.371259, 'd12': 1.176561, 'd13': 2.547001},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 174""",
    longDesc = 
u"""
""",
)

entry(
    index = 1246,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.402633, 'd12': 1.151769, 'd13': 2.553686},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 175""",
    longDesc = 
u"""
""",
)

entry(
    index = 1247,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.395402, 'd12': 1.358629, 'd13': 2.751896},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 176""",
    longDesc = 
u"""
""",
)

entry(
    index = 1248,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.352975, 'd12': 1.378691, 'd13': 2.731071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 177""",
    longDesc = 
u"""
""",
)

entry(
    index = 1249,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.396635, 'd12': 1.332454, 'd13': 2.72898},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 178""",
    longDesc = 
u"""
""",
)

entry(
    index = 1250,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.400777, 'd12': 1.349393, 'd13': 2.748536},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 179""",
    longDesc = 
u"""
""",
)

entry(
    index = 1251,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.295021, 'd12': 1.410103, 'd13': 2.703918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 180""",
    longDesc = 
u"""
""",
)

entry(
    index = 1252,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.603839, 'd12': 1.075459, 'd13': 2.678774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 181""",
    longDesc = 
u"""
""",
)

entry(
    index = 1253,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.275561, 'd12': 1.502489, 'd13': 2.776544},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 182""",
    longDesc = 
u"""
""",
)

entry(
    index = 1254,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307104, 'd12': 1.422416, 'd13': 2.729321},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 183""",
    longDesc = 
u"""
""",
)

entry(
    index = 1255,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.291611, 'd12': 1.443078, 'd13': 2.733904},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 184""",
    longDesc = 
u"""
""",
)

entry(
    index = 1256,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.494936, 'd12': 1.12593, 'd13': 2.619254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 185""",
    longDesc = 
u"""
""",
)

entry(
    index = 1257,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {9,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,D} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     O u0 p2 c0  {3,D}
10 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307047, 'd12': 1.460727, 'd13': 2.76402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 186""",
    longDesc = 
u"""
""",
)

entry(
    index = 1258,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.274549, 'd12': 1.503366, 'd13': 2.776775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 187""",
    longDesc = 
u"""
""",
)

entry(
    index = 1259,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3     C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4  *3 C u1 p0 c0  {1,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3     C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4  *1 C u0 p0 c0  {1,S} {10,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
11 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.280838, 'd12': 1.499708, 'd13': 2.777508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 188""",
    longDesc = 
u"""
""",
)

entry(
    index = 1260,
    reactant1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    reactant2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *1 C u0 p0 c0  {3,S} {10,D} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
11 *2 H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.281734, 'd12': 1.490125, 'd13': 2.768809},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 189""",
    longDesc = 
u"""
""",
)

entry(
    index = 1261,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.213795, 'd12': 1.369307, 'd13': 2.578224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 190""",
    longDesc = 
u"""
""",
)

entry(
    index = 1262,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.303803, 'd12': 1.381618, 'd13': 2.685418},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 191""",
    longDesc = 
u"""
""",
)

entry(
    index = 1263,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.386573, 'd12': 1.339219, 'd13': 2.724421},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 192""",
    longDesc = 
u"""
""",
)

entry(
    index = 1264,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.324029, 'd12': 1.40752, 'd13': 2.729261},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 193""",
    longDesc = 
u"""
""",
)

entry(
    index = 1265,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {7,S} {8,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6 *2 H u0 p0 c0  {3,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.341631, 'd12': 1.419813, 'd13': 2.752365},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 194""",
    longDesc = 
u"""
""",
)

entry(
    index = 1266,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.300082, 'd12': 1.409078, 'd13': 2.708894},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 195""",
    longDesc = 
u"""
""",
)

entry(
    index = 1267,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.322631, 'd12': 1.404289, 'd13': 2.726413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 196""",
    longDesc = 
u"""
""",
)

entry(
    index = 1268,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.314745, 'd12': 1.406087, 'd13': 2.715634},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 197""",
    longDesc = 
u"""
""",
)

entry(
    index = 1269,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.265173, 'd12': 1.481921, 'd13': 2.746184},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 198""",
    longDesc = 
u"""
""",
)

entry(
    index = 1270,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {2,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.273234, 'd12': 1.502992, 'd13': 2.775786},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 199""",
    longDesc = 
u"""
""",
)

entry(
    index = 1271,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     O u0 p2 c0  {1,S} {5,S}
5  *3 C u1 p0 c0  {4,S} {13,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *1 C u0 p0 c0  {5,S} {13,D} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31096, 'd12': 1.411288, 'd13': 2.722246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 200""",
    longDesc = 
u"""
""",
)

entry(
    index = 1272,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,D}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {1,S} {15,D} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.277167, 'd12': 1.504782, 'd13': 2.778712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 201""",
    longDesc = 
u"""
""",
)

entry(
    index = 1273,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.279787, 'd12': 1.422491, 'd13': 2.702277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 202""",
    longDesc = 
u"""
""",
)

entry(
    index = 1274,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.331086, 'd12': 1.433791, 'd13': 2.759466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 203""",
    longDesc = 
u"""
""",
)

entry(
    index = 1275,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.232721, 'd12': 1.344864, 'd13': 2.576968},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 204""",
    longDesc = 
u"""
""",
)

entry(
    index = 1276,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.417057, 'd12': 1.189731, 'd13': 2.604216},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 205""",
    longDesc = 
u"""
""",
)

entry(
    index = 1277,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {2,S} {12,D} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    O u0 p2 c0  {4,D}
13 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.308636, 'd12': 1.461026, 'd13': 2.768538},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 206""",
    longDesc = 
u"""
""",
)

entry(
    index = 1278,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3751, 'd12': 1.35724, 'd13': 2.73016},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 207""",
    longDesc = 
u"""
""",
)

entry(
    index = 1279,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.236844, 'd12': 1.339756, 'd13': 2.575745},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 208""",
    longDesc = 
u"""
""",
)

entry(
    index = 1280,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.240011, 'd12': 1.465935, 'd13': 2.705301},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 209""",
    longDesc = 
u"""
""",
)

entry(
    index = 1281,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {10,S} {11,S} {12,S}
2     C u0 p0 c0  {4,S} {13,S} {14,S} {15,S}
3     C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {6,S}
6  *3 C u1 p0 c0  {5,S} {16,S} {17,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {2,S}
15    H u0 p0 c0  {2,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {5,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {5,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {6,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {1,S} {2,S} {6,D}
6     C u0 p0 c0  {3,S} {4,S} {5,D}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.310685, 'd12': 1.426374, 'd13': 2.73602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 210""",
    longDesc = 
u"""
""",
)

entry(
    index = 1282,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     C u0 p0 c0  {1,S} {15,S} {16,S} {17,S}
6     C u0 p0 c0  {1,S} {18,S} {19,S} {20,S}
7     C u0 p0 c0  {2,S} {21,S} {22,S} {23,S}
8  *3 C u1 p0 c0  {2,S} {24,S} {25,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {6,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    H u0 p0 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7  *1 C u0 p0 c0  {2,S} {12,S} {22,S} {23,S}
8     C u0 p0 c0  {2,S} {24,S} {25,S} {26,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {7,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {7,S}
24    H u0 p0 c0  {8,S}
25    H u0 p0 c0  {8,S}
26    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.165923, 'd12': 1.467679, 'd13': 2.632605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 211""",
    longDesc = 
u"""
""",
)

entry(
    index = 1283,
    reactant1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {3,S} {5,S} {14,S}
5     O u0 p2 c0  {1,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *3 C u1 p0 c0  {2,S} {13,S} {14,S}
5     O u0 p2 c0  {1,S} {2,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     O u0 p2 c0  {1,S} {2,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.307357, 'd12': 1.440032, 'd13': 2.743703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 212""",
    longDesc = 
u"""
""",
)

entry(
    index = 1284,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {8,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {3,B} {4,B}
3     C u0 p0 c0  {2,B} {6,B} {11,S}
4     C u0 p0 c0  {2,B} {7,B} {12,S}
5     C u0 p0 c0  {6,B} {7,B} {13,S}
6     C u0 p0 c0  {3,B} {5,B} {14,S}
7     C u0 p0 c0  {4,B} {5,B} {15,S}
8  *3 C u1 p0 c0  {1,S} {16,S} {17,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {7,S}
16    H u0 p0 c0  {8,S}
17    H u0 p0 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
3     C u0 p0 c0  {1,S} {4,B} {5,B}
4     C u0 p0 c0  {3,B} {7,B} {14,S}
5     C u0 p0 c0  {3,B} {8,B} {15,S}
6     C u0 p0 c0  {7,B} {8,B} {16,S}
7     C u0 p0 c0  {4,B} {6,B} {17,S}
8     C u0 p0 c0  {5,B} {6,B} {18,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {2,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {7,S}
18    H u0 p0 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.389889, 'd12': 1.155233, 'd13': 2.544901},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 213""",
    longDesc = 
u"""
""",
)

entry(
    index = 1285,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {3,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {3,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.308541, 'd12': 1.463798, 'd13': 2.77175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 214""",
    longDesc = 
u"""
""",
)

entry(
    index = 1286,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {2,S} {15,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {5,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {2,S} {15,D} {16,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.299677, 'd12': 1.470008, 'd13': 2.765791},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 215""",
    longDesc = 
u"""
""",
)

entry(
    index = 1287,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 C u1 p0 c0  {1,S} {15,D}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 C u0 p0 c0  {1,S} {15,D} {16,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    O u0 p2 c0  {5,D}
16 *2 H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.355331, 'd12': 1.419633, 'd13': 2.757765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 216""",
    longDesc = 
u"""
""",
)

entry(
    index = 1288,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.256038, 'd12': 1.289507, 'd13': 2.542827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 217""",
    longDesc = 
u"""
""",
)

entry(
    index = 1289,
    reactant1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 3
1    O u1 p2 c0  {2,S}
2 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.599845, 'd12': 1.084727, 'd13': 2.632605},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 218""",
    longDesc = 
u"""
""",
)

entry(
    index = 1290,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    O u0 p2 c0  {1,S} {3,S}
3 *1 O u0 p2 c0  {2,S} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *3 O u1 p2 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.343942, 'd12': 1.207728, 'd13': 2.52238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 219""",
    longDesc = 
u"""
""",
)

entry(
    index = 1291,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.268698, 'd12': 1.447046, 'd13': 2.715651},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 220""",
    longDesc = 
u"""
""",
)

entry(
    index = 1292,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {2,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.387852, 'd12': 1.157061, 'd13': 2.544644},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 221""",
    longDesc = 
u"""
""",
)

entry(
    index = 1293,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     O u0 p2 c0  {1,S} {4,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {4,S} {10,D} {11,S}
4     O u0 p2 c0  {1,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
11 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.317411, 'd12': 1.400219, 'd13': 2.717538},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 222""",
    longDesc = 
u"""
""",
)

entry(
    index = 1294,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     O u0 p2 c0  {1,S} {4,S}
4  *3 C u1 p0 c0  {3,S} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3  *1 C u0 p0 c0  {4,S} {10,D} {11,S}
4     O u0 p2 c0  {1,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
11 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.350874, 'd12': 1.369407, 'd13': 2.720067},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 223""",
    longDesc = 
u"""
""",
)

entry(
    index = 1295,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     O u0 p2 c0  {2,S} {5,S}
5  *3 C u1 p0 c0  {4,S} {13,D}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {5,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {5,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4  *1 C u0 p0 c0  {5,S} {13,D} {14,S}
5     O u0 p2 c0  {2,S} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *2 H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.316801, 'd12': 1.401544, 'd13': 2.718293},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 224""",
    longDesc = 
u"""
""",
)

entry(
    index = 1296,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3 *3 C u1 p0 c0  {1,S} {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,S} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {2,S} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.301866, 'd12': 1.368342, 'd13': 2.670175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 225""",
    longDesc = 
u"""
""",
)

entry(
    index = 1297,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,D} {8,S}
3     C u0 p0 c0  {2,D} {4,S} {9,S}
4  *3 C u1 p0 c0  {3,S} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {4,D} {11,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.223685, 'd12': 1.366807, 'd13': 2.589608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 226""",
    longDesc = 
u"""
""",
)

entry(
    index = 1298,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {4,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {4,S} {11,S} {12,S} {13,S}
4  *3 C u1 p0 c0  {1,S} {2,S} {3,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.244105, 'd12': 1.49714, 'd13': 2.741235},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 227""",
    longDesc = 
u"""
""",
)

entry(
    index = 1299,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *1 O u0 p2 c0  {1,S} {15,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {4,D} {5,S}
4     C u0 p0 c0  {2,S} {3,D} {12,S}
5  *3 C u1 p0 c0  {3,S} {13,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5  *3 O u1 p2 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {4,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {4,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {5,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {1,S} {2,S} {5,D}
5     C u0 p0 c0  {3,S} {4,D} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22576, 'd12': 1.365815, 'd13': 2.590913},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 228""",
    longDesc = 
u"""
""",
)

entry(
    index = 1300,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {5,S} {10,S} {11,S}
4     C u0 p0 c0  {2,S} {5,S} {12,S} {13,S}
5     C u0 p0 c0  {3,S} {4,S} {14,S} {15,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {5,S}
15    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2474, 'd12': 1.475176, 'd13': 2.722152},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 229""",
    longDesc = 
u"""
""",
)

entry(
    index = 1301,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {11,S} {12,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {9,S} {10,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {1,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {6,S} {13,S} {14,S}
5     C u0 p0 c0  {3,S} {6,S} {15,S} {16,S}
6     C u0 p0 c0  {4,S} {5,S} {17,S} {18,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {5,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {6,S}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.257363, 'd12': 1.460601, 'd13': 2.717863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 230""",
    longDesc = 
u"""
""",
)

entry(
    index = 1302,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.28515, 'd12': 1.4645, 'd13': 2.74755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 231""",
    longDesc = 
u"""
""",
)

entry(
    index = 1303,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15497, 'd12': 1.39584, 'd13': 2.55035},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 232""",
    longDesc = 
u"""
""",
)

entry(
    index = 1304,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22246, 'd12': 1.33923, 'd13': 2.55653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 233""",
    longDesc = 
u"""
""",
)

entry(
    index = 1305,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1524, 'd12': 1.4027, 'd13': 2.5549},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 234""",
    longDesc = 
u"""
""",
)

entry(
    index = 1306,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22029, 'd12': 1.33965, 'd13': 2.55515},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 235""",
    longDesc = 
u"""
""",
)

entry(
    index = 1307,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.05778, 'd12': 1.14693, 'd13': 2.2018},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 236""",
    longDesc = 
u"""
""",
)

entry(
    index = 1308,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19277, 'd12': 1.3615, 'd13': 2.55206},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 237""",
    longDesc = 
u"""
""",
)

entry(
    index = 1309,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18793, 'd12': 1.36537, 'd13': 2.55312},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 238""",
    longDesc = 
u"""
""",
)

entry(
    index = 1310,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24975, 'd12': 1.04802, 'd13': 2.29631},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 239""",
    longDesc = 
u"""
""",
)

entry(
    index = 1311,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20093, 'd12': 1.34472, 'd13': 2.54466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 240""",
    longDesc = 
u"""
""",
)

entry(
    index = 1312,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.21958, 'd12': 1.56172, 'd13': 2.77843},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 241""",
    longDesc = 
u"""
""",
)

entry(
    index = 1313,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.29438, 'd12': 1.40437, 'd13': 2.69639},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 242""",
    longDesc = 
u"""
""",
)

entry(
    index = 1314,
    reactant1 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.06429, 'd12': 1.54692, 'd13': 2.61094},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 243""",
    longDesc = 
u"""
""",
)

entry(
    index = 1315,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.07478, 'd12': 1.51251, 'd13': 2.58617},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 244""",
    longDesc = 
u"""
""",
)

entry(
    index = 1316,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23899, 'd12': 1.49915, 'd13': 2.73813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 245""",
    longDesc = 
u"""
""",
)

entry(
    index = 1317,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29223, 'd12': 1.43931, 'd13': 2.73106},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 246""",
    longDesc = 
u"""
""",
)

entry(
    index = 1318,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3751, 'd12': 1.3563, 'd13': 2.7299},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 247""",
    longDesc = 
u"""
""",
)

entry(
    index = 1319,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23524, 'd12': 1.32493, 'd13': 2.55853},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 248""",
    longDesc = 
u"""
""",
)

entry(
    index = 1320,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23227, 'd12': 1.32662, 'd13': 2.55831},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 249""",
    longDesc = 
u"""
""",
)

entry(
    index = 1321,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16929, 'd12': 1.43796, 'd13': 2.60307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 250""",
    longDesc = 
u"""
""",
)

entry(
    index = 1322,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13195, 'd12': 1.48877, 'd13': 2.61754},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 251""",
    longDesc = 
u"""
""",
)

entry(
    index = 1323,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36997, 'd12': 1.36627, 'd13': 2.72492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 252""",
    longDesc = 
u"""
""",
)

entry(
    index = 1324,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2841, 'd12': 1.28842, 'd13': 2.57085},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 253""",
    longDesc = 
u"""
""",
)

entry(
    index = 1325,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25665, 'd12': 1.30648, 'd13': 2.55165},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 254""",
    longDesc = 
u"""
""",
)

entry(
    index = 1326,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28233, 'd12': 1.29098, 'd13': 2.57282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 255""",
    longDesc = 
u"""
""",
)

entry(
    index = 1327,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24693, 'd12': 1.31291, 'd13': 2.55976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 256""",
    longDesc = 
u"""
""",
)

entry(
    index = 1328,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.18161, 'd12': 1.21398, 'd13': 2.3926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 257""",
    longDesc = 
u"""
""",
)

entry(
    index = 1329,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.19861, 'd12': 1.14566, 'd13': 2.34236},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 258""",
    longDesc = 
u"""
""",
)

entry(
    index = 1330,
    reactant1 = """
1    O u0 p2 c0  {2,S} {3,S}
2 *1 O u0 p2 c0  {1,S} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29127, 'd12': 1.2645, 'd13': 2.55403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 259""",
    longDesc = 
u"""
""",
)

entry(
    index = 1331,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30678, 'd12': 1.4317, 'd13': 2.73707},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 260""",
    longDesc = 
u"""
""",
)

entry(
    index = 1332,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32678, 'd12': 1.39513, 'd13': 2.72178},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 261""",
    longDesc = 
u"""
""",
)

entry(
    index = 1333,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33276, 'd12': 1.4003, 'd13': 2.73048},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 262""",
    longDesc = 
u"""
""",
)

entry(
    index = 1334,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35932, 'd12': 1.36925, 'd13': 2.72635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 263""",
    longDesc = 
u"""
""",
)

entry(
    index = 1335,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25472, 'd12': 1.52025, 'd13': 2.77157},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 264""",
    longDesc = 
u"""
""",
)

entry(
    index = 1336,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31715, 'd12': 1.42535, 'd13': 2.74206},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 265""",
    longDesc = 
u"""
""",
)

entry(
    index = 1337,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31943, 'd12': 1.42188, 'd13': 2.74058},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 266""",
    longDesc = 
u"""
""",
)

entry(
    index = 1338,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35642, 'd12': 1.39787, 'd13': 2.75277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 267""",
    longDesc = 
u"""
""",
)

entry(
    index = 1339,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30496, 'd12': 1.3949, 'd13': 2.69921},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 268""",
    longDesc = 
u"""
""",
)

entry(
    index = 1340,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22688, 'd12': 1.54499, 'd13': 2.76811},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 269""",
    longDesc = 
u"""
""",
)

entry(
    index = 1341,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.08536, 'd12': 1.49453, 'd13': 2.57808},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 270""",
    longDesc = 
u"""
""",
)

entry(
    index = 1342,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32515, 'd12': 1.34372, 'd13': 2.66858},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 271""",
    longDesc = 
u"""
""",
)

entry(
    index = 1343,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21013, 'd12': 1.58064, 'd13': 2.78913},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 272""",
    longDesc = 
u"""
""",
)

entry(
    index = 1344,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19456, 'd12': 1.63621, 'd13': 2.8296},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 273""",
    longDesc = 
u"""
""",
)

entry(
    index = 1345,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.22872, 'd12': 1.30104, 'd13': 2.52774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 274""",
    longDesc = 
u"""
""",
)

entry(
    index = 1346,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2474, 'd12': 1.45271, 'd13': 2.69994},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 275""",
    longDesc = 
u"""
""",
)

entry(
    index = 1347,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24755, 'd12': 1.48384, 'd13': 2.73092},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 276""",
    longDesc = 
u"""
""",
)

entry(
    index = 1348,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,B} {6,B} {7,S}
2     C u0 p0 c0  {1,B} {3,B} {8,S}
3     C u0 p0 c0  {2,B} {4,B} {9,S}
4     C u0 p0 c0  {3,B} {5,B} {10,S}
5     C u0 p0 c0  {4,B} {6,B} {11,S}
6     C u0 p0 c0  {1,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.11822, 'd12': 1.7883, 'd13': 2.72249},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 277""",
    longDesc = 
u"""
""",
)

entry(
    index = 1349,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15005, 'd12': 1.83906, 'd13': 2.8339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 278""",
    longDesc = 
u"""
""",
)

entry(
    index = 1350,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32731, 'd12': 1.33911, 'd13': 2.66614},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 279""",
    longDesc = 
u"""
""",
)

entry(
    index = 1351,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3002, 'd12': 1.38136, 'd13': 2.68147},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 280""",
    longDesc = 
u"""
""",
)

entry(
    index = 1352,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12041, 'd12': 1.4419, 'd13': 2.56111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 281""",
    longDesc = 
u"""
""",
)

entry(
    index = 1353,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24362, 'd12': 1.52157, 'd13': 2.76374},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 282""",
    longDesc = 
u"""
""",
)

entry(
    index = 1354,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25446, 'd12': 1.48582, 'd13': 2.73982},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 283""",
    longDesc = 
u"""
""",
)

entry(
    index = 1355,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28254, 'd12': 1.47281, 'd13': 2.75245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 284""",
    longDesc = 
u"""
""",
)

entry(
    index = 1356,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14908, 'd12': 1.40491, 'd13': 2.55287},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 285""",
    longDesc = 
u"""
""",
)

entry(
    index = 1357,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14979, 'd12': 1.40496, 'd13': 2.55458},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 286""",
    longDesc = 
u"""
""",
)

entry(
    index = 1358,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26884, 'd12': 1.48928, 'd13': 2.757},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 287""",
    longDesc = 
u"""
""",
)

entry(
    index = 1359,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27882, 'd12': 1.45564, 'd13': 2.73397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 288""",
    longDesc = 
u"""
""",
)

entry(
    index = 1360,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3076, 'd12': 1.41597, 'd13': 2.72339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 289""",
    longDesc = 
u"""
""",
)

entry(
    index = 1361,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33465, 'd12': 1.3921, 'd13': 2.71635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 290""",
    longDesc = 
u"""
""",
)

entry(
    index = 1362,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30203, 'd12': 1.4489, 'd13': 2.7492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 291""",
    longDesc = 
u"""
""",
)

entry(
    index = 1363,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17504, 'd12': 1.37297, 'd13': 2.54771},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 292""",
    longDesc = 
u"""
""",
)

entry(
    index = 1364,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28126, 'd12': 1.46579, 'd13': 2.74613},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 293""",
    longDesc = 
u"""
""",
)

entry(
    index = 1365,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30178, 'd12': 1.42727, 'd13': 2.72849},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 294""",
    longDesc = 
u"""
""",
)

entry(
    index = 1366,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2665, 'd12': 1.49951, 'd13': 2.76595},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 295""",
    longDesc = 
u"""
""",
)

entry(
    index = 1367,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3275, 'd12': 1.39121, 'd13': 2.71845},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 296""",
    longDesc = 
u"""
""",
)

entry(
    index = 1368,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30932, 'd12': 1.37145, 'd13': 2.68013},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 297""",
    longDesc = 
u"""
""",
)

entry(
    index = 1369,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.21389, 'd12': 1.51956, 'd13': 2.73063},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 298""",
    longDesc = 
u"""
""",
)

entry(
    index = 1370,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12316, 'd12': 1.42941, 'd13': 2.51147},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 299""",
    longDesc = 
u"""
""",
)

entry(
    index = 1371,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.9018, 'd12': 1.33968, 'd13': 2.22722},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 300""",
    longDesc = 
u"""
""",
)

entry(
    index = 1372,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21817, 'd12': 1.30467, 'd13': 2.402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 301""",
    longDesc = 
u"""
""",
)

entry(
    index = 1373,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1423, 'd12': 1.3887, 'd13': 2.49413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 302""",
    longDesc = 
u"""
""",
)

entry(
    index = 1374,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25393, 'd12': 1.43653, 'd13': 2.68602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 303""",
    longDesc = 
u"""
""",
)

entry(
    index = 1375,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26872, 'd12': 1.3766, 'd13': 2.64367},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 304""",
    longDesc = 
u"""
""",
)

entry(
    index = 1376,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23161, 'd12': 1.48049, 'd13': 2.7063},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 305""",
    longDesc = 
u"""
""",
)

entry(
    index = 1377,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21282, 'd12': 1.52012, 'd13': 2.73203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 306""",
    longDesc = 
u"""
""",
)

entry(
    index = 1378,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18263, 'd12': 1.64989, 'd13': 2.82623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 307""",
    longDesc = 
u"""
""",
)

entry(
    index = 1379,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28719, 'd12': 1.36923, 'd13': 2.65352},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 308""",
    longDesc = 
u"""
""",
)

entry(
    index = 1380,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.06073, 'd12': 1.63906, 'd13': 2.67112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 309""",
    longDesc = 
u"""
""",
)

entry(
    index = 1381,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.41201, 'd12': 1.33681, 'd13': 2.74352},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 310""",
    longDesc = 
u"""
""",
)

entry(
    index = 1382,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29925, 'd12': 1.45701, 'd13': 2.75322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 311""",
    longDesc = 
u"""
""",
)

entry(
    index = 1383,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1896, 'd12': 1.35579, 'd13': 2.54517},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 312""",
    longDesc = 
u"""
""",
)

entry(
    index = 1384,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,D} {4,S}
2 *2 H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19842, 'd12': 1.34673, 'd13': 2.54512},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 313""",
    longDesc = 
u"""
""",
)

entry(
    index = 1385,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36509, 'd12': 1.37871, 'd13': 2.7437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 314""",
    longDesc = 
u"""
""",
)

entry(
    index = 1386,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.346, 'd12': 1.39566, 'd13': 2.7406},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 315""",
    longDesc = 
u"""
""",
)

entry(
    index = 1387,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2966, 'd12': 1.47435, 'd13': 2.77043},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 316""",
    longDesc = 
u"""
""",
)

entry(
    index = 1388,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31876, 'd12': 1.43306, 'd13': 2.75032},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 317""",
    longDesc = 
u"""
""",
)

entry(
    index = 1389,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3079, 'd12': 1.44466, 'd13': 2.74542},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 318""",
    longDesc = 
u"""
""",
)

entry(
    index = 1390,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31165, 'd12': 1.43245, 'd13': 2.7418},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 319""",
    longDesc = 
u"""
""",
)

entry(
    index = 1391,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1892, 'd12': 1.35885, 'd13': 2.54765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 320""",
    longDesc = 
u"""
""",
)

entry(
    index = 1392,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.21905, 'd12': 1.35535, 'd13': 2.57338},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 321""",
    longDesc = 
u"""
""",
)

entry(
    index = 1393,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34325, 'd12': 1.38428, 'd13': 2.71004},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 322""",
    longDesc = 
u"""
""",
)

entry(
    index = 1394,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31117, 'd12': 1.422, 'd13': 2.72112},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 323""",
    longDesc = 
u"""
""",
)

entry(
    index = 1395,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2927, 'd12': 1.46414, 'd13': 2.74909},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 324""",
    longDesc = 
u"""
""",
)

entry(
    index = 1396,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27717, 'd12': 1.41, 'd13': 2.68716},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 325""",
    longDesc = 
u"""
""",
)

entry(
    index = 1397,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20382, 'd12': 1.57265, 'd13': 2.77343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 326""",
    longDesc = 
u"""
""",
)

entry(
    index = 1398,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.841684, 'd12': 1.49513, 'd13': 2.33681},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 327""",
    longDesc = 
u"""
""",
)

entry(
    index = 1399,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.06245, 'd12': 1.5254, 'd13': 2.58634},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 328""",
    longDesc = 
u"""
""",
)

entry(
    index = 1400,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18795, 'd12': 1.61958, 'd13': 2.80652},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 329""",
    longDesc = 
u"""
""",
)

entry(
    index = 1401,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19841, 'd12': 1.5714, 'd13': 2.76953},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 330""",
    longDesc = 
u"""
""",
)

entry(
    index = 1402,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17338, 'd12': 1.68593, 'd13': 2.85891},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 331""",
    longDesc = 
u"""
""",
)

entry(
    index = 1403,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22722, 'd12': 1.50087, 'd13': 2.72783},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 332""",
    longDesc = 
u"""
""",
)

entry(
    index = 1404,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21578, 'd12': 1.53278, 'd13': 2.74802},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 333""",
    longDesc = 
u"""
""",
)

entry(
    index = 1405,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32045, 'd12': 1.3333, 'd13': 2.65337},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 334""",
    longDesc = 
u"""
""",
)

entry(
    index = 1406,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19765, 'd12': 1.60895, 'd13': 2.8065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 335""",
    longDesc = 
u"""
""",
)

entry(
    index = 1407,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2363, 'd12': 1.4903, 'd13': 2.72627},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 336""",
    longDesc = 
u"""
""",
)

entry(
    index = 1408,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.27494, 'd12': 1.47875, 'd13': 2.7441},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 337""",
    longDesc = 
u"""
""",
)

entry(
    index = 1409,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3353, 'd12': 1.37079, 'd13': 2.70413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 338""",
    longDesc = 
u"""
""",
)

entry(
    index = 1410,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31238, 'd12': 1.42485, 'd13': 2.73645},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 339""",
    longDesc = 
u"""
""",
)

entry(
    index = 1411,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.27581, 'd12': 1.24878, 'd13': 2.52443},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 340""",
    longDesc = 
u"""
""",
)

entry(
    index = 1412,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15338, 'd12': 1.4014, 'd13': 2.55064},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 341""",
    longDesc = 
u"""
""",
)

entry(
    index = 1413,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13681, 'd12': 1.42331, 'd13': 2.55943},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 342""",
    longDesc = 
u"""
""",
)

entry(
    index = 1414,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20843, 'd12': 1.34092, 'd13': 2.54924},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 343""",
    longDesc = 
u"""
""",
)

entry(
    index = 1415,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.08962, 'd12': 1.30897, 'd13': 2.36795},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 344""",
    longDesc = 
u"""
""",
)

entry(
    index = 1416,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.30766, 'd12': 1.21694, 'd13': 2.52459},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 345""",
    longDesc = 
u"""
""",
)

entry(
    index = 1417,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35935, 'd12': 1.36898, 'd13': 2.71107},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 346""",
    longDesc = 
u"""
""",
)

entry(
    index = 1418,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25137, 'd12': 1.29497, 'd13': 2.54477},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 347""",
    longDesc = 
u"""
""",
)

entry(
    index = 1419,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29288, 'd12': 1.39814, 'd13': 2.68982},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 348""",
    longDesc = 
u"""
""",
)

entry(
    index = 1420,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24358, 'd12': 1.50287, 'd13': 2.74346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 349""",
    longDesc = 
u"""
""",
)

entry(
    index = 1421,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27691, 'd12': 1.45635, 'd13': 2.73245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 350""",
    longDesc = 
u"""
""",
)

entry(
    index = 1422,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32704, 'd12': 1.40453, 'd13': 2.71695},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 351""",
    longDesc = 
u"""
""",
)

entry(
    index = 1423,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27233, 'd12': 1.46945, 'd13': 2.74161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 352""",
    longDesc = 
u"""
""",
)

entry(
    index = 1424,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32392, 'd12': 1.40813, 'd13': 2.72161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 353""",
    longDesc = 
u"""
""",
)

entry(
    index = 1425,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23897, 'd12': 1.54225, 'd13': 2.78097},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 354""",
    longDesc = 
u"""
""",
)

entry(
    index = 1426,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28487, 'd12': 1.48069, 'd13': 2.7573},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 355""",
    longDesc = 
u"""
""",
)

entry(
    index = 1427,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30369, 'd12': 1.44844, 'd13': 2.74594},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 356""",
    longDesc = 
u"""
""",
)

entry(
    index = 1428,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29562, 'd12': 1.40254, 'd13': 2.69763},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 357""",
    longDesc = 
u"""
""",
)

entry(
    index = 1429,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15905, 'd12': 1.34532, 'd13': 2.50237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 358""",
    longDesc = 
u"""
""",
)

entry(
    index = 1430,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34346, 'd12': 1.36685, 'd13': 2.70935},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 359""",
    longDesc = 
u"""
""",
)

entry(
    index = 1431,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32115, 'd12': 1.41397, 'd13': 2.73455},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 360""",
    longDesc = 
u"""
""",
)

entry(
    index = 1432,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32233, 'd12': 1.39197, 'd13': 2.71424},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 361""",
    longDesc = 
u"""
""",
)

entry(
    index = 1433,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34692, 'd12': 1.38667, 'd13': 2.73232},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 362""",
    longDesc = 
u"""
""",
)

entry(
    index = 1434,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27405, 'd12': 1.41606, 'd13': 2.68801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 363""",
    longDesc = 
u"""
""",
)

entry(
    index = 1435,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14532, 'd12': 1.34439, 'd13': 2.48689},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 364""",
    longDesc = 
u"""
""",
)

entry(
    index = 1436,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35146, 'd12': 1.3971, 'd13': 2.72129},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 365""",
    longDesc = 
u"""
""",
)

entry(
    index = 1437,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35312, 'd12': 1.38379, 'd13': 2.70705},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 366""",
    longDesc = 
u"""
""",
)

entry(
    index = 1438,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30486, 'd12': 1.42342, 'd13': 2.7282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 367""",
    longDesc = 
u"""
""",
)

entry(
    index = 1439,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.289, 'd12': 1.4712, 'd13': 2.75925},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 368""",
    longDesc = 
u"""
""",
)

entry(
    index = 1440,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29495, 'd12': 1.22322, 'd13': 2.51816},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 369""",
    longDesc = 
u"""
""",
)

entry(
    index = 1441,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21428, 'd12': 1.28956, 'd13': 2.43122},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 370""",
    longDesc = 
u"""
""",
)

entry(
    index = 1442,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.32124, 'd12': 1.40033, 'd13': 2.72027},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 371""",
    longDesc = 
u"""
""",
)

entry(
    index = 1443,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34611, 'd12': 1.41519, 'd13': 2.75749},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 372""",
    longDesc = 
u"""
""",
)

entry(
    index = 1444,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30179, 'd12': 1.41789, 'd13': 2.71733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 373""",
    longDesc = 
u"""
""",
)

entry(
    index = 1445,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29585, 'd12': 1.479, 'd13': 2.769},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 374""",
    longDesc = 
u"""
""",
)

entry(
    index = 1446,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15072, 'd12': 1.40908, 'd13': 2.55872},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 375""",
    longDesc = 
u"""
""",
)

entry(
    index = 1447,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22644, 'd12': 1.33091, 'd13': 2.5551},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 376""",
    longDesc = 
u"""
""",
)

entry(
    index = 1448,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16802, 'd12': 1.3856, 'd13': 2.55167},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 377""",
    longDesc = 
u"""
""",
)

entry(
    index = 1449,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.25616, 'd12': 1.03208, 'd13': 2.28495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 378""",
    longDesc = 
u"""
""",
)

entry(
    index = 1450,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.26362, 'd12': 1.26764, 'd13': 2.52879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 379""",
    longDesc = 
u"""
""",
)

entry(
    index = 1451,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34244, 'd12': 1.37004, 'd13': 2.70934},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 380""",
    longDesc = 
u"""
""",
)

entry(
    index = 1452,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36275, 'd12': 1.38854, 'd13': 2.75065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 381""",
    longDesc = 
u"""
""",
)

entry(
    index = 1453,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22487, 'd12': 1.57828, 'd13': 2.79964},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 382""",
    longDesc = 
u"""
""",
)

entry(
    index = 1454,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32433, 'd12': 1.39692, 'd13': 2.71827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 383""",
    longDesc = 
u"""
""",
)

entry(
    index = 1455,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31046, 'd12': 1.40724, 'd13': 2.71494},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 384""",
    longDesc = 
u"""
""",
)

entry(
    index = 1456,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34608, 'd12': 1.40463, 'd13': 2.74465},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 385""",
    longDesc = 
u"""
""",
)

entry(
    index = 1457,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26802, 'd12': 1.48906, 'd13': 2.75507},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 386""",
    longDesc = 
u"""
""",
)

entry(
    index = 1458,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30388, 'd12': 1.47384, 'd13': 2.77606},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 387""",
    longDesc = 
u"""
""",
)

entry(
    index = 1459,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29455, 'd12': 1.44577, 'd13': 2.7385},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 388""",
    longDesc = 
u"""
""",
)

entry(
    index = 1460,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32518, 'd12': 1.44111, 'd13': 2.76238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 389""",
    longDesc = 
u"""
""",
)

entry(
    index = 1461,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23357, 'd12': 1.56044, 'd13': 2.79353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 390""",
    longDesc = 
u"""
""",
)

entry(
    index = 1462,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29908, 'd12': 1.41813, 'd13': 2.71518},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 391""",
    longDesc = 
u"""
""",
)

entry(
    index = 1463,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32309, 'd12': 1.38731, 'd13': 2.70918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 392""",
    longDesc = 
u"""
""",
)

entry(
    index = 1464,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23122, 'd12': 1.48978, 'd13': 2.71946},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 393""",
    longDesc = 
u"""
""",
)

entry(
    index = 1465,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35666, 'd12': 1.37981, 'd13': 2.67437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 394""",
    longDesc = 
u"""
""",
)

entry(
    index = 1466,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36471, 'd12': 1.39732, 'd13': 2.70692},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 395""",
    longDesc = 
u"""
""",
)

entry(
    index = 1467,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29123, 'd12': 1.42207, 'd13': 2.71297},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 396""",
    longDesc = 
u"""
""",
)

entry(
    index = 1468,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28849, 'd12': 1.48012, 'd13': 2.76623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 397""",
    longDesc = 
u"""
""",
)

entry(
    index = 1469,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26377, 'd12': 1.26723, 'd13': 2.5295},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 398""",
    longDesc = 
u"""
""",
)

entry(
    index = 1470,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34897, 'd12': 1.39807, 'd13': 2.7452},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 399""",
    longDesc = 
u"""
""",
)

entry(
    index = 1471,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2763, 'd12': 1.39662, 'd13': 2.65627},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 400""",
    longDesc = 
u"""
""",
)

entry(
    index = 1472,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34982, 'd12': 1.38898, 'd13': 2.73659},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 401""",
    longDesc = 
u"""
""",
)

entry(
    index = 1473,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37352, 'd12': 1.36152, 'd13': 2.66839},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 402""",
    longDesc = 
u"""
""",
)

entry(
    index = 1474,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34754, 'd12': 1.36122, 'd13': 2.70843},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 403""",
    longDesc = 
u"""
""",
)

entry(
    index = 1475,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27439, 'd12': 1.47498, 'd13': 2.74156},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 404""",
    longDesc = 
u"""
""",
)

entry(
    index = 1476,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15711, 'd12': 1.39255, 'd13': 2.54933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 405""",
    longDesc = 
u"""
""",
)

entry(
    index = 1477,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2659, 'd12': 1.48718, 'd13': 2.75167},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 406""",
    longDesc = 
u"""
""",
)

entry(
    index = 1478,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28048, 'd12': 1.45259, 'd13': 2.73265},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 407""",
    longDesc = 
u"""
""",
)

entry(
    index = 1479,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25105, 'd12': 1.52296, 'd13': 2.77378},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 408""",
    longDesc = 
u"""
""",
)

entry(
    index = 1480,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30539, 'd12': 1.41451, 'd13': 2.71983},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 409""",
    longDesc = 
u"""
""",
)

entry(
    index = 1481,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33988, 'd12': 1.36752, 'd13': 2.70732},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 410""",
    longDesc = 
u"""
""",
)

entry(
    index = 1482,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32146, 'd12': 1.4082, 'd13': 2.72864},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 411""",
    longDesc = 
u"""
""",
)

entry(
    index = 1483,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27052, 'd12': 1.25339, 'd13': 2.52391},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 412""",
    longDesc = 
u"""
""",
)

entry(
    index = 1484,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3002, 'd12': 1.414, 'd13': 2.71331},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 413""",
    longDesc = 
u"""
""",
)

entry(
    index = 1485,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.28855, 'd12': 1.23931, 'd13': 2.52786},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 414""",
    longDesc = 
u"""
""",
)

entry(
    index = 1486,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26732, 'd12': 1.42039, 'd13': 2.68765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 415""",
    longDesc = 
u"""
""",
)

entry(
    index = 1487,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21954, 'd12': 1.52273, 'd13': 2.73698},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 416""",
    longDesc = 
u"""
""",
)

entry(
    index = 1488,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.24711, 'd12': 1.30063, 'd13': 2.54774},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 417""",
    longDesc = 
u"""
""",
)

entry(
    index = 1489,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27052, 'd12': 1.41978, 'd13': 2.69014},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 418""",
    longDesc = 
u"""
""",
)

entry(
    index = 1490,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24287, 'd12': 1.46706, 'd13': 2.70985},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 419""",
    longDesc = 
u"""
""",
)

entry(
    index = 1491,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.08945, 'd12': 1.58035, 'd13': 2.66557},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 420""",
    longDesc = 
u"""
""",
)

entry(
    index = 1492,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34062, 'd12': 1.39938, 'd13': 2.73493},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 421""",
    longDesc = 
u"""
""",
)

entry(
    index = 1493,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30129, 'd12': 1.42796, 'd13': 2.72825},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 422""",
    longDesc = 
u"""
""",
)

entry(
    index = 1494,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23285, 'd12': 1.32469, 'd13': 2.55648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 423""",
    longDesc = 
u"""
""",
)

entry(
    index = 1495,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22023, 'd12': 1.33573, 'd13': 2.55506},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 424""",
    longDesc = 
u"""
""",
)

entry(
    index = 1496,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23278, 'd12': 1.31879, 'd13': 2.54995},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 425""",
    longDesc = 
u"""
""",
)

entry(
    index = 1497,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38181, 'd12': 1.3243, 'd13': 2.70604},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 426""",
    longDesc = 
u"""
""",
)

entry(
    index = 1498,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34882, 'd12': 1.38315, 'd13': 2.7317},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 427""",
    longDesc = 
u"""
""",
)

entry(
    index = 1499,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3026, 'd12': 1.4515, 'd13': 2.75339},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 428""",
    longDesc = 
u"""
""",
)

entry(
    index = 1500,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31705, 'd12': 1.42422, 'd13': 2.7398},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 429""",
    longDesc = 
u"""
""",
)

entry(
    index = 1501,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30064, 'd12': 1.42895, 'd13': 2.72899},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 430""",
    longDesc = 
u"""
""",
)

entry(
    index = 1502,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32504, 'd12': 1.40298, 'd13': 2.7275},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 431""",
    longDesc = 
u"""
""",
)

entry(
    index = 1503,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21498, 'd12': 1.53653, 'd13': 2.7511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 432""",
    longDesc = 
u"""
""",
)

entry(
    index = 1504,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35014, 'd12': 1.38226, 'd13': 2.72797},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 433""",
    longDesc = 
u"""
""",
)

entry(
    index = 1505,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28818, 'd12': 1.44255, 'd13': 2.73006},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 434""",
    longDesc = 
u"""
""",
)

entry(
    index = 1506,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33952, 'd12': 1.38556, 'd13': 2.72332},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 435""",
    longDesc = 
u"""
""",
)

entry(
    index = 1507,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30158, 'd12': 1.42766, 'd13': 2.72917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 436""",
    longDesc = 
u"""
""",
)

entry(
    index = 1508,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33603, 'd12': 1.39717, 'd13': 2.73031},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 437""",
    longDesc = 
u"""
""",
)

entry(
    index = 1509,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37843, 'd12': 1.37412, 'd13': 2.74968},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 438""",
    longDesc = 
u"""
""",
)

entry(
    index = 1510,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33753, 'd12': 1.40849, 'd13': 2.7456},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 439""",
    longDesc = 
u"""
""",
)

entry(
    index = 1511,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.22081, 'd12': 1.34227, 'd13': 2.56129},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 440""",
    longDesc = 
u"""
""",
)

entry(
    index = 1512,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.22373, 'd12': 1.32993, 'd13': 2.55323},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 441""",
    longDesc = 
u"""
""",
)

entry(
    index = 1513,
    reactant1 = """
1  *1 C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23401, 'd12': 1.54891, 'd13': 2.77926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 442""",
    longDesc = 
u"""
""",
)

entry(
    index = 1514,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.32307, 'd12': 1.43704, 'd13': 2.75649},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 443""",
    longDesc = 
u"""
""",
)

entry(
    index = 1515,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.3449, 'd12': 1.4158, 'd13': 2.74243},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 444""",
    longDesc = 
u"""
""",
)

entry(
    index = 1516,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30749, 'd12': 1.48217, 'd13': 2.7756},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 445""",
    longDesc = 
u"""
""",
)

entry(
    index = 1517,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35799, 'd12': 1.40241, 'd13': 2.74951},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 446""",
    longDesc = 
u"""
""",
)

entry(
    index = 1518,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39311, 'd12': 1.38926, 'd13': 2.78222},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 447""",
    longDesc = 
u"""
""",
)

entry(
    index = 1519,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34637, 'd12': 1.42115, 'd13': 2.76729},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 448""",
    longDesc = 
u"""
""",
)

entry(
    index = 1520,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29715, 'd12': 1.46021, 'd13': 2.7571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 449""",
    longDesc = 
u"""
""",
)

entry(
    index = 1521,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37034, 'd12': 1.40085, 'd13': 2.76176},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 450""",
    longDesc = 
u"""
""",
)

entry(
    index = 1522,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38769, 'd12': 1.39054, 'd13': 2.77622},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 451""",
    longDesc = 
u"""
""",
)

entry(
    index = 1523,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31025, 'd12': 1.44278, 'd13': 2.75033},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 452""",
    longDesc = 
u"""
""",
)

entry(
    index = 1524,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31835, 'd12': 1.44705, 'd13': 2.76111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 453""",
    longDesc = 
u"""
""",
)

entry(
    index = 1525,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.05815, 'd12': 1.56893, 'd13': 2.62141},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 454""",
    longDesc = 
u"""
""",
)

entry(
    index = 1526,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 0.847337, 'd12': 1.4952, 'd13': 2.34245},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 455""",
    longDesc = 
u"""
""",
)

entry(
    index = 1527,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17661, 'd12': 1.69328, 'd13': 2.86926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 456""",
    longDesc = 
u"""
""",
)

entry(
    index = 1528,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22941, 'd12': 1.5134, 'd13': 2.74253},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 457""",
    longDesc = 
u"""
""",
)

entry(
    index = 1529,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31336, 'd12': 1.35025, 'd13': 2.66355},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 458""",
    longDesc = 
u"""
""",
)

entry(
    index = 1530,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31451, 'd12': 1.35667, 'd13': 2.67053},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 459""",
    longDesc = 
u"""
""",
)

entry(
    index = 1531,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26578, 'd12': 1.37831, 'd13': 2.6419},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 460""",
    longDesc = 
u"""
""",
)

entry(
    index = 1532,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29177, 'd12': 1.39315, 'd13': 2.68488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 461""",
    longDesc = 
u"""
""",
)

entry(
    index = 1533,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23504, 'd12': 1.49798, 'd13': 2.73061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 462""",
    longDesc = 
u"""
""",
)

entry(
    index = 1534,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30416, 'd12': 0.96225, 'd13': 2.26271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 463""",
    longDesc = 
u"""
""",
)

entry(
    index = 1535,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2622, 'd12': 1.43164, 'd13': 2.69172},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 464""",
    longDesc = 
u"""
""",
)

entry(
    index = 1536,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27591, 'd12': 1.37772, 'd13': 2.65247},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 465""",
    longDesc = 
u"""
""",
)

entry(
    index = 1537,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29014, 'd12': 1.46922, 'd13': 2.74358},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 466""",
    longDesc = 
u"""
""",
)

entry(
    index = 1538,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20425, 'd12': 1.35535, 'd13': 2.55918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 467""",
    longDesc = 
u"""
""",
)

entry(
    index = 1539,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.19113, 'd12': 1.16334, 'd13': 2.34154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 468""",
    longDesc = 
u"""
""",
)

entry(
    index = 1540,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18712, 'd12': 1.36104, 'd13': 2.54519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 469""",
    longDesc = 
u"""
""",
)

entry(
    index = 1541,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35211, 'd12': 1.37029, 'd13': 2.7088},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 470""",
    longDesc = 
u"""
""",
)

entry(
    index = 1542,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36975, 'd12': 1.35672, 'd13': 2.72409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 471""",
    longDesc = 
u"""
""",
)

entry(
    index = 1543,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33781, 'd12': 1.4149, 'd13': 2.75114},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 472""",
    longDesc = 
u"""
""",
)

entry(
    index = 1544,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35061, 'd12': 1.39891, 'd13': 2.73131},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 473""",
    longDesc = 
u"""
""",
)

entry(
    index = 1545,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26262, 'd12': 1.47826, 'd13': 2.73345},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 474""",
    longDesc = 
u"""
""",
)

entry(
    index = 1546,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30263, 'd12': 1.42803, 'd13': 2.71906},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 475""",
    longDesc = 
u"""
""",
)

entry(
    index = 1547,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29459, 'd12': 1.46208, 'd13': 2.75378},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 476""",
    longDesc = 
u"""
""",
)

entry(
    index = 1548,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20557, 'd12': 1.57557, 'd13': 2.76642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 477""",
    longDesc = 
u"""
""",
)

entry(
    index = 1549,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30925, 'd12': 1.44174, 'd13': 2.73402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 478""",
    longDesc = 
u"""
""",
)

entry(
    index = 1550,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2602, 'd12': 1.5025, 'd13': 2.75386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 479""",
    longDesc = 
u"""
""",
)

entry(
    index = 1551,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28569, 'd12': 1.45939, 'd13': 2.73657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 480""",
    longDesc = 
u"""
""",
)

entry(
    index = 1552,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31667, 'd12': 1.41904, 'd13': 2.7347},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 481""",
    longDesc = 
u"""
""",
)

entry(
    index = 1553,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40976, 'd12': 1.33068, 'd13': 2.73102},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 482""",
    longDesc = 
u"""
""",
)

entry(
    index = 1554,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33999, 'd12': 1.40023, 'd13': 2.73812},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 483""",
    longDesc = 
u"""
""",
)

entry(
    index = 1555,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41187, 'd12': 1.34538, 'd13': 2.73639},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 484""",
    longDesc = 
u"""
""",
)

entry(
    index = 1556,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23017, 'd12': 1.53028, 'd13': 2.74519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 485""",
    longDesc = 
u"""
""",
)

entry(
    index = 1557,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34198, 'd12': 1.36646, 'd13': 2.70608},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 486""",
    longDesc = 
u"""
""",
)

entry(
    index = 1558,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5  *1 C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15182, 'd12': 1.40229, 'd13': 2.55364},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 487""",
    longDesc = 
u"""
""",
)

entry(
    index = 1559,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.3722, 'd12': 0.921406, 'd13': 2.29351},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 488""",
    longDesc = 
u"""
""",
)

entry(
    index = 1560,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14911, 'd12': 1.39767, 'd13': 2.5466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 489""",
    longDesc = 
u"""
""",
)

entry(
    index = 1561,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29561, 'd12': 1.42436, 'd13': 2.71976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 490""",
    longDesc = 
u"""
""",
)

entry(
    index = 1562,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30613, 'd12': 1.3869, 'd13': 2.69264},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 491""",
    longDesc = 
u"""
""",
)

entry(
    index = 1563,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29464, 'd12': 1.45347, 'd13': 2.72115},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 492""",
    longDesc = 
u"""
""",
)

entry(
    index = 1564,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25033, 'd12': 1.52223, 'd13': 2.77109},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 493""",
    longDesc = 
u"""
""",
)

entry(
    index = 1565,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32308, 'd12': 1.3796, 'd13': 2.70218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 494""",
    longDesc = 
u"""
""",
)

entry(
    index = 1566,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35333, 'd12': 1.35925, 'd13': 2.71199},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 495""",
    longDesc = 
u"""
""",
)

entry(
    index = 1567,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27552, 'd12': 1.41189, 'd13': 2.68619},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 496""",
    longDesc = 
u"""
""",
)

entry(
    index = 1568,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3166, 'd12': 1.4111, 'd13': 2.72353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 497""",
    longDesc = 
u"""
""",
)

entry(
    index = 1569,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34131, 'd12': 1.36478, 'd13': 2.70397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 498""",
    longDesc = 
u"""
""",
)

entry(
    index = 1570,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35471, 'd12': 1.35427, 'd13': 2.70828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 499""",
    longDesc = 
u"""
""",
)

entry(
    index = 1571,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32664, 'd12': 1.40477, 'd13': 2.72937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 500""",
    longDesc = 
u"""
""",
)

entry(
    index = 1572,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29628, 'd12': 1.4558, 'd13': 2.75088},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 501""",
    longDesc = 
u"""
""",
)

entry(
    index = 1573,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27166, 'd12': 1.48981, 'd13': 2.75918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 502""",
    longDesc = 
u"""
""",
)

entry(
    index = 1574,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27513, 'd12': 1.29083, 'd13': 2.56346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 503""",
    longDesc = 
u"""
""",
)

entry(
    index = 1575,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29226, 'd12': 1.26436, 'd13': 2.55636},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 504""",
    longDesc = 
u"""
""",
)

entry(
    index = 1576,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1007, 'd12': 1.29297, 'd13': 2.36587},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 505""",
    longDesc = 
u"""
""",
)

entry(
    index = 1577,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.11254, 'd12': 1.28509, 'd13': 2.35466},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 506""",
    longDesc = 
u"""
""",
)

entry(
    index = 1578,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22107, 'd12': 1.38764, 'd13': 2.60764},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 507""",
    longDesc = 
u"""
""",
)

entry(
    index = 1579,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23778, 'd12': 1.34824, 'd13': 2.58597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 508""",
    longDesc = 
u"""
""",
)

entry(
    index = 1580,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25494, 'd12': 1.31637, 'd13': 2.57087},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 509""",
    longDesc = 
u"""
""",
)

entry(
    index = 1581,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2485, 'd12': 1.33531, 'd13': 2.57495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 510""",
    longDesc = 
u"""
""",
)

entry(
    index = 1582,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23786, 'd12': 1.35139, 'd13': 2.58357},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 511""",
    longDesc = 
u"""
""",
)

entry(
    index = 1583,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2071, 'd12': 1.32962, 'd13': 2.53574},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 512""",
    longDesc = 
u"""
""",
)

entry(
    index = 1584,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.11146, 'd12': 1.41998, 'd13': 2.53061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 513""",
    longDesc = 
u"""
""",
)

entry(
    index = 1585,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27947, 'd12': 1.47185, 'd13': 2.73907},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 514""",
    longDesc = 
u"""
""",
)

entry(
    index = 1586,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20364, 'd12': 1.34221, 'd13': 2.54311},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 515""",
    longDesc = 
u"""
""",
)

entry(
    index = 1587,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37476, 'd12': 1.35988, 'd13': 2.72511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 516""",
    longDesc = 
u"""
""",
)

entry(
    index = 1588,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32677, 'd12': 1.43263, 'd13': 2.75306},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 517""",
    longDesc = 
u"""
""",
)

entry(
    index = 1589,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25494, 'd12': 1.50195, 'd13': 2.75148},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 518""",
    longDesc = 
u"""
""",
)

entry(
    index = 1590,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2758, 'd12': 1.48331, 'd13': 2.74918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 519""",
    longDesc = 
u"""
""",
)

entry(
    index = 1591,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29902, 'd12': 1.45507, 'd13': 2.7437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 520""",
    longDesc = 
u"""
""",
)

entry(
    index = 1592,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20924, 'd12': 1.55469, 'd13': 2.76225},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 521""",
    longDesc = 
u"""
""",
)

entry(
    index = 1593,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31295, 'd12': 1.43153, 'd13': 2.72826},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 522""",
    longDesc = 
u"""
""",
)

entry(
    index = 1594,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26998, 'd12': 1.48449, 'd13': 2.74554},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 523""",
    longDesc = 
u"""
""",
)

entry(
    index = 1595,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26032, 'd12': 1.29472, 'd13': 2.55282},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 524""",
    longDesc = 
u"""
""",
)

entry(
    index = 1596,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31069, 'd12': 1.4146, 'd13': 2.71524},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 525""",
    longDesc = 
u"""
""",
)

entry(
    index = 1597,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27873, 'd12': 1.46939, 'd13': 2.73755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 526""",
    longDesc = 
u"""
""",
)

entry(
    index = 1598,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13473, 'd12': 1.77539, 'd13': 2.8567},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 527""",
    longDesc = 
u"""
""",
)

entry(
    index = 1599,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41477, 'd12': 1.33572, 'd13': 2.74611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 528""",
    longDesc = 
u"""
""",
)

entry(
    index = 1600,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34214, 'd12': 1.39812, 'd13': 2.73691},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 529""",
    longDesc = 
u"""
""",
)

entry(
    index = 1601,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.42925, 'd12': 1.32478, 'd13': 2.74904},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 530""",
    longDesc = 
u"""
""",
)

entry(
    index = 1602,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27437, 'd12': 1.29147, 'd13': 2.56139},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 531""",
    longDesc = 
u"""
""",
)

entry(
    index = 1603,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.39534, 'd12': 1.3485, 'd13': 2.73601},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 532""",
    longDesc = 
u"""
""",
)

entry(
    index = 1604,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30554, 'd12': 1.43033, 'd13': 2.73549},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 533""",
    longDesc = 
u"""
""",
)

entry(
    index = 1605,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22888, 'd12': 1.32983, 'd13': 2.55778},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 534""",
    longDesc = 
u"""
""",
)

entry(
    index = 1606,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.2379, 'd12': 1.08399, 'd13': 2.32103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 535""",
    longDesc = 
u"""
""",
)

entry(
    index = 1607,
    reactant1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24721, 'd12': 1.30689, 'd13': 2.55389},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 536""",
    longDesc = 
u"""
""",
)

entry(
    index = 1608,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3836, 'd12': 1.35236, 'd13': 2.73459},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 537""",
    longDesc = 
u"""
""",
)

entry(
    index = 1609,
    reactant1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34647, 'd12': 1.38536, 'd13': 2.73158},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 538""",
    longDesc = 
u"""
""",
)

entry(
    index = 1610,
    reactant1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30834, 'd12': 1.45021, 'd13': 2.75849},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 539""",
    longDesc = 
u"""
""",
)

entry(
    index = 1611,
    reactant1 = """
1     C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32471, 'd12': 1.42413, 'd13': 2.74816},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 540""",
    longDesc = 
u"""
""",
)

entry(
    index = 1612,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27571, 'd12': 1.46516, 'd13': 2.74009},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 541""",
    longDesc = 
u"""
""",
)

entry(
    index = 1613,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30286, 'd12': 1.43311, 'd13': 2.73532},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 542""",
    longDesc = 
u"""
""",
)

entry(
    index = 1614,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32641, 'd12': 1.40728, 'd13': 2.73254},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 543""",
    longDesc = 
u"""
""",
)

entry(
    index = 1615,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35192, 'd12': 1.38674, 'd13': 2.73439},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 544""",
    longDesc = 
u"""
""",
)

entry(
    index = 1616,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.38216, 'd12': 1.3836, 'd13': 2.76484},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 545""",
    longDesc = 
u"""
""",
)

entry(
    index = 1617,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33976, 'd12': 1.38984, 'd13': 2.72832},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 546""",
    longDesc = 
u"""
""",
)

entry(
    index = 1618,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30418, 'd12': 1.43083, 'd13': 2.73393},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 547""",
    longDesc = 
u"""
""",
)

entry(
    index = 1619,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33664, 'd12': 1.4021, 'd13': 2.7349},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 548""",
    longDesc = 
u"""
""",
)

entry(
    index = 1620,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37374, 'd12': 1.385, 'd13': 2.7572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 549""",
    longDesc = 
u"""
""",
)

entry(
    index = 1621,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36752, 'd12': 1.37265, 'd13': 2.73991},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 550""",
    longDesc = 
u"""
""",
)

entry(
    index = 1622,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.37954, 'd12': 1.37093, 'd13': 2.74137},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 551""",
    longDesc = 
u"""
""",
)

entry(
    index = 1623,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.39866, 'd12': 1.34254, 'd13': 2.7296},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 552""",
    longDesc = 
u"""
""",
)

entry(
    index = 1624,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40445, 'd12': 1.34438, 'd13': 2.74589},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 553""",
    longDesc = 
u"""
""",
)

entry(
    index = 1625,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28076, 'd12': 1.28163, 'd13': 2.5505},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 554""",
    longDesc = 
u"""
""",
)

entry(
    index = 1626,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.09719, 'd12': 1.31178, 'd13': 2.37274},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 555""",
    longDesc = 
u"""
""",
)

entry(
    index = 1627,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28153, 'd12': 1.28376, 'd13': 2.55387},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 556""",
    longDesc = 
u"""
""",
)

entry(
    index = 1628,
    reactant1 = """
1 *2 H u0 p0 c0  {2,S}
2 *1 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12951, 'd12': 1.0033, 'd13': 2.13189},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 557""",
    longDesc = 
u"""
""",
)

entry(
    index = 1629,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21533, 'd12': 1.40386, 'd13': 2.61884},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 558""",
    longDesc = 
u"""
""",
)

entry(
    index = 1630,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2428, 'd12': 1.34264, 'd13': 2.5851},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 559""",
    longDesc = 
u"""
""",
)

entry(
    index = 1631,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20346, 'd12': 1.43921, 'd13': 2.64238},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 560""",
    longDesc = 
u"""
""",
)

entry(
    index = 1632,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28937, 'd12': 1.26042, 'd13': 2.5497},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 561""",
    longDesc = 
u"""
""",
)

entry(
    index = 1633,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25352, 'd12': 1.32826, 'd13': 2.57242},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 562""",
    longDesc = 
u"""
""",
)

entry(
    index = 1634,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30885, 'd12': 1.238, 'd13': 2.54504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 563""",
    longDesc = 
u"""
""",
)

entry(
    index = 1635,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17814, 'd12': 1.18494, 'd13': 2.36175},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 564""",
    longDesc = 
u"""
""",
)

entry(
    index = 1636,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.27934, 'd12': 1.47701, 'd13': 2.74805},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 565""",
    longDesc = 
u"""
""",
)

entry(
    index = 1637,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35903, 'd12': 1.35259, 'd13': 2.71095},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 566""",
    longDesc = 
u"""
""",
)

entry(
    index = 1638,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15057, 'd12': 1.42318, 'd13': 2.54778},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 567""",
    longDesc = 
u"""
""",
)

entry(
    index = 1639,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14131, 'd12': 1.41715, 'd13': 2.55597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 568""",
    longDesc = 
u"""
""",
)

entry(
    index = 1640,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.3793, 'd12': 0.910509, 'd13': 2.28925},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 569""",
    longDesc = 
u"""
""",
)

entry(
    index = 1641,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27318, 'd12': 1.4607, 'd13': 2.73105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 570""",
    longDesc = 
u"""
""",
)

entry(
    index = 1642,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2605, 'd12': 1.51782, 'd13': 2.77411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 571""",
    longDesc = 
u"""
""",
)

entry(
    index = 1643,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29783, 'd12': 1.39691, 'd13': 2.69417},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 572""",
    longDesc = 
u"""
""",
)

entry(
    index = 1644,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32647, 'd12': 1.37792, 'd13': 2.70384},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 573""",
    longDesc = 
u"""
""",
)

entry(
    index = 1645,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37365, 'd12': 1.34141, 'd13': 2.71447},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 574""",
    longDesc = 
u"""
""",
)

entry(
    index = 1646,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32584, 'd12': 1.39253, 'd13': 2.71732},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 575""",
    longDesc = 
u"""
""",
)

entry(
    index = 1647,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29189, 'd12': 1.38888, 'd13': 2.68057},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 576""",
    longDesc = 
u"""
""",
)

entry(
    index = 1648,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30392, 'd12': 1.42442, 'd13': 2.72808},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 577""",
    longDesc = 
u"""
""",
)

entry(
    index = 1649,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35632, 'd12': 1.35499, 'd13': 2.71012},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 578""",
    longDesc = 
u"""
""",
)

entry(
    index = 1650,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35404, 'd12': 1.35529, 'd13': 2.70845},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 579""",
    longDesc = 
u"""
""",
)

entry(
    index = 1651,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31902, 'd12': 1.41284, 'd13': 2.72837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 580""",
    longDesc = 
u"""
""",
)

entry(
    index = 1652,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12563, 'd12': 1.80797, 'd13': 2.93169},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 581""",
    longDesc = 
u"""
""",
)

entry(
    index = 1653,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28402, 'd12': 1.46532, 'd13': 2.74078},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 582""",
    longDesc = 
u"""
""",
)

entry(
    index = 1654,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.29554, 'd12': 1.44306, 'd13': 2.73801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 583""",
    longDesc = 
u"""
""",
)

entry(
    index = 1655,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27441, 'd12': 1.42229, 'd13': 2.69495},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 584""",
    longDesc = 
u"""
""",
)

entry(
    index = 1656,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28634, 'd12': 1.47934, 'd13': 2.75686},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 585""",
    longDesc = 
u"""
""",
)

entry(
    index = 1657,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36092, 'd12': 1.35438, 'd13': 2.71277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 586""",
    longDesc = 
u"""
""",
)

entry(
    index = 1658,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27934, 'd12': 1.47355, 'd13': 2.74281},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 587""",
    longDesc = 
u"""
""",
)

entry(
    index = 1659,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.05367, 'd12': 1.6743, 'd13': 2.72623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 588""",
    longDesc = 
u"""
""",
)

entry(
    index = 1660,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31595, 'd12': 1.39801, 'd13': 2.71349},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 589""",
    longDesc = 
u"""
""",
)

entry(
    index = 1661,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15796, 'd12': 1.39545, 'd13': 2.55229},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 590""",
    longDesc = 
u"""
""",
)

entry(
    index = 1662,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14781, 'd12': 1.41087, 'd13': 2.55822},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 591""",
    longDesc = 
u"""
""",
)

entry(
    index = 1663,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.26963, 'd12': 1.26019, 'd13': 2.52793},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 592""",
    longDesc = 
u"""
""",
)

entry(
    index = 1664,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16774, 'd12': 1.37445, 'd13': 2.54032},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 593""",
    longDesc = 
u"""
""",
)

entry(
    index = 1665,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33357, 'd12': 1.3788, 'd13': 2.71049},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 594""",
    longDesc = 
u"""
""",
)

entry(
    index = 1666,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33585, 'd12': 1.35261, 'd13': 2.6873},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 595""",
    longDesc = 
u"""
""",
)

entry(
    index = 1667,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24559, 'd12': 1.48044, 'd13': 2.72562},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 596""",
    longDesc = 
u"""
""",
)

entry(
    index = 1668,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30695, 'd12': 1.41607, 'd13': 2.71966},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 597""",
    longDesc = 
u"""
""",
)

entry(
    index = 1669,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26559, 'd12': 1.49624, 'd13': 2.75825},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 598""",
    longDesc = 
u"""
""",
)

entry(
    index = 1670,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28538, 'd12': 1.45861, 'd13': 2.73933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 599""",
    longDesc = 
u"""
""",
)

entry(
    index = 1671,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31233, 'd12': 1.40471, 'd13': 2.71539},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 600""",
    longDesc = 
u"""
""",
)

entry(
    index = 1672,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33535, 'd12': 1.37628, 'd13': 2.70978},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 601""",
    longDesc = 
u"""
""",
)

entry(
    index = 1673,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23622, 'd12': 1.47669, 'd13': 2.71203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 602""",
    longDesc = 
u"""
""",
)

entry(
    index = 1674,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35078, 'd12': 1.37275, 'd13': 2.72312},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 603""",
    longDesc = 
u"""
""",
)

entry(
    index = 1675,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27612, 'd12': 1.25158, 'd13': 2.52572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 604""",
    longDesc = 
u"""
""",
)

entry(
    index = 1676,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33375, 'd12': 1.41505, 'd13': 2.74714},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 605""",
    longDesc = 
u"""
""",
)

entry(
    index = 1677,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33936, 'd12': 1.36551, 'd13': 2.70022},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 606""",
    longDesc = 
u"""
""",
)

entry(
    index = 1678,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31203, 'd12': 1.40034, 'd13': 2.71041},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 607""",
    longDesc = 
u"""
""",
)

entry(
    index = 1679,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35631, 'd12': 1.37705, 'd13': 2.67091},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 608""",
    longDesc = 
u"""
""",
)

entry(
    index = 1680,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33704, 'd12': 1.40264, 'd13': 2.73802},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 609""",
    longDesc = 
u"""
""",
)

entry(
    index = 1681,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33057, 'd12': 1.39548, 'd13': 2.72411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 610""",
    longDesc = 
u"""
""",
)

entry(
    index = 1682,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3433, 'd12': 1.39897, 'd13': 2.73757},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 611""",
    longDesc = 
u"""
""",
)

entry(
    index = 1683,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31145, 'd12': 1.41243, 'd13': 2.71838},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 612""",
    longDesc = 
u"""
""",
)

entry(
    index = 1684,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.32878, 'd12': 1.40216, 'd13': 2.72965},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 613""",
    longDesc = 
u"""
""",
)

entry(
    index = 1685,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16 *2 H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30846, 'd12': 1.40151, 'd13': 2.7039},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 614""",
    longDesc = 
u"""
""",
)

entry(
    index = 1686,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33902, 'd12': 1.39056, 'd13': 2.72877},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 615""",
    longDesc = 
u"""
""",
)

entry(
    index = 1687,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2336, 'd12': 1.55829, 'd13': 2.78933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 616""",
    longDesc = 
u"""
""",
)

entry(
    index = 1688,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31833, 'd12': 1.43053, 'd13': 2.74624},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 617""",
    longDesc = 
u"""
""",
)

entry(
    index = 1689,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34026, 'd12': 1.39071, 'd13': 2.72923},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 618""",
    longDesc = 
u"""
""",
)

entry(
    index = 1690,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33284, 'd12': 1.43153, 'd13': 2.76379},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 619""",
    longDesc = 
u"""
""",
)

entry(
    index = 1691,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25229, 'd12': 1.52683, 'd13': 2.77633},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 620""",
    longDesc = 
u"""
""",
)

entry(
    index = 1692,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19012, 'd12': 1.63851, 'd13': 2.81856},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 621""",
    longDesc = 
u"""
""",
)

entry(
    index = 1693,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3148, 'd12': 1.4198, 'd13': 2.73394},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 622""",
    longDesc = 
u"""
""",
)

entry(
    index = 1694,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22131, 'd12': 1.56451, 'd13': 2.77962},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 623""",
    longDesc = 
u"""
""",
)

entry(
    index = 1695,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31788, 'd12': 1.42476, 'd13': 2.74138},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 624""",
    longDesc = 
u"""
""",
)

entry(
    index = 1696,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35278, 'd12': 1.38353, 'd13': 2.7341},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 625""",
    longDesc = 
u"""
""",
)

entry(
    index = 1697,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1579, 'd12': 1.33456, 'd13': 2.48586},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 626""",
    longDesc = 
u"""
""",
)

entry(
    index = 1698,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19982, 'd12': 1.62473, 'd13': 2.82455},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 627""",
    longDesc = 
u"""
""",
)

entry(
    index = 1699,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18206, 'd12': 1.68226, 'd13': 2.86093},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 628""",
    longDesc = 
u"""
""",
)

entry(
    index = 1700,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19329, 'd12': 1.64434, 'd13': 2.83353},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 629""",
    longDesc = 
u"""
""",
)

entry(
    index = 1701,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30115, 'd12': 1.45582, 'd13': 2.75626},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 630""",
    longDesc = 
u"""
""",
)

entry(
    index = 1702,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.33739, 'd12': 0.938574, 'd13': 2.27402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 631""",
    longDesc = 
u"""
""",
)

entry(
    index = 1703,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.27685, 'd12': 1.24166, 'd13': 2.51712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 632""",
    longDesc = 
u"""
""",
)

entry(
    index = 1704,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24308, 'd12': 1.25839, 'd13': 2.48813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 633""",
    longDesc = 
u"""
""",
)

entry(
    index = 1705,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16062, 'd12': 1.45274, 'd13': 2.6078},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 634""",
    longDesc = 
u"""
""",
)

entry(
    index = 1706,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24532, 'd12': 1.46236, 'd13': 2.70694},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 635""",
    longDesc = 
u"""
""",
)

entry(
    index = 1707,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33122, 'd12': 1.3339, 'd13': 2.66472},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 636""",
    longDesc = 
u"""
""",
)

entry(
    index = 1708,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31227, 'd12': 1.36664, 'd13': 2.67788},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 637""",
    longDesc = 
u"""
""",
)

entry(
    index = 1709,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37166, 'd12': 1.36495, 'd13': 2.73596},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 638""",
    longDesc = 
u"""
""",
)

entry(
    index = 1710,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32921, 'd12': 1.39799, 'd13': 2.72657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 639""",
    longDesc = 
u"""
""",
)

entry(
    index = 1711,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34874, 'd12': 1.38932, 'd13': 2.73597},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 640""",
    longDesc = 
u"""
""",
)

entry(
    index = 1712,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32196, 'd12': 1.42214, 'd13': 2.74268},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 641""",
    longDesc = 
u"""
""",
)

entry(
    index = 1713,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35009, 'd12': 1.39391, 'd13': 2.74355},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 642""",
    longDesc = 
u"""
""",
)

entry(
    index = 1714,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35718, 'd12': 1.3301, 'd13': 2.68643},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 643""",
    longDesc = 
u"""
""",
)

entry(
    index = 1715,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30102, 'd12': 1.37501, 'd13': 2.6748},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 644""",
    longDesc = 
u"""
""",
)

entry(
    index = 1716,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21385, 'd12': 1.55167, 'd13': 2.76503},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 645""",
    longDesc = 
u"""
""",
)

entry(
    index = 1717,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33257, 'd12': 1.34532, 'd13': 2.67783},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 646""",
    longDesc = 
u"""
""",
)

entry(
    index = 1718,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26531, 'd12': 1.48521, 'd13': 2.75003},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 647""",
    longDesc = 
u"""
""",
)

entry(
    index = 1719,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28762, 'd12': 1.45393, 'd13': 2.74141},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 648""",
    longDesc = 
u"""
""",
)

entry(
    index = 1720,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26829, 'd12': 1.50055, 'd13': 2.76673},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 649""",
    longDesc = 
u"""
""",
)

entry(
    index = 1721,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21237, 'd12': 1.54964, 'd13': 2.75163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 650""",
    longDesc = 
u"""
""",
)

entry(
    index = 1722,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18264, 'd12': 1.65468, 'd13': 2.83635},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 651""",
    longDesc = 
u"""
""",
)

entry(
    index = 1723,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32565, 'd12': 1.42942, 'd13': 2.75428},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 652""",
    longDesc = 
u"""
""",
)

entry(
    index = 1724,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30877, 'd12': 1.4531, 'd13': 2.74512},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 653""",
    longDesc = 
u"""
""",
)

entry(
    index = 1725,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28864, 'd12': 1.46011, 'd13': 2.73855},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 654""",
    longDesc = 
u"""
""",
)

entry(
    index = 1726,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27264, 'd12': 1.49449, 'd13': 2.75511},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 655""",
    longDesc = 
u"""
""",
)

entry(
    index = 1727,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19972, 'd12': 1.58313, 'd13': 2.78194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 656""",
    longDesc = 
u"""
""",
)

entry(
    index = 1728,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30282, 'd12': 1.43997, 'd13': 2.73277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 657""",
    longDesc = 
u"""
""",
)

entry(
    index = 1729,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28272, 'd12': 1.4795, 'd13': 2.75164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 658""",
    longDesc = 
u"""
""",
)

entry(
    index = 1730,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30123, 'd12': 1.43039, 'd13': 2.73035},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 659""",
    longDesc = 
u"""
""",
)

entry(
    index = 1731,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32843, 'd12': 1.43536, 'd13': 2.76096},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 660""",
    longDesc = 
u"""
""",
)

entry(
    index = 1732,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27778, 'd12': 1.47983, 'd13': 2.75507},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 661""",
    longDesc = 
u"""
""",
)

entry(
    index = 1733,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3084, 'd12': 1.47368, 'd13': 2.77214},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 662""",
    longDesc = 
u"""
""",
)

entry(
    index = 1734,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21968, 'd12': 1.5883, 'd13': 2.8075},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 663""",
    longDesc = 
u"""
""",
)

entry(
    index = 1735,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27489, 'd12': 1.42469, 'd13': 2.69939},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 664""",
    longDesc = 
u"""
""",
)

entry(
    index = 1736,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26714, 'd12': 1.48246, 'd13': 2.74948},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 665""",
    longDesc = 
u"""
""",
)

entry(
    index = 1737,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25239, 'd12': 1.52354, 'd13': 2.77492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 666""",
    longDesc = 
u"""
""",
)

entry(
    index = 1738,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,D}
2 *3 C u1 p0 c0  {1,D} {4,S}
3    O u0 p2 c0  {1,D}
4    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.26933, 'd12': 1.37308, 'd13': 2.64103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 667""",
    longDesc = 
u"""
""",
)

entry(
    index = 1739,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.14252, 'd12': 1.65247, 'd13': 2.71127},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 668""",
    longDesc = 
u"""
""",
)

entry(
    index = 1740,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {8,S}
2     C u0 p0 c0  {1,D} {4,S} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {7,S}
4  *3 C u1 p0 c0  {2,S} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.33014, 'd12': 1.43687, 'd13': 2.76348},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 669""",
    longDesc = 
u"""
""",
)

entry(
    index = 1741,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30449, 'd12': 1.48044, 'd13': 2.76837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 670""",
    longDesc = 
u"""
""",
)

entry(
    index = 1742,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27083, 'd12': 1.42417, 'd13': 2.68999},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 671""",
    longDesc = 
u"""
""",
)

entry(
    index = 1743,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26481, 'd12': 1.47417, 'd13': 2.73568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 672""",
    longDesc = 
u"""
""",
)

entry(
    index = 1744,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35254, 'd12': 1.37348, 'd13': 2.72445},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 673""",
    longDesc = 
u"""
""",
)

entry(
    index = 1745,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.35019, 'd12': 1.38442, 'd13': 2.72837},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 674""",
    longDesc = 
u"""
""",
)

entry(
    index = 1746,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28498, 'd12': 1.45333, 'd13': 2.73508},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 675""",
    longDesc = 
u"""
""",
)

entry(
    index = 1747,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32455, 'd12': 1.40834, 'd13': 2.73224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 676""",
    longDesc = 
u"""
""",
)

entry(
    index = 1748,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30722, 'd12': 1.45036, 'd13': 2.75734},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 677""",
    longDesc = 
u"""
""",
)

entry(
    index = 1749,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.22263, 'd12': 1.09787, 'd13': 2.3173},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 678""",
    longDesc = 
u"""
""",
)

entry(
    index = 1750,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.22285, 'd12': 1.34569, 'd13': 2.56657},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 679""",
    longDesc = 
u"""
""",
)

entry(
    index = 1751,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20714, 'd12': 1.33965, 'd13': 2.54547},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 680""",
    longDesc = 
u"""
""",
)

entry(
    index = 1752,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37122, 'd12': 1.35056, 'd13': 2.71768},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 681""",
    longDesc = 
u"""
""",
)

entry(
    index = 1753,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22818, 'd12': 1.53019, 'd13': 2.75642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 682""",
    longDesc = 
u"""
""",
)

entry(
    index = 1754,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34688, 'd12': 1.38535, 'd13': 2.73181},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 683""",
    longDesc = 
u"""
""",
)

entry(
    index = 1755,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3, 'd12': 1.46219, 'd13': 2.75883},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 684""",
    longDesc = 
u"""
""",
)

entry(
    index = 1756,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31956, 'd12': 1.42291, 'd13': 2.73315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 685""",
    longDesc = 
u"""
""",
)

entry(
    index = 1757,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23452, 'd12': 1.51629, 'd13': 2.74519},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 686""",
    longDesc = 
u"""
""",
)

entry(
    index = 1758,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3954, 'd12': 1.34229, 'd13': 2.71348},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 687""",
    longDesc = 
u"""
""",
)

entry(
    index = 1759,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29322, 'd12': 1.44589, 'd13': 2.73652},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 688""",
    longDesc = 
u"""
""",
)

entry(
    index = 1760,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37997, 'd12': 1.36905, 'd13': 2.74857},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 689""",
    longDesc = 
u"""
""",
)

entry(
    index = 1761,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37771, 'd12': 1.33674, 'd13': 2.70833},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 690""",
    longDesc = 
u"""
""",
)

entry(
    index = 1762,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28936, 'd12': 1.44228, 'd13': 2.72558},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 691""",
    longDesc = 
u"""
""",
)

entry(
    index = 1763,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.41012, 'd12': 1.32826, 'd13': 2.71484},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 692""",
    longDesc = 
u"""
""",
)

entry(
    index = 1764,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37952, 'd12': 1.36152, 'd13': 2.73696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 693""",
    longDesc = 
u"""
""",
)

entry(
    index = 1765,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36627, 'd12': 1.3631, 'd13': 2.72149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 694""",
    longDesc = 
u"""
""",
)

entry(
    index = 1766,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3851, 'd12': 1.35841, 'd13': 2.74085},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 695""",
    longDesc = 
u"""
""",
)

entry(
    index = 1767,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35184, 'd12': 1.37815, 'd13': 2.72755},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 696""",
    longDesc = 
u"""
""",
)

entry(
    index = 1768,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36832, 'd12': 1.37677, 'd13': 2.74479},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 697""",
    longDesc = 
u"""
""",
)

entry(
    index = 1769,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2757, 'd12': 1.47362, 'd13': 2.74741},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 698""",
    longDesc = 
u"""
""",
)

entry(
    index = 1770,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34989, 'd12': 1.37881, 'd13': 2.72856},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 699""",
    longDesc = 
u"""
""",
)

entry(
    index = 1771,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32895, 'd12': 1.41594, 'd13': 2.74279},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 700""",
    longDesc = 
u"""
""",
)

entry(
    index = 1772,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1401, 'd12': 1.47976, 'd13': 2.61975},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 701""",
    longDesc = 
u"""
""",
)

entry(
    index = 1773,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3281, 'd12': 1.41226, 'd13': 2.74016},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 702""",
    longDesc = 
u"""
""",
)

entry(
    index = 1774,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34321, 'd12': 1.38785, 'd13': 2.73002},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 703""",
    longDesc = 
u"""
""",
)

entry(
    index = 1775,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22344, 'd12': 1.54588, 'd13': 2.76789},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 704""",
    longDesc = 
u"""
""",
)

entry(
    index = 1776,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29743, 'd12': 1.44116, 'd13': 2.73813},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 705""",
    longDesc = 
u"""
""",
)

entry(
    index = 1777,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20128, 'd12': 1.57381, 'd13': 2.77437},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 706""",
    longDesc = 
u"""
""",
)

entry(
    index = 1778,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31622, 'd12': 1.42495, 'd13': 2.72863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 707""",
    longDesc = 
u"""
""",
)

entry(
    index = 1779,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27438, 'd12': 1.47255, 'd13': 2.74499},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 708""",
    longDesc = 
u"""
""",
)

entry(
    index = 1780,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34491, 'd12': 1.41542, 'd13': 2.75676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 709""",
    longDesc = 
u"""
""",
)

entry(
    index = 1781,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31199, 'd12': 1.41, 'd13': 2.72163},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 710""",
    longDesc = 
u"""
""",
)

entry(
    index = 1782,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27818, 'd12': 1.46518, 'd13': 2.74276},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 711""",
    longDesc = 
u"""
""",
)

entry(
    index = 1783,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21017, 'd12': 1.53617, 'd13': 2.73795},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 712""",
    longDesc = 
u"""
""",
)

entry(
    index = 1784,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30864, 'd12': 1.43405, 'd13': 2.74148},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 713""",
    longDesc = 
u"""
""",
)

entry(
    index = 1785,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33631, 'd12': 1.41458, 'd13': 2.74877},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 714""",
    longDesc = 
u"""
""",
)

entry(
    index = 1786,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34695, 'd12': 1.39173, 'd13': 2.72477},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 715""",
    longDesc = 
u"""
""",
)

entry(
    index = 1787,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33938, 'd12': 1.39359, 'd13': 2.73186},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 716""",
    longDesc = 
u"""
""",
)

entry(
    index = 1788,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34986, 'd12': 1.38488, 'd13': 2.73332},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 717""",
    longDesc = 
u"""
""",
)

entry(
    index = 1789,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36738, 'd12': 1.37426, 'd13': 2.73994},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 718""",
    longDesc = 
u"""
""",
)

entry(
    index = 1790,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34165, 'd12': 1.40708, 'd13': 2.74711},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 719""",
    longDesc = 
u"""
""",
)

entry(
    index = 1791,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.19936, 'd12': 1.1583, 'd13': 2.3568},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 720""",
    longDesc = 
u"""
""",
)

entry(
    index = 1792,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16881, 'd12': 1.46014, 'd13': 2.62033},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 721""",
    longDesc = 
u"""
""",
)

entry(
    index = 1793,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34265, 'd12': 1.3832, 'd13': 2.72522},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 722""",
    longDesc = 
u"""
""",
)

entry(
    index = 1794,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34314, 'd12': 1.40851, 'd13': 2.74987},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 723""",
    longDesc = 
u"""
""",
)

entry(
    index = 1795,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35944, 'd12': 1.38091, 'd13': 2.73876},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 724""",
    longDesc = 
u"""
""",
)

entry(
    index = 1796,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25939, 'd12': 1.49674, 'd13': 2.75602},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 725""",
    longDesc = 
u"""
""",
)

entry(
    index = 1797,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27651, 'd12': 1.47253, 'd13': 2.74872},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 726""",
    longDesc = 
u"""
""",
)

entry(
    index = 1798,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19739, 'd12': 1.58885, 'd13': 2.7861},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 727""",
    longDesc = 
u"""
""",
)

entry(
    index = 1799,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29448, 'd12': 1.45602, 'd13': 2.74229},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 728""",
    longDesc = 
u"""
""",
)

entry(
    index = 1800,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.31816, 'd12': 1.44267, 'd13': 2.76081},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 729""",
    longDesc = 
u"""
""",
)

entry(
    index = 1801,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29719, 'd12': 1.42671, 'd13': 2.7219},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 730""",
    longDesc = 
u"""
""",
)

entry(
    index = 1802,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26058, 'd12': 1.49379, 'd13': 2.75431},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 731""",
    longDesc = 
u"""
""",
)

entry(
    index = 1803,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23182, 'd12': 1.49329, 'd13': 2.71344},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 732""",
    longDesc = 
u"""
""",
)

entry(
    index = 1804,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,D}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30777, 'd12': 1.44529, 'd13': 2.75095},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 733""",
    longDesc = 
u"""
""",
)

entry(
    index = 1805,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.32022, 'd12': 1.42553, 'd13': 2.74571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 734""",
    longDesc = 
u"""
""",
)

entry(
    index = 1806,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30869, 'd12': 1.4458, 'd13': 2.7522},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 735""",
    longDesc = 
u"""
""",
)

entry(
    index = 1807,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20768, 'd12': 1.5832, 'd13': 2.79038},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 736""",
    longDesc = 
u"""
""",
)

entry(
    index = 1808,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32625, 'd12': 1.40881, 'd13': 2.72158},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 737""",
    longDesc = 
u"""
""",
)

entry(
    index = 1809,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35127, 'd12': 1.37804, 'd13': 2.72771},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 738""",
    longDesc = 
u"""
""",
)

entry(
    index = 1810,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40395, 'd12': 1.28313, 'd13': 2.68703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 739""",
    longDesc = 
u"""
""",
)

entry(
    index = 1811,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.45849, 'd12': 1.09066, 'd13': 2.54912},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 740""",
    longDesc = 
u"""
""",
)

entry(
    index = 1812,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35429, 'd12': 1.31078, 'd13': 2.66504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 741""",
    longDesc = 
u"""
""",
)

entry(
    index = 1813,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19668, 'd12': 1.59454, 'd13': 2.79109},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 742""",
    longDesc = 
u"""
""",
)

entry(
    index = 1814,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17201, 'd12': 1.71185, 'd13': 2.8827},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 743""",
    longDesc = 
u"""
""",
)

entry(
    index = 1815,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36499, 'd12': 1.30259, 'd13': 2.6671},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 744""",
    longDesc = 
u"""
""",
)

entry(
    index = 1816,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37251, 'd12': 1.13164, 'd13': 2.50155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 745""",
    longDesc = 
u"""
""",
)

entry(
    index = 1817,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.244, 'd12': 1.45747, 'd13': 2.69917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 746""",
    longDesc = 
u"""
""",
)

entry(
    index = 1818,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30103, 'd12': 1.39639, 'd13': 2.69685},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 747""",
    longDesc = 
u"""
""",
)

entry(
    index = 1819,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27988, 'd12': 0.993558, 'd13': 2.27252},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 748""",
    longDesc = 
u"""
""",
)

entry(
    index = 1820,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2888, 'd12': 1.40786, 'd13': 2.69653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 749""",
    longDesc = 
u"""
""",
)

entry(
    index = 1821,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *1 C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2564, 'd12': 1.44418, 'd13': 2.69996},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 750""",
    longDesc = 
u"""
""",
)

entry(
    index = 1822,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25328, 'd12': 1.44711, 'd13': 2.69988},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 751""",
    longDesc = 
u"""
""",
)

entry(
    index = 1823,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24408, 'd12': 1.45798, 'd13': 2.70165},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 752""",
    longDesc = 
u"""
""",
)

entry(
    index = 1824,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27421, 'd12': 1.42601, 'd13': 2.7002},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 753""",
    longDesc = 
u"""
""",
)

entry(
    index = 1825,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24702, 'd12': 1.45919, 'd13': 2.70571},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 754""",
    longDesc = 
u"""
""",
)

entry(
    index = 1826,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38604, 'd12': 1.31732, 'd13': 2.69931},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 755""",
    longDesc = 
u"""
""",
)

entry(
    index = 1827,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25943, 'd12': 1.49221, 'd13': 2.7509},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 756""",
    longDesc = 
u"""
""",
)

entry(
    index = 1828,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26416, 'd12': 1.40293, 'd13': 2.65444},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 757""",
    longDesc = 
u"""
""",
)

entry(
    index = 1829,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35775, 'd12': 1.34821, 'd13': 2.70535},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 758""",
    longDesc = 
u"""
""",
)

entry(
    index = 1830,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31063, 'd12': 1.38929, 'd13': 2.69985},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 759""",
    longDesc = 
u"""
""",
)

entry(
    index = 1831,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37758, 'd12': 1.33055, 'd13': 2.70743},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 760""",
    longDesc = 
u"""
""",
)

entry(
    index = 1832,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25435, 'd12': 1.26546, 'd13': 2.51716},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 761""",
    longDesc = 
u"""
""",
)

entry(
    index = 1833,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35687, 'd12': 1.34315, 'd13': 2.69805},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 762""",
    longDesc = 
u"""
""",
)

entry(
    index = 1834,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31841, 'd12': 1.37733, 'd13': 2.69501},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 763""",
    longDesc = 
u"""
""",
)

entry(
    index = 1835,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31605, 'd12': 1.38053, 'd13': 2.69658},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 764""",
    longDesc = 
u"""
""",
)

entry(
    index = 1836,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3439, 'd12': 1.35326, 'd13': 2.69708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 765""",
    longDesc = 
u"""
""",
)

entry(
    index = 1837,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.23374, 'd12': 1.29652, 'd13': 2.52852},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 766""",
    longDesc = 
u"""
""",
)

entry(
    index = 1838,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32895, 'd12': 1.37696, 'd13': 2.7057},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 767""",
    longDesc = 
u"""
""",
)

entry(
    index = 1839,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.34382, 'd12': 1.36424, 'd13': 2.70745},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 768""",
    longDesc = 
u"""
""",
)

entry(
    index = 1840,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26789, 'd12': 1.47969, 'd13': 2.74621},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 769""",
    longDesc = 
u"""
""",
)

entry(
    index = 1841,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.36623, 'd12': 0.926756, 'd13': 2.2926},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 770""",
    longDesc = 
u"""
""",
)

entry(
    index = 1842,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.29495, 'd12': 1.23386, 'd13': 2.52865},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 771""",
    longDesc = 
u"""
""",
)

entry(
    index = 1843,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30243, 'd12': 1.42189, 'd13': 2.72373},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 772""",
    longDesc = 
u"""
""",
)

entry(
    index = 1844,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25946, 'd12': 1.49721, 'd13': 2.75537},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 773""",
    longDesc = 
u"""
""",
)

entry(
    index = 1845,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29398, 'd12': 1.40659, 'd13': 2.69995},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 774""",
    longDesc = 
u"""
""",
)

entry(
    index = 1846,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3534, 'd12': 1.35792, 'd13': 2.71103},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 775""",
    longDesc = 
u"""
""",
)

entry(
    index = 1847,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33201, 'd12': 1.38349, 'd13': 2.7155},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 776""",
    longDesc = 
u"""
""",
)

entry(
    index = 1848,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27402, 'd12': 1.41402, 'd13': 2.68794},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 777""",
    longDesc = 
u"""
""",
)

entry(
    index = 1849,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31625, 'd12': 1.41319, 'd13': 2.72846},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 778""",
    longDesc = 
u"""
""",
)

entry(
    index = 1850,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35094, 'd12': 1.35807, 'd13': 2.70887},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 779""",
    longDesc = 
u"""
""",
)

entry(
    index = 1851,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28748, 'd12': 1.23729, 'd13': 2.52401},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 780""",
    longDesc = 
u"""
""",
)

entry(
    index = 1852,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30047, 'd12': 1.46329, 'd13': 2.7611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 781""",
    longDesc = 
u"""
""",
)

entry(
    index = 1853,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2979, 'd12': 1.42317, 'd13': 2.71892},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 782""",
    longDesc = 
u"""
""",
)

entry(
    index = 1854,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35088, 'd12': 1.35622, 'd13': 2.7071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 783""",
    longDesc = 
u"""
""",
)

entry(
    index = 1855,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33252, 'd12': 1.39935, 'd13': 2.73164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 784""",
    longDesc = 
u"""
""",
)

entry(
    index = 1856,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3046, 'd12': 1.45348, 'd13': 2.75733},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 785""",
    longDesc = 
u"""
""",
)

entry(
    index = 1857,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30712, 'd12': 1.44973, 'd13': 2.7546},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 786""",
    longDesc = 
u"""
""",
)

entry(
    index = 1858,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.28708, 'd12': 1.4461, 'd13': 2.72767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 787""",
    longDesc = 
u"""
""",
)

entry(
    index = 1859,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {6,S}
2     C u0 p0 c0  {1,D} {4,S} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25759, 'd12': 1.49832, 'd13': 2.75592},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 788""",
    longDesc = 
u"""
""",
)

entry(
    index = 1860,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25576, 'd12': 1.5257, 'd13': 2.77724},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 789""",
    longDesc = 
u"""
""",
)

entry(
    index = 1861,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.29432, 'd12': 1.23463, 'd13': 2.52885},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 790""",
    longDesc = 
u"""
""",
)

entry(
    index = 1862,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1615, 'd12': 1.38587, 'd13': 2.54729},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 791""",
    longDesc = 
u"""
""",
)

entry(
    index = 1863,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30521, 'd12': 1.41923, 'd13': 2.72297},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 792""",
    longDesc = 
u"""
""",
)

entry(
    index = 1864,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27548, 'd12': 1.4174, 'd13': 2.69251},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 793""",
    longDesc = 
u"""
""",
)

entry(
    index = 1865,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32601, 'd12': 1.42051, 'd13': 2.74369},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 794""",
    longDesc = 
u"""
""",
)

entry(
    index = 1866,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35413, 'd12': 1.3595, 'd13': 2.71337},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 795""",
    longDesc = 
u"""
""",
)

entry(
    index = 1867,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30072, 'd12': 1.43256, 'd13': 2.73271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 796""",
    longDesc = 
u"""
""",
)

entry(
    index = 1868,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30679, 'd12': 1.45014, 'd13': 2.75289},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 797""",
    longDesc = 
u"""
""",
)

entry(
    index = 1869,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28517, 'd12': 1.46886, 'd13': 2.75105},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 798""",
    longDesc = 
u"""
""",
)

entry(
    index = 1870,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {3,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26722, 'd12': 1.49678, 'd13': 2.76292},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 799""",
    longDesc = 
u"""
""",
)

entry(
    index = 1871,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35801, 'd12': 1.35855, 'd13': 2.7152},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 800""",
    longDesc = 
u"""
""",
)

entry(
    index = 1872,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25745, 'd12': 1.51912, 'd13': 2.77579},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 801""",
    longDesc = 
u"""
""",
)

entry(
    index = 1873,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33344, 'd12': 1.42412, 'd13': 2.75006},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 802""",
    longDesc = 
u"""
""",
)

entry(
    index = 1874,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.16491, 'd12': 1.29437, 'd13': 2.45731},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 803""",
    longDesc = 
u"""
""",
)

entry(
    index = 1875,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22743, 'd12': 1.5683, 'd13': 2.79411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 804""",
    longDesc = 
u"""
""",
)

entry(
    index = 1876,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30955, 'd12': 1.43573, 'd13': 2.74302},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 805""",
    longDesc = 
u"""
""",
)

entry(
    index = 1877,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29959, 'd12': 1.44545, 'd13': 2.74492},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 806""",
    longDesc = 
u"""
""",
)

entry(
    index = 1878,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19014, 'd12': 1.65036, 'd13': 2.83937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 807""",
    longDesc = 
u"""
""",
)

entry(
    index = 1879,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30837, 'd12': 1.4487, 'd13': 2.75615},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 808""",
    longDesc = 
u"""
""",
)

entry(
    index = 1880,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {10,S}
4     C u0 p0 c0  {3,S} {5,D} {11,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3444, 'd12': 1.40025, 'd13': 2.74258},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 809""",
    longDesc = 
u"""
""",
)

entry(
    index = 1881,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21079, 'd12': 1.572, 'd13': 2.77974},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 810""",
    longDesc = 
u"""
""",
)

entry(
    index = 1882,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {5,S} {6,S}
2     C u0 p0 c0  {1,D} {3,S} {7,S}
3     C u0 p0 c0  {2,S} {4,D} {8,S}
4     C u0 p0 c0  {3,D} {5,S} {9,S}
5  *3 C u1 p0 c0  {1,S} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3373, 'd12': 1.41199, 'd13': 2.74696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 811""",
    longDesc = 
u"""
""",
)

entry(
    index = 1883,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38683, 'd12': 1.37461, 'd13': 2.75922},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 812""",
    longDesc = 
u"""
""",
)

entry(
    index = 1884,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29848, 'd12': 1.46134, 'd13': 2.75655},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 813""",
    longDesc = 
u"""
""",
)

entry(
    index = 1885,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35407, 'd12': 1.39095, 'd13': 2.74434},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 814""",
    longDesc = 
u"""
""",
)

entry(
    index = 1886,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {9,S} {10,S}
2     C u0 p0 c0  {1,S} {4,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {1,S}
10 *2 H u0 p0 c0  {1,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31634, 'd12': 1.43373, 'd13': 2.74932},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 815""",
    longDesc = 
u"""
""",
)

entry(
    index = 1887,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37369, 'd12': 1.37966, 'd13': 2.75246},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 816""",
    longDesc = 
u"""
""",
)

entry(
    index = 1888,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30134, 'd12': 1.47327, 'd13': 2.77381},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 817""",
    longDesc = 
u"""
""",
)

entry(
    index = 1889,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27698, 'd12': 1.49647, 'd13': 2.75717},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 818""",
    longDesc = 
u"""
""",
)

entry(
    index = 1890,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24619, 'd12': 1.53082, 'd13': 2.77574},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 819""",
    longDesc = 
u"""
""",
)

entry(
    index = 1891,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27446, 'd12': 1.49826, 'd13': 2.75642},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 820""",
    longDesc = 
u"""
""",
)

entry(
    index = 1892,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30735, 'd12': 1.47303, 'd13': 2.77879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 821""",
    longDesc = 
u"""
""",
)

entry(
    index = 1893,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24397, 'd12': 1.53763, 'd13': 2.78084},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 822""",
    longDesc = 
u"""
""",
)

entry(
    index = 1894,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25993, 'd12': 1.51361, 'd13': 2.77239},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 823""",
    longDesc = 
u"""
""",
)

entry(
    index = 1895,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *1 C u0 p0 c0  {1,S} {7,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
8 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30388, 'd12': 1.4887, 'd13': 2.78598},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 824""",
    longDesc = 
u"""
""",
)

entry(
    index = 1896,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26541, 'd12': 1.50851, 'd13': 2.77315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 825""",
    longDesc = 
u"""
""",
)

entry(
    index = 1897,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32484, 'd12': 1.4202, 'd13': 2.74183},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 826""",
    longDesc = 
u"""
""",
)

entry(
    index = 1898,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17671, 'd12': 1.67468, 'd13': 2.85052},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 827""",
    longDesc = 
u"""
""",
)

entry(
    index = 1899,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1559, 'd12': 1.22543, 'd13': 2.36582},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 828""",
    longDesc = 
u"""
""",
)

entry(
    index = 1900,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.28401, 'd12': 1.24735, 'd13': 2.53128},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 829""",
    longDesc = 
u"""
""",
)

entry(
    index = 1901,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.08573, 'd12': 1.5875, 'd13': 2.67185},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 830""",
    longDesc = 
u"""
""",
)

entry(
    index = 1902,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6  *1 C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21 *2 H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30965, 'd12': 1.38265, 'd13': 2.69203},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 831""",
    longDesc = 
u"""
""",
)

entry(
    index = 1903,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26778, 'd12': 1.00142, 'd13': 2.26801},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 832""",
    longDesc = 
u"""
""",
)

entry(
    index = 1904,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15696, 'd12': 1.46987, 'd13': 2.59782},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 833""",
    longDesc = 
u"""
""",
)

entry(
    index = 1905,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22707, 'd12': 1.53058, 'd13': 2.75727},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 834""",
    longDesc = 
u"""
""",
)

entry(
    index = 1906,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27245, 'd12': 1.48625, 'd13': 2.75463},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 835""",
    longDesc = 
u"""
""",
)

entry(
    index = 1907,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12 *2 H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28405, 'd12': 1.45052, 'd13': 2.73061},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 836""",
    longDesc = 
u"""
""",
)

entry(
    index = 1908,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20219, 'd12': 1.60197, 'd13': 2.80371},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 837""",
    longDesc = 
u"""
""",
)

entry(
    index = 1909,
    reactant1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {1,S} {5,D} {11,S}
5     C u0 p0 c0  {2,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18521, 'd12': 1.42178, 'd13': 2.60601},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 838""",
    longDesc = 
u"""
""",
)

entry(
    index = 1910,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.15706, 'd12': 1.32771, 'd13': 2.48383},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 839""",
    longDesc = 
u"""
""",
)

entry(
    index = 1911,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29114, 'd12': 1.4604, 'd13': 2.75123},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 840""",
    longDesc = 
u"""
""",
)

entry(
    index = 1912,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18904, 'd12': 1.65773, 'd13': 2.84603},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 841""",
    longDesc = 
u"""
""",
)

entry(
    index = 1913,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22061, 'd12': 1.53929, 'd13': 2.75918},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 842""",
    longDesc = 
u"""
""",
)

entry(
    index = 1914,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.0915, 'd12': 1.48479, 'd13': 2.57607},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 843""",
    longDesc = 
u"""
""",
)

entry(
    index = 1915,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12752, 'd12': 1.72931, 'd13': 2.66883},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 844""",
    longDesc = 
u"""
""",
)

entry(
    index = 1916,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32675, 'd12': 1.37094, 'd13': 2.6976},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 845""",
    longDesc = 
u"""
""",
)

entry(
    index = 1917,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2452, 'd12': 1.51676, 'd13': 2.75708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 846""",
    longDesc = 
u"""
""",
)

entry(
    index = 1918,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12191, 'd12': 1.79222, 'd13': 2.65523},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 847""",
    longDesc = 
u"""
""",
)

entry(
    index = 1919,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *1 C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28273, 'd12': 1.4224, 'd13': 2.70479},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 848""",
    longDesc = 
u"""
""",
)

entry(
    index = 1920,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17993, 'd12': 1.36795, 'd13': 2.54543},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 849""",
    longDesc = 
u"""
""",
)

entry(
    index = 1921,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3313, 'd12': 1.35995, 'd13': 2.69093},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 850""",
    longDesc = 
u"""
""",
)

entry(
    index = 1922,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33046, 'd12': 1.33706, 'd13': 2.66667},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 851""",
    longDesc = 
u"""
""",
)

entry(
    index = 1923,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28617, 'd12': 1.41514, 'd13': 2.70116},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 852""",
    longDesc = 
u"""
""",
)

entry(
    index = 1924,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32098, 'd12': 1.38324, 'd13': 2.70403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 853""",
    longDesc = 
u"""
""",
)

entry(
    index = 1925,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26522, 'd12': 1.45037, 'd13': 2.71552},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 854""",
    longDesc = 
u"""
""",
)

entry(
    index = 1926,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29804, 'd12': 1.41412, 'd13': 2.71189},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 855""",
    longDesc = 
u"""
""",
)

entry(
    index = 1927,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.29897, 'd12': 1.35366, 'd13': 2.64496},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 856""",
    longDesc = 
u"""
""",
)

entry(
    index = 1928,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12972, 'd12': 1.41716, 'd13': 2.51447},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 857""",
    longDesc = 
u"""
""",
)

entry(
    index = 1929,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28289, 'd12': 1.35844, 'd13': 2.63999},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 858""",
    longDesc = 
u"""
""",
)

entry(
    index = 1930,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    C u0 p0 c0  {1,D} {4,D}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {2,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32618, 'd12': 1.31627, 'd13': 2.64064},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 859""",
    longDesc = 
u"""
""",
)

entry(
    index = 1931,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32623, 'd12': 1.31892, 'd13': 2.64402},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 860""",
    longDesc = 
u"""
""",
)

entry(
    index = 1932,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24345, 'd12': 1.43283, 'd13': 2.67525},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 861""",
    longDesc = 
u"""
""",
)

entry(
    index = 1933,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22546, 'd12': 1.56345, 'd13': 2.7866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 862""",
    longDesc = 
u"""
""",
)

entry(
    index = 1934,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23682, 'd12': 1.54377, 'd13': 2.77828},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 863""",
    longDesc = 
u"""
""",
)

entry(
    index = 1935,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26535, 'd12': 1.4927, 'd13': 2.75791},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 864""",
    longDesc = 
u"""
""",
)

entry(
    index = 1936,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21514, 'd12': 1.33245, 'd13': 2.54606},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 865""",
    longDesc = 
u"""
""",
)

entry(
    index = 1937,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34529, 'd12': 1.35426, 'd13': 2.69875},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 866""",
    longDesc = 
u"""
""",
)

entry(
    index = 1938,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25621, 'd12': 1.47659, 'd13': 2.73086},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 867""",
    longDesc = 
u"""
""",
)

entry(
    index = 1939,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27145, 'd12': 1.49717, 'd13': 2.76302},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 868""",
    longDesc = 
u"""
""",
)

entry(
    index = 1940,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26902, 'd12': 1.46158, 'd13': 2.73047},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 869""",
    longDesc = 
u"""
""",
)

entry(
    index = 1941,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29394, 'd12': 1.42674, 'd13': 2.72065},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 870""",
    longDesc = 
u"""
""",
)

entry(
    index = 1942,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.09182, 'd12': 1.46487, 'd13': 2.5481},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 871""",
    longDesc = 
u"""
""",
)

entry(
    index = 1943,
    reactant1 = """
multiplicity 2
1 *1 O u1 p2 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 3
1 *3 O u2 p2 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.33568, 'd12': 1.18587, 'd13': 2.52149},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 872""",
    longDesc = 
u"""
""",
)

entry(
    index = 1944,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29098, 'd12': 1.42911, 'd13': 2.71933},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 873""",
    longDesc = 
u"""
""",
)

entry(
    index = 1945,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3641, 'd12': 1.33666, 'd13': 2.69967},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 874""",
    longDesc = 
u"""
""",
)

entry(
    index = 1946,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28632, 'd12': 1.41708, 'd13': 2.70146},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 875""",
    longDesc = 
u"""
""",
)

entry(
    index = 1947,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18185, 'd12': 1.48022, 'd13': 2.66056},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 876""",
    longDesc = 
u"""
""",
)

entry(
    index = 1948,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25312, 'd12': 1.50386, 'd13': 2.75683},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 877""",
    longDesc = 
u"""
""",
)

entry(
    index = 1949,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1942, 'd12': 1.43173, 'd13': 2.62521},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 878""",
    longDesc = 
u"""
""",
)

entry(
    index = 1950,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29547, 'd12': 1.39507, 'd13': 2.69026},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 879""",
    longDesc = 
u"""
""",
)

entry(
    index = 1951,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32627, 'd12': 1.37522, 'd13': 2.70138},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 880""",
    longDesc = 
u"""
""",
)

entry(
    index = 1952,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28386, 'd12': 1.44678, 'd13': 2.72891},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 881""",
    longDesc = 
u"""
""",
)

entry(
    index = 1953,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27217, 'd12': 1.25466, 'd13': 2.52674},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 882""",
    longDesc = 
u"""
""",
)

entry(
    index = 1954,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21686, 'd12': 1.53531, 'd13': 2.75166},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 883""",
    longDesc = 
u"""
""",
)

entry(
    index = 1955,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2165, 'd12': 1.35358, 'd13': 2.56758},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 884""",
    longDesc = 
u"""
""",
)

entry(
    index = 1956,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12382, 'd12': 1.86601, 'd13': 2.89113},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 885""",
    longDesc = 
u"""
""",
)

entry(
    index = 1957,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30835, 'd12': 1.33836, 'd13': 2.64307},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 886""",
    longDesc = 
u"""
""",
)

entry(
    index = 1958,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21025, 'd12': 1.36094, 'd13': 2.56111},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 887""",
    longDesc = 
u"""
""",
)

entry(
    index = 1959,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23884, 'd12': 1.49686, 'd13': 2.73408},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 888""",
    longDesc = 
u"""
""",
)

entry(
    index = 1960,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2431, 'd12': 1.48766, 'd13': 2.72937},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 889""",
    longDesc = 
u"""
""",
)

entry(
    index = 1961,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23064, 'd12': 1.5563, 'd13': 2.78107},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 890""",
    longDesc = 
u"""
""",
)

entry(
    index = 1962,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27151, 'd12': 1.44761, 'd13': 2.71754},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 891""",
    longDesc = 
u"""
""",
)

entry(
    index = 1963,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26893, 'd12': 1.49971, 'd13': 2.76194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 892""",
    longDesc = 
u"""
""",
)

entry(
    index = 1964,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19361, 'd12': 1.64033, 'd13': 2.83392},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 893""",
    longDesc = 
u"""
""",
)

entry(
    index = 1965,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20242, 'd12': 1.39101, 'd13': 2.58403},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 894""",
    longDesc = 
u"""
""",
)

entry(
    index = 1966,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15369, 'd12': 1.39758, 'd13': 2.54972},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 895""",
    longDesc = 
u"""
""",
)

entry(
    index = 1967,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30683, 'd12': 1.3853, 'd13': 2.69212},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 896""",
    longDesc = 
u"""
""",
)

entry(
    index = 1968,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29015, 'd12': 1.41379, 'd13': 2.70311},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 897""",
    longDesc = 
u"""
""",
)

entry(
    index = 1969,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31804, 'd12': 1.38284, 'd13': 2.70071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 898""",
    longDesc = 
u"""
""",
)

entry(
    index = 1970,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24105, 'd12': 1.45318, 'd13': 2.692},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 899""",
    longDesc = 
u"""
""",
)

entry(
    index = 1971,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23188, 'd12': 1.52223, 'd13': 2.75409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 900""",
    longDesc = 
u"""
""",
)

entry(
    index = 1972,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34035, 'd12': 1.38761, 'd13': 2.72788},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 901""",
    longDesc = 
u"""
""",
)

entry(
    index = 1973,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26781, 'd12': 1.46629, 'd13': 2.73399},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 902""",
    longDesc = 
u"""
""",
)

entry(
    index = 1974,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31364, 'd12': 1.45301, 'd13': 2.76177},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 903""",
    longDesc = 
u"""
""",
)

entry(
    index = 1975,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *1 C u0 p0 c0  {1,S} {5,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.20595, 'd12': 1.34513, 'd13': 2.54997},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 904""",
    longDesc = 
u"""
""",
)

entry(
    index = 1976,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27711, 'd12': 1.49206, 'd13': 2.76775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 905""",
    longDesc = 
u"""
""",
)

entry(
    index = 1977,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21198, 'd12': 1.54507, 'd13': 2.75442},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 906""",
    longDesc = 
u"""
""",
)

entry(
    index = 1978,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *2 H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28193, 'd12': 1.47813, 'd13': 2.75993},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 907""",
    longDesc = 
u"""
""",
)

entry(
    index = 1979,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21217, 'd12': 1.36211, 'd13': 2.56789},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 908""",
    longDesc = 
u"""
""",
)

entry(
    index = 1980,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,D} {6,S}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35742, 'd12': 1.39042, 'd13': 2.7428},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 909""",
    longDesc = 
u"""
""",
)

entry(
    index = 1981,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.36987, 'd12': 1.37688, 'd13': 2.73991},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 910""",
    longDesc = 
u"""
""",
)

entry(
    index = 1982,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {8,S}
2     C u0 p0 c0  {1,B} {4,B} {7,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,B} {6,B} {7,S}
2     C u0 p0 c0  {1,B} {3,B} {8,S}
3     C u0 p0 c0  {2,B} {4,B} {9,S}
4     C u0 p0 c0  {3,B} {5,B} {10,S}
5     C u0 p0 c0  {4,B} {6,B} {11,S}
6     C u0 p0 c0  {1,B} {5,B} {12,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32198, 'd12': 1.34704, 'd13': 2.6677},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 911""",
    longDesc = 
u"""
""",
)

entry(
    index = 1983,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2289, 'd12': 1.4813, 'd13': 2.70983},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 912""",
    longDesc = 
u"""
""",
)

entry(
    index = 1984,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12859, 'd12': 1.70846, 'd13': 2.74322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 913""",
    longDesc = 
u"""
""",
)

entry(
    index = 1985,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28764, 'd12': 1.39585, 'd13': 2.68333},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 914""",
    longDesc = 
u"""
""",
)

entry(
    index = 1986,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28125, 'd12': 1.41172, 'd13': 2.69194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 915""",
    longDesc = 
u"""
""",
)

entry(
    index = 1987,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22567, 'd12': 1.53913, 'd13': 2.76389},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 916""",
    longDesc = 
u"""
""",
)

entry(
    index = 1988,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13839, 'd12': 1.36473, 'd13': 2.50034},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 917""",
    longDesc = 
u"""
""",
)

entry(
    index = 1989,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26632, 'd12': 1.43887, 'd13': 2.70515},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 918""",
    longDesc = 
u"""
""",
)

entry(
    index = 1990,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27046, 'd12': 1.43385, 'd13': 2.70411},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 919""",
    longDesc = 
u"""
""",
)

entry(
    index = 1991,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24552, 'd12': 1.47801, 'd13': 2.7234},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 920""",
    longDesc = 
u"""
""",
)

entry(
    index = 1992,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2215, 'd12': 1.59187, 'd13': 2.8131},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 921""",
    longDesc = 
u"""
""",
)

entry(
    index = 1993,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12535, 'd12': 1.43098, 'd13': 2.55318},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 922""",
    longDesc = 
u"""
""",
)

entry(
    index = 1994,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1581, 'd12': 1.37621, 'd13': 2.53151},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 923""",
    longDesc = 
u"""
""",
)

entry(
    index = 1995,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {10,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26066, 'd12': 1.48379, 'd13': 2.74142},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 924""",
    longDesc = 
u"""
""",
)

entry(
    index = 1996,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30237, 'd12': 1.38552, 'd13': 2.68616},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 925""",
    longDesc = 
u"""
""",
)

entry(
    index = 1997,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28737, 'd12': 1.42677, 'd13': 2.71361},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 926""",
    longDesc = 
u"""
""",
)

entry(
    index = 1998,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {3,S}
2    O u0 p2 c0  {1,D}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30625, 'd12': 1.4222, 'd13': 2.72456},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 927""",
    longDesc = 
u"""
""",
)

entry(
    index = 1999,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    O u0 p2 c0  {1,S} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    O u0 p2 c0  {1,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.33066, 'd12': 1.3765, 'd13': 2.70328},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 928""",
    longDesc = 
u"""
""",
)

entry(
    index = 2000,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,S} {3,S} {7,S}
3    O u0 p2 c0  {2,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31601, 'd12': 1.39558, 'd13': 2.70759},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 929""",
    longDesc = 
u"""
""",
)

entry(
    index = 2001,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31545, 'd12': 1.38142, 'd13': 2.69481},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 930""",
    longDesc = 
u"""
""",
)

entry(
    index = 2002,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30367, 'd12': 1.43382, 'd13': 2.73291},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 931""",
    longDesc = 
u"""
""",
)

entry(
    index = 2003,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35462, 'd12': 1.33802, 'd13': 2.69224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 932""",
    longDesc = 
u"""
""",
)

entry(
    index = 2004,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35704, 'd12': 1.33876, 'd13': 2.69559},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 933""",
    longDesc = 
u"""
""",
)

entry(
    index = 2005,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31417, 'd12': 1.42516, 'd13': 2.72543},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 934""",
    longDesc = 
u"""
""",
)

entry(
    index = 2006,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.12519, 'd12': 1.50467, 'd13': 2.62453},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 935""",
    longDesc = 
u"""
""",
)

entry(
    index = 2007,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36073, 'd12': 1.37359, 'd13': 2.73351},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 936""",
    longDesc = 
u"""
""",
)

entry(
    index = 2008,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.37353, 'd12': 1.36702, 'd13': 2.71876},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 937""",
    longDesc = 
u"""
""",
)

entry(
    index = 2009,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24721, 'd12': 1.51826, 'd13': 2.75697},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 938""",
    longDesc = 
u"""
""",
)

entry(
    index = 2010,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5     C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.406, 'd12': 1.34739, 'd13': 2.74051},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 939""",
    longDesc = 
u"""
""",
)

entry(
    index = 2011,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
4     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
5  *1 C u0 p0 c0  {2,S} {11,S} {12,S} {13,S}
6     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11 *2 H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
15    H u0 p0 c0  {6,S}
16    H u0 p0 c0  {6,S}
17    H u0 p0 c0  {3,S}
18    H u0 p0 c0  {3,S}
19    H u0 p0 c0  {3,S}
20    H u0 p0 c0  {4,S}
21    H u0 p0 c0  {4,S}
22    H u0 p0 c0  {4,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13658, 'd12': 1.42516, 'd13': 2.56162},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 940""",
    longDesc = 
u"""
""",
)

entry(
    index = 2012,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27413, 'd12': 1.42748, 'd13': 2.70104},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 941""",
    longDesc = 
u"""
""",
)

entry(
    index = 2013,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28498, 'd12': 1.41317, 'd13': 2.69712},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 942""",
    longDesc = 
u"""
""",
)

entry(
    index = 2014,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30128, 'd12': 1.41592, 'd13': 2.71276},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 943""",
    longDesc = 
u"""
""",
)

entry(
    index = 2015,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29811, 'd12': 1.35743, 'd13': 2.65071},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 944""",
    longDesc = 
u"""
""",
)

entry(
    index = 2016,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13119, 'd12': 1.78373, 'd13': 2.9029},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 945""",
    longDesc = 
u"""
""",
)

entry(
    index = 2017,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35655, 'd12': 1.34239, 'd13': 2.69841},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 946""",
    longDesc = 
u"""
""",
)

entry(
    index = 2018,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2 *3 O u1 p2 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    product1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.047, 'd12': 1.426, 'd13': 2.46431},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 947""",
    longDesc = 
u"""
""",
)

entry(
    index = 2019,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {5,S} {14,D}
5     O u0 p2 c0  {4,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {15,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    O u0 p2 c0  {4,D}
15 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {5,S} {13,D}
5     O u0 p2 c0  {4,S} {14,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    O u0 p2 c0  {4,D}
14 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31974, 'd12': 1.21926, 'd13': 2.53718},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 948""",
    longDesc = 
u"""
""",
)

entry(
    index = 2020,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10 *2 H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {1,S} {23,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22954, 'd12': 1.33507, 'd13': 2.55965},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 949""",
    longDesc = 
u"""
""",
)

entry(
    index = 2021,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.201, 'd12': 1.14168, 'd13': 2.33315},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 950""",
    longDesc = 
u"""
""",
)

entry(
    index = 2022,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17 *2 H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {10,S}
2     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {6,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {6,S} {19,S} {20,S} {21,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {22,D}
8     O u0 p2 c0  {2,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {2,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    H u0 p0 c0  {5,S}
22    O u0 p2 c0  {7,D}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2  *1 C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11 *2 H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27456, 'd12': 1.48503, 'd13': 2.75364},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 951""",
    longDesc = 
u"""
""",
)

entry(
    index = 2023,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3  *1 C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2322, 'd12': 1.5294, 'd13': 2.76137},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 952""",
    longDesc = 
u"""
""",
)

entry(
    index = 2024,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24601, 'd12': 1.51006, 'd13': 2.75369},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 953""",
    longDesc = 
u"""
""",
)

entry(
    index = 2025,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2678, 'd12': 1.47196, 'd13': 2.73917},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 954""",
    longDesc = 
u"""
""",
)

entry(
    index = 2026,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21697, 'd12': 1.52761, 'd13': 2.74458},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 955""",
    longDesc = 
u"""
""",
)

entry(
    index = 2027,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29778, 'd12': 1.42649, 'd13': 2.72359},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 956""",
    longDesc = 
u"""
""",
)

entry(
    index = 2028,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5  *1 C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19 *2 H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3  *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,D}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    O u0 p2 c0  {4,D}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {6,S} {7,S}
2     C u0 p0 c0  {3,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {4,D}
4     C u0 p0 c0  {3,D} {11,D}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    O u0 p2 c0  {4,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {1,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30243, 'd12': 1.43127, 'd13': 2.7335},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 957""",
    longDesc = 
u"""
""",
)

entry(
    index = 2029,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {6,S} {7,S} {9,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {11,S} {12,S}
4     C u0 p0 c0  {2,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     O u0 p2 c0  {3,S} {23,S}
9     H u0 p0 c0  {1,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
23 *3 O u1 p2 c0  {8,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9  *1 O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24 *2 H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.09292, 'd12': 1.30797, 'd13': 2.39488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 958""",
    longDesc = 
u"""
""",
)

entry(
    index = 2030,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26208, 'd12': 1.30727, 'd13': 2.56878},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 959""",
    longDesc = 
u"""
""",
)

entry(
    index = 2031,
    reactant1 = """
1     C u0 p0 c0  {2,S} {7,S} {8,S} {9,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {10,D}
4     C u0 p0 c0  {2,D} {11,S} {12,S}
5     O u0 p2 c0  {3,S} {6,S}
6  *1 O u0 p2 c0  {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {1,S}
10    O u0 p2 c0  {3,D}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
13 *2 H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    C u0 p0 c0  {1,S} {5,D} {6,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {4,D}
3     C u0 p0 c0  {2,S} {5,S} {9,D}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     O u0 p2 c0  {3,S} {12,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     O u0 p2 c0  {3,D}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12 *3 O u1 p2 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32782, 'd12': 1.21147, 'd13': 2.53922},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 960""",
    longDesc = 
u"""
""",
)

entry(
    index = 2032,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13212, 'd12': 1.42322, 'd13': 2.55226},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 961""",
    longDesc = 
u"""
""",
)

entry(
    index = 2033,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30936, 'd12': 1.38481, 'd13': 2.69386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 962""",
    longDesc = 
u"""
""",
)

entry(
    index = 2034,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32357, 'd12': 1.37629, 'd13': 2.69097},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 963""",
    longDesc = 
u"""
""",
)

entry(
    index = 2035,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29227, 'd12': 1.22741, 'd13': 2.51669},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 964""",
    longDesc = 
u"""
""",
)

entry(
    index = 2036,
    reactant1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {10,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {1,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22 *2 H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3074, 'd12': 1.40912, 'd13': 2.71202},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 965""",
    longDesc = 
u"""
""",
)

entry(
    index = 2037,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {10,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4  *1 C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {2,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14 *2 H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30752, 'd12': 1.4532, 'd13': 2.75513},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 966""",
    longDesc = 
u"""
""",
)

entry(
    index = 2038,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {4,S} {5,S} {6,S} {10,S}
2     C u0 p0 c0  {3,S} {6,S} {7,S} {11,S}
3     C u0 p0 c0  {2,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {1,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {17,S} {18,S} {19,S}
6     C u0 p0 c0  {1,S} {2,S} {20,D}
7  *3 C u1 p0 c0  {2,S} {21,S} {22,S}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {23,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    O u0 p2 c0  {6,D}
21    H u0 p0 c0  {7,S}
22    H u0 p0 c0  {7,S}
23    H u0 p0 c0  {9,S}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {6,S} {7,S} {10,S}
2     C u0 p0 c0  {4,S} {5,S} {7,S} {11,S}
3     C u0 p0 c0  {1,S} {8,S} {12,S} {13,S}
4     C u0 p0 c0  {2,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {2,S} {17,S} {18,S} {19,S}
6  *1 C u0 p0 c0  {1,S} {20,S} {21,S} {22,S}
7     C u0 p0 c0  {1,S} {2,S} {23,D}
8     O u0 p2 c0  {3,S} {9,S}
9     O u0 p2 c0  {8,S} {24,S}
10    H u0 p0 c0  {1,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20 *2 H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    H u0 p0 c0  {6,S}
23    O u0 p2 c0  {7,D}
24    H u0 p0 c0  {9,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3602, 'd12': 1.33803, 'd13': 2.69039},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 967""",
    longDesc = 
u"""
""",
)

entry(
    index = 2039,
    reactant1 = """
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.31358, 'd12': 1.41337, 'd13': 2.72653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 968""",
    longDesc = 
u"""
""",
)

entry(
    index = 2040,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25015, 'd12': 1.47067, 'd13': 2.71963},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 969""",
    longDesc = 
u"""
""",
)

entry(
    index = 2041,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2812, 'd12': 1.43247, 'd13': 2.71309},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 970""",
    longDesc = 
u"""
""",
)

entry(
    index = 2042,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,D}
3 *3 C u1 p0 c0  {2,S} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    O u0 p2 c0  {2,D}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {2,S} {10,D}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    O u0 p2 c0  {3,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32384, 'd12': 1.37031, 'd13': 2.69218},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 971""",
    longDesc = 
u"""
""",
)

entry(
    index = 2043,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25021, 'd12': 1.49471, 'd13': 2.74397},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 972""",
    longDesc = 
u"""
""",
)

entry(
    index = 2044,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22607, 'd12': 1.55342, 'd13': 2.77343},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 973""",
    longDesc = 
u"""
""",
)

entry(
    index = 2045,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24041, 'd12': 1.52066, 'd13': 2.75987},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 974""",
    longDesc = 
u"""
""",
)

entry(
    index = 2046,
    reactant1 = """
1    C u0 p0 c0  {3,D} {4,S} {5,S}
2 *1 C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29538, 'd12': 1.42279, 'd13': 2.71676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 975""",
    longDesc = 
u"""
""",
)

entry(
    index = 2047,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26087, 'd12': 1.47334, 'd13': 2.73346},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 976""",
    longDesc = 
u"""
""",
)

entry(
    index = 2048,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19704, 'd12': 1.63093, 'd13': 2.82794},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 977""",
    longDesc = 
u"""
""",
)

entry(
    index = 2049,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 3
1 *3 O u1 p2 c0  {2,S}
2    O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u1 p2 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.07699, 'd12': 1.58837, 'd13': 2.6653},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 978""",
    longDesc = 
u"""
""",
)

entry(
    index = 2050,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23799, 'd12': 1.49669, 'd13': 2.73421},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 979""",
    longDesc = 
u"""
""",
)

entry(
    index = 2051,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26573, 'd12': 1.43274, 'd13': 2.69676},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 980""",
    longDesc = 
u"""
""",
)

entry(
    index = 2052,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,D} {11,S}
4     C u0 p0 c0  {2,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {3,S} {5,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {2,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {1,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38238, 'd12': 1.37374, 'd13': 2.75374},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 981""",
    longDesc = 
u"""
""",
)

entry(
    index = 2053,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31774, 'd12': 1.35913, 'd13': 2.67585},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 982""",
    longDesc = 
u"""
""",
)

entry(
    index = 2054,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2 *3 C u1 p0 c0  {1,D} {5,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32106, 'd12': 1.34511, 'd13': 2.66523},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 983""",
    longDesc = 
u"""
""",
)

entry(
    index = 2055,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30511, 'd12': 1.37942, 'd13': 2.68166},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 984""",
    longDesc = 
u"""
""",
)

entry(
    index = 2056,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28718, 'd12': 1.4219, 'd13': 2.70752},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 985""",
    longDesc = 
u"""
""",
)

entry(
    index = 2057,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26654, 'd12': 1.45871, 'd13': 2.7231},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 986""",
    longDesc = 
u"""
""",
)

entry(
    index = 2058,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2  *1 C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *2 H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28847, 'd12': 1.43026, 'd13': 2.71439},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 987""",
    longDesc = 
u"""
""",
)

entry(
    index = 2059,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27626, 'd12': 1.37582, 'd13': 2.64959},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 988""",
    longDesc = 
u"""
""",
)

entry(
    index = 2060,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26907, 'd12': 1.40568, 'd13': 2.67434},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 989""",
    longDesc = 
u"""
""",
)

entry(
    index = 2061,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *3 C u1 p0 c0  {1,S} {4,S} {9,S}
3     C u0 p0 c0  {1,S} {5,D} {10,S}
4     C u0 p0 c0  {2,S} {6,D} {11,S}
5     C u0 p0 c0  {3,D} {6,S} {12,S}
6     C u0 p0 c0  {4,D} {5,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17658, 'd12': 1.68236, 'd13': 2.85612},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 990""",
    longDesc = 
u"""
""",
)

entry(
    index = 2062,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25545, 'd12': 1.49838, 'd13': 2.75326},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 991""",
    longDesc = 
u"""
""",
)

entry(
    index = 2063,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.38015, 'd12': 1.32114, 'd13': 2.69514},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 992""",
    longDesc = 
u"""
""",
)

entry(
    index = 2064,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31553, 'd12': 1.1909, 'd13': 2.50386},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 993""",
    longDesc = 
u"""
""",
)

entry(
    index = 2065,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28291, 'd12': 1.41993, 'd13': 2.69996},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 994""",
    longDesc = 
u"""
""",
)

entry(
    index = 2066,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23851, 'd12': 1.49378, 'd13': 2.73076},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 995""",
    longDesc = 
u"""
""",
)

entry(
    index = 2067,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4  *1 C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22812, 'd12': 1.55197, 'd13': 2.77525},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 996""",
    longDesc = 
u"""
""",
)

entry(
    index = 2068,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23552, 'd12': 1.54694, 'd13': 2.76807},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 997""",
    longDesc = 
u"""
""",
)

entry(
    index = 2069,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32066, 'd12': 1.33999, 'd13': 2.66062},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 998""",
    longDesc = 
u"""
""",
)

entry(
    index = 2070,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25283, 'd12': 1.49396, 'd13': 2.74416},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 999""",
    longDesc = 
u"""
""",
)

entry(
    index = 2071,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29268, 'd12': 1.44743, 'd13': 2.73467},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1000""",
    longDesc = 
u"""
""",
)

entry(
    index = 2072,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2     C u0 p0 c0  {3,S} {7,S} {8,S} {9,S}
3  *3 C u1 p0 c0  {1,S} {2,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31164, 'd12': 1.42146, 'd13': 2.73115},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1001""",
    longDesc = 
u"""
""",
)

entry(
    index = 2073,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21361, 'd12': 1.54131, 'd13': 2.75322},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1002""",
    longDesc = 
u"""
""",
)

entry(
    index = 2074,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24306, 'd12': 1.45527, 'd13': 2.69156},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1003""",
    longDesc = 
u"""
""",
)

entry(
    index = 2075,
    reactant1 = """
1    C u0 p0 c0  {2,T} {3,S}
2 *1 C u0 p0 c0  {1,T} {4,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,T} {3,S}
2 *3 C u1 p0 c0  {1,T}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.13328, 'd12': 1.76763, 'd13': 2.84773},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1004""",
    longDesc = 
u"""
""",
)

entry(
    index = 2076,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22354, 'd12': 1.53645, 'd13': 2.75765},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1005""",
    longDesc = 
u"""
""",
)

entry(
    index = 2077,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {18,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {17,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {6,S}
18    O u0 p2 c0  {5,D}
""",
    product1 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.30072, 'd12': 1.41335, 'd13': 2.70863},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1006""",
    longDesc = 
u"""
""",
)

entry(
    index = 2078,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32419, 'd12': 1.40433, 'd13': 2.7274},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1007""",
    longDesc = 
u"""
""",
)

entry(
    index = 2079,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21738, 'd12': 1.55929, 'd13': 2.77648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1008""",
    longDesc = 
u"""
""",
)

entry(
    index = 2080,
    reactant1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35455, 'd12': 1.3727, 'd13': 2.72587},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1009""",
    longDesc = 
u"""
""",
)

entry(
    index = 2081,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22922, 'd12': 1.54407, 'd13': 2.76703},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1010""",
    longDesc = 
u"""
""",
)

entry(
    index = 2082,
    reactant1 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.24265, 'd12': 1.52014, 'd13': 2.76268},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1011""",
    longDesc = 
u"""
""",
)

entry(
    index = 2083,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21255, 'd12': 1.55905, 'd13': 2.7708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1012""",
    longDesc = 
u"""
""",
)

entry(
    index = 2084,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
3     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
4     C u0 p0 c0  {6,S} {15,S} {16,S} {17,S}
5     C u0 p0 c0  {6,S} {18,S} {19,S} {20,S}
6  *3 C u1 p0 c0  {4,S} {5,S} {7,S}
7     C u0 p0 c0  {1,S} {6,S} {21,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {2,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {5,S}
20    H u0 p0 c0  {5,S}
21    O u0 p2 c0  {7,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8  *2 H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.20625, 'd12': 1.59101, 'd13': 2.78503},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1013""",
    longDesc = 
u"""
""",
)

entry(
    index = 2085,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.25637, 'd12': 1.45292, 'd13': 2.70879},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1014""",
    longDesc = 
u"""
""",
)

entry(
    index = 2086,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19737, 'd12': 1.60863, 'd13': 2.80488},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1015""",
    longDesc = 
u"""
""",
)

entry(
    index = 2087,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,D} {9,S}
3  *3 C u1 p0 c0  {1,S} {5,S} {10,S}
4     C u0 p0 c0  {2,D} {6,S} {12,S}
5     C u0 p0 c0  {3,S} {6,D} {13,S}
6     C u0 p0 c0  {4,S} {5,D} {11,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {6,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,S} {9,S} {10,S}
3     C u0 p0 c0  {2,S} {5,D} {11,S}
4     C u0 p0 c0  {1,S} {6,D} {12,S}
5     C u0 p0 c0  {3,D} {6,S} {13,S}
6     C u0 p0 c0  {4,D} {5,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {5,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.17736, 'd12': 1.70073, 'd13': 2.87611},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1016""",
    longDesc = 
u"""
""",
)

entry(
    index = 2088,
    reactant1 = """
1 *1 H u0 p0 c0  {2,S}
2 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 H u1 p0 c0 
""",
    distances = DistanceData(
        distances = {'d23': 1.53746, 'd12': 0.834517, 'd13': 2.37194},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1017""",
    longDesc = 
u"""
""",
)

entry(
    index = 2089,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *3 O u1 p2 c0  {1,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    O u0 p2 c0  {1,S} {4,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.05429, 'd12': 1.56333, 'd13': 2.61718},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1018""",
    longDesc = 
u"""
""",
)

entry(
    index = 2090,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,T}
3    C u0 p0 c0  {2,T} {7,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22279, 'd12': 1.52824, 'd13': 2.75062},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1019""",
    longDesc = 
u"""
""",
)

entry(
    index = 2091,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {4,D} {8,S} {9,S}
4 *3 C u1 p0 c0  {1,S} {3,D}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29094, 'd12': 1.38878, 'd13': 2.67882},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1020""",
    longDesc = 
u"""
""",
)

entry(
    index = 2092,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {5,S} {9,S}
4     C u0 p0 c0  {2,S} {5,D} {10,S}
5     C u0 p0 c0  {3,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2  *1 C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18711, 'd12': 1.64229, 'd13': 2.82866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1021""",
    longDesc = 
u"""
""",
)

entry(
    index = 2093,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26168, 'd12': 1.44528, 'd13': 2.70696},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1022""",
    longDesc = 
u"""
""",
)

entry(
    index = 2094,
    reactant1 = """
multiplicity 2
1 *1 C u1 p0 c0  {2,S} {3,S} {4,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 3
1 *3 C u2 p0 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35503, 'd12': 1.2969, 'd13': 2.65192},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1023""",
    longDesc = 
u"""
""",
)

entry(
    index = 2095,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3    O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {2,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    O u0 p2 c0  {1,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.44216, 'd12': 1.26704, 'd13': 2.70443},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1024""",
    longDesc = 
u"""
""",
)

entry(
    index = 2096,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.1997, 'd12': 1.64192, 'd13': 2.84154},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1025""",
    longDesc = 
u"""
""",
)

entry(
    index = 2097,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.22449, 'd12': 1.52263, 'd13': 2.74623},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1026""",
    longDesc = 
u"""
""",
)

entry(
    index = 2098,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,S} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26039, 'd12': 1.44762, 'd13': 2.708},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1027""",
    longDesc = 
u"""
""",
)

entry(
    index = 2099,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.40884, 'd12': 1.24649, 'd13': 2.65412},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1028""",
    longDesc = 
u"""
""",
)

entry(
    index = 2100,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,S} {3,D}
2    H u0 p0 c0  {1,S}
3    O u0 p2 c0  {1,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    O u0 p2 c0  {1,D}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2021, 'd12': 1.61742, 'd13': 2.81952},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1029""",
    longDesc = 
u"""
""",
)

entry(
    index = 2101,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.21449, 'd12': 1.60828, 'd13': 2.82277},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1030""",
    longDesc = 
u"""
""",
)

entry(
    index = 2102,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.34274, 'd12': 1.31707, 'd13': 2.65897},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1031""",
    longDesc = 
u"""
""",
)

entry(
    index = 2103,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4  *1 C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10 *2 H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3592, 'd12': 1.31258, 'd13': 2.66866},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1032""",
    longDesc = 
u"""
""",
)

entry(
    index = 2104,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.20995, 'd12': 1.56773, 'd13': 2.77265},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1033""",
    longDesc = 
u"""
""",
)

entry(
    index = 2105,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20119, 'd12': 1.59503, 'd13': 2.79504},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1034""",
    longDesc = 
u"""
""",
)

entry(
    index = 2106,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,D} {3,S} {6,S}
2     C u0 p0 c0  {1,D} {4,S} {7,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4  *3 C u1 p0 c0  {2,S} {5,S} {9,S}
5     C u0 p0 c0  {3,D} {4,S} {10,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5     C u0 p0 c0  {3,D} {4,S} {11,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.19503, 'd12': 1.61859, 'd13': 2.81321},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1035""",
    longDesc = 
u"""
""",
)

entry(
    index = 2107,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2377, 'd12': 1.46989, 'd13': 2.70663},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1036""",
    longDesc = 
u"""
""",
)

entry(
    index = 2108,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31867, 'd12': 1.36318, 'd13': 2.68142},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1037""",
    longDesc = 
u"""
""",
)

entry(
    index = 2109,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.23021, 'd12': 1.48636, 'd13': 2.7161},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1038""",
    longDesc = 
u"""
""",
)

entry(
    index = 2110,
    reactant1 = """
1 *1 O u0 p2 c0  {2,S} {3,S}
2    H u0 p0 c0  {1,S}
3 *2 H u0 p0 c0  {1,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1 *3 O u1 p2 c0  {2,S}
2    H u0 p0 c0  {1,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.15339, 'd12': 1.48483, 'd13': 2.60691},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1039""",
    longDesc = 
u"""
""",
)

entry(
    index = 2111,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *3 C u1 p0 c0  {1,S} {6,D}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
""",
    product1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2 *1 C u0 p0 c0  {1,S} {6,D} {7,S}
3    H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7 *2 H u0 p0 c0  {2,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32206, 'd12': 1.41086, 'd13': 2.73237},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1040""",
    longDesc = 
u"""
""",
)

entry(
    index = 2112,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3 *1 C u0 p0 c0  {1,S} {5,D} {8,S}
4    H u0 p0 c0  {1,S}
5    O u0 p2 c0  {3,D}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8 *2 H u0 p0 c0  {3,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32928, 'd12': 1.39662, 'd13': 2.7258},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1041""",
    longDesc = 
u"""
""",
)

entry(
    index = 2113,
    reactant1 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29358, 'd12': 1.42494, 'd13': 2.71767},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1042""",
    longDesc = 
u"""
""",
)

entry(
    index = 2114,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,S} {6,S}
3 *3 C u1 p0 c0  {1,S} {7,S} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29002, 'd12': 1.44613, 'd13': 2.73555},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1043""",
    longDesc = 
u"""
""",
)

entry(
    index = 2115,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3033, 'd12': 1.39145, 'd13': 2.69413},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1044""",
    longDesc = 
u"""
""",
)

entry(
    index = 2116,
    reactant1 = """
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2  *1 C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6     C u0 p0 c0  {4,B} {5,B} {12,S}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,B} {3,B} {7,S}
2     C u0 p0 c0  {1,B} {4,B} {8,S}
3     C u0 p0 c0  {1,B} {5,B} {9,S}
4     C u0 p0 c0  {2,B} {6,B} {10,S}
5     C u0 p0 c0  {3,B} {6,B} {11,S}
6  *3 C u1 p0 c0  {4,B} {5,B}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28613, 'd12': 1.41667, 'd13': 2.70271},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1045""",
    longDesc = 
u"""
""",
)

entry(
    index = 2117,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32391, 'd12': 1.37467, 'd13': 2.69839},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1046""",
    longDesc = 
u"""
""",
)

entry(
    index = 2118,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29154, 'd12': 1.36383, 'd13': 2.65429},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1047""",
    longDesc = 
u"""
""",
)

entry(
    index = 2119,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {4,S}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    C u0 p0 c0  {1,D} {7,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
7    O u0 p2 c0  {3,D}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    O u0 p2 c0  {3,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.30049, 'd12': 1.4341, 'd13': 2.73398},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1048""",
    longDesc = 
u"""
""",
)

entry(
    index = 2120,
    reactant1 = """
1    C u0 p0 c0  {2,D} {3,S} {5,S}
2 *1 C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5    H u0 p0 c0  {1,S}
6 *2 H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,T}
3 *3 C u1 p0 c0  {1,D} {6,S}
4    C u0 p0 c0  {2,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26865, 'd12': 1.43396, 'd13': 2.7026},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1049""",
    longDesc = 
u"""
""",
)

entry(
    index = 2121,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31396, 'd12': 1.38184, 'd13': 2.69579},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1050""",
    longDesc = 
u"""
""",
)

entry(
    index = 2122,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29097, 'd12': 1.41433, 'd13': 2.70224},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1051""",
    longDesc = 
u"""
""",
)

entry(
    index = 2123,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {5,S} {6,S} {7,S}
2  *3 C u1 p0 c0  {1,S} {3,S} {8,S}
3     C u0 p0 c0  {2,S} {4,D} {9,S}
4     C u0 p0 c0  {3,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5  *2 H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.27691, 'd12': 1.46516, 'd13': 2.7409},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1052""",
    longDesc = 
u"""
""",
)

entry(
    index = 2124,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7  *2 H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.2677, 'd12': 1.43686, 'd13': 2.70414},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1053""",
    longDesc = 
u"""
""",
)

entry(
    index = 2125,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {6,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
4     C u0 p0 c0  {1,S} {16,S} {17,S} {18,S}
5     C u0 p0 c0  {2,S} {10,S} {11,S} {12,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7  *3 C u1 p0 c0  {2,S} {20,S} {21,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {5,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {3,S}
15    H u0 p0 c0  {3,S}
16    H u0 p0 c0  {4,S}
17    H u0 p0 c0  {4,S}
18    H u0 p0 c0  {4,S}
19    O u0 p2 c0  {6,D}
20    H u0 p0 c0  {7,S}
21    H u0 p0 c0  {7,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {5,S} {6,S} {7,S} {9,S}
3  *1 C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {2,S} {19,S} {20,S} {21,S}
7     C u0 p0 c0  {1,S} {2,S} {22,D}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10 *2 H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    H u0 p0 c0  {6,S}
20    H u0 p0 c0  {6,S}
21    H u0 p0 c0  {6,S}
22    O u0 p2 c0  {7,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.36735, 'd12': 1.35426, 'd13': 2.72044},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1054""",
    longDesc = 
u"""
""",
)

entry(
    index = 2126,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,D} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,D} {5,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5  *3 C u1 p0 c0  {3,S} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {6,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {3,D} {9,S}
3     C u0 p0 c0  {2,D} {4,S} {11,S}
4     C u0 p0 c0  {3,S} {5,D} {10,S}
5     C u0 p0 c0  {4,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26549, 'd12': 1.48696, 'd13': 2.75164},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1055""",
    longDesc = 
u"""
""",
)

entry(
    index = 2127,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {4,S} {5,S}
2    C u0 p0 c0  {1,D} {3,D}
3 *3 C u1 p0 c0  {2,D} {6,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {3,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {4,S} {5,S}
2    C u0 p0 c0  {3,D} {6,S} {7,S}
3    C u0 p0 c0  {1,D} {2,D}
4 *2 H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.3065, 'd12': 1.38913, 'd13': 2.69554},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1056""",
    longDesc = 
u"""
""",
)

entry(
    index = 2128,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {3,S} {4,S} {7,S} {8,S}
2     C u0 p0 c0  {3,S} {5,S} {6,D}
3  *3 C u1 p0 c0  {1,S} {2,S} {9,S}
4     C u0 p0 c0  {1,S} {5,D} {10,S}
5     C u0 p0 c0  {2,S} {4,D} {11,S}
6     C u0 p0 c0  {2,D} {12,S} {13,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {6,S}
13    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {7,S} {8,S}
2     C u0 p0 c0  {1,S} {4,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {5,S} {6,D}
4     C u0 p0 c0  {2,S} {5,D} {11,S}
5     C u0 p0 c0  {3,S} {4,D} {12,S}
6     C u0 p0 c0  {3,D} {13,S} {14,S}
7  *2 H u0 p0 c0  {1,S}
8     H u0 p0 c0  {1,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {6,S}
14    H u0 p0 c0  {6,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28076, 'd12': 1.45541, 'd13': 2.73615},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1057""",
    longDesc = 
u"""
""",
)

entry(
    index = 2129,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29548, 'd12': 1.41059, 'd13': 2.70572},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1058""",
    longDesc = 
u"""
""",
)

entry(
    index = 2130,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2 *1 C u0 p0 c0  {1,S} {3,D} {7,S}
3    C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7 *2 H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {3,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {3,D} {7,S} {8,S}
3 *3 C u1 p0 c0  {1,S} {2,D}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.32312, 'd12': 1.37984, 'd13': 2.70272},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1059""",
    longDesc = 
u"""
""",
)

entry(
    index = 2131,
    reactant1 = """
1    C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3 *1 O u0 p2 c0  {1,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,S} {7,S} {8,S}
3 *3 O u1 p2 c0  {2,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28612, 'd12': 1.24003, 'd13': 2.52591},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1060""",
    longDesc = 
u"""
""",
)

entry(
    index = 2132,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,S} {4,D}
2 *3 C u1 p0 c0  {1,S} {5,S} {6,S}
3    H u0 p0 c0  {1,S}
4    O u0 p2 c0  {1,D}
5    H u0 p0 c0  {2,S}
6    H u0 p0 c0  {2,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2    C u0 p0 c0  {1,S} {6,D} {7,S}
3 *2 H u0 p0 c0  {1,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    O u0 p2 c0  {2,D}
7    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29856, 'd12': 1.42255, 'd13': 2.71914},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1061""",
    longDesc = 
u"""
""",
)

entry(
    index = 2133,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.29393, 'd12': 1.3659, 'd13': 2.65648},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1062""",
    longDesc = 
u"""
""",
)

entry(
    index = 2134,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {5,S}
2    C u0 p0 c0  {1,D} {6,S} {7,S}
3    C u0 p0 c0  {1,S} {4,T}
4    C u0 p0 c0  {3,T} {8,S}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2 *3 C u1 p0 c0  {1,D} {3,S}
3    C u0 p0 c0  {2,S} {4,T}
4    C u0 p0 c0  {3,T} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.35986, 'd12': 1.33559, 'd13': 2.69509},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1063""",
    longDesc = 
u"""
""",
)

entry(
    index = 2135,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1    C u0 p0 c0  {2,D} {5,S} {6,S}
2    C u0 p0 c0  {1,D} {3,D}
3    C u0 p0 c0  {2,D} {4,D}
4 *3 C u1 p0 c0  {3,D} {7,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {4,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1 *1 C u0 p0 c0  {3,D} {5,S} {6,S}
2    C u0 p0 c0  {4,D} {7,S} {8,S}
3    C u0 p0 c0  {1,D} {4,D}
4    C u0 p0 c0  {2,D} {3,D}
5 *2 H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {2,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.31643, 'd12': 1.38237, 'd13': 2.69867},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1064""",
    longDesc = 
u"""
""",
)

entry(
    index = 2136,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,D} {5,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3  *1 C u0 p0 c0  {1,D} {7,S} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {3,S}
8  *2 H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {3,D} {5,S}
2    C u0 p0 c0  {1,S} {4,D} {6,S}
3    C u0 p0 c0  {1,D} {7,S} {8,S}
4 *3 C u1 p0 c0  {2,D} {9,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {2,S}
7    H u0 p0 c0  {3,S}
8    H u0 p0 c0  {3,S}
9    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.28005, 'd12': 1.42069, 'd13': 2.70055},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1065""",
    longDesc = 
u"""
""",
)

entry(
    index = 2137,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *1 C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14 *2 H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {7,S}
2     C u0 p0 c0  {1,S} {8,S} {9,S} {10,S}
3     C u0 p0 c0  {1,S} {11,S} {12,S} {13,S}
4     C u0 p0 c0  {6,S} {14,S} {15,S} {16,S}
5     C u0 p0 c0  {1,S} {6,S} {17,D}
6  *3 C u1 p0 c0  {4,S} {5,S} {18,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {2,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {3,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {4,S}
17    O u0 p2 c0  {5,D}
18    H u0 p0 c0  {6,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product2 = """
1     C u0 p0 c0  {3,S} {4,S} {6,S} {7,S}
2  *1 C u0 p0 c0  {5,S} {6,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {10,S} {11,S} {12,S}
4     C u0 p0 c0  {1,S} {13,S} {14,S} {15,S}
5     C u0 p0 c0  {2,S} {16,S} {17,S} {18,S}
6     C u0 p0 c0  {1,S} {2,S} {19,D}
7     H u0 p0 c0  {1,S}
8  *2 H u0 p0 c0  {2,S}
9     H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {3,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
15    H u0 p0 c0  {4,S}
16    H u0 p0 c0  {5,S}
17    H u0 p0 c0  {5,S}
18    H u0 p0 c0  {5,S}
19    O u0 p2 c0  {6,D}
""",
    distances = DistanceData(
        distances = {'d23': 1.28794, 'd12': 1.44855, 'd13': 2.73128},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1066""",
    longDesc = 
u"""
""",
)

entry(
    index = 2138,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *1 C u0 p0 c0  {3,D} {4,S} {11,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11 *2 H u0 p0 c0  {5,S}
""",
    reactant2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4  *3 C u1 p0 c0  {1,S} {12,S} {13,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
""",
    product1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2  *1 C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3     C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     C u0 p0 c0  {1,S} {12,S} {13,S} {14,S}
5     H u0 p0 c0  {1,S}
6  *2 H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {3,S}
12    H u0 p0 c0  {4,S}
13    H u0 p0 c0  {4,S}
14    H u0 p0 c0  {4,S}
""",
    product2 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {5,S} {10,S}
5  *3 C u1 p0 c0  {3,D} {4,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26504, 'd12': 1.44333, 'd13': 2.70806},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1067""",
    longDesc = 
u"""
""",
)

entry(
    index = 2139,
    reactant1 = """
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *1 C u0 p0 c0  {2,D} {8,S} {9,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
9 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1    C u0 p0 c0  {2,S} {4,S} {5,S} {6,S}
2    C u0 p0 c0  {1,S} {3,D} {7,S}
3 *3 C u1 p0 c0  {2,D} {8,S}
4    H u0 p0 c0  {1,S}
5    H u0 p0 c0  {1,S}
6    H u0 p0 c0  {1,S}
7    H u0 p0 c0  {2,S}
8    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.20678, 'd12': 1.61836, 'd13': 2.81885},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1068""",
    longDesc = 
u"""
""",
)

entry(
    index = 2140,
    reactant1 = """
1 *1 C u0 p0 c0  {2,D} {3,S} {4,S}
2    C u0 p0 c0  {1,D} {5,D}
3    H u0 p0 c0  {1,S}
4 *2 H u0 p0 c0  {1,S}
5    O u0 p2 c0  {2,D}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1 *3 C u1 p0 c0  {2,D} {4,S}
2    C u0 p0 c0  {1,D} {3,D}
3    O u0 p2 c0  {2,D}
4    H u0 p0 c0  {1,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.18877, 'd12': 1.62646, 'd13': 2.80617},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1069""",
    longDesc = 
u"""
""",
)

entry(
    index = 2141,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *1 C u0 p0 c0  {1,S} {9,S} {10,S} {11,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
11 *2 H u0 p0 c0  {3,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {4,S} {5,S}
2     C u0 p0 c0  {1,S} {6,S} {7,S} {8,S}
3  *3 C u1 p0 c0  {1,S} {9,S} {10,S}
4     H u0 p0 c0  {1,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {3,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.25136, 'd12': 1.53291, 'd13': 2.78427},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1070""",
    longDesc = 
u"""
""",
)

entry(
    index = 2142,
    reactant1 = """
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2  *1 C u0 p0 c0  {1,S} {7,S} {8,S} {9,S}
3     C u0 p0 c0  {1,S} {4,D} {10,S}
4     C u0 p0 c0  {3,D} {11,S} {12,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {2,S}
9  *2 H u0 p0 c0  {2,S}
10    H u0 p0 c0  {3,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {4,S}
""",
    reactant2 = """
multiplicity 2
1  *3 C u1 p0 c0  {2,S} {3,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {6,S}
3     C u0 p0 c0  {1,S} {5,D} {8,S}
4     C u0 p0 c0  {2,D} {9,S} {10,S}
5     C u0 p0 c0  {3,D} {11,S} {12,S}
6     H u0 p0 c0  {2,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {4,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {5,S}
12    H u0 p0 c0  {5,S}
""",
    product1 = """
multiplicity 2
1     C u0 p0 c0  {2,S} {3,S} {5,S} {6,S}
2     C u0 p0 c0  {1,S} {4,D} {7,S}
3  *3 C u1 p0 c0  {1,S} {8,S} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     H u0 p0 c0  {1,S}
6     H u0 p0 c0  {1,S}
7     H u0 p0 c0  {2,S}
8     H u0 p0 c0  {3,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
""",
    product2 = """
1  *1 C u0 p0 c0  {2,S} {3,S} {6,S} {7,S}
2     C u0 p0 c0  {1,S} {4,D} {8,S}
3     C u0 p0 c0  {1,S} {5,D} {9,S}
4     C u0 p0 c0  {2,D} {10,S} {11,S}
5     C u0 p0 c0  {3,D} {12,S} {13,S}
6  *2 H u0 p0 c0  {1,S}
7     H u0 p0 c0  {1,S}
8     H u0 p0 c0  {2,S}
9     H u0 p0 c0  {3,S}
10    H u0 p0 c0  {4,S}
11    H u0 p0 c0  {4,S}
12    H u0 p0 c0  {5,S}
13    H u0 p0 c0  {5,S}
""",
    distances = DistanceData(
        distances = {'d23': 1.26123, 'd12': 1.5188, 'd13': 2.7775},
        method = "B3LYP/6-31+G(d,p)",
    ),
    reference = None,
    referenceType = "",
    rank = 3,
    shortDesc = u"""Reverse reaction for reaction index 1071""",
    longDesc = 
u"""
""",
)

